@@ -21,6 +21,7 @@
 #include <string.h>
 #include "../lib/version.h"
 #include "../lib/wire/datadir.h"
+#include "libgimp/gimpintl.h"
 
 #ifdef WIN32
 
@@ -133,7 +134,7 @@ server_start(int port, char *log)
 
   eval_proc = procedural_db_lookup ("extension_script_fu_server");
   if(!eval_proc) {
-      g_message ("script-fu error: server mode not available\n");
+      g_message (_("script-fu error: server mode not available\n"));
       return;
   }
 
@@ -145,7 +146,7 @@ server_start(int port, char *log)
   args[1].value.pdb_int = port;
   args[2].value.pdb_pointer = log;
 
-  vals = procedural_db_execute ("extension_script_fu_server", args);
+  vals = procedural_db_execute (_("extension_script_fu_server"), args);
   switch (vals[0].value.pdb_int) {
     case PDB_EXECUTION_ERROR:
       g_print ("server start: experienced an execution error.\n");
@@ -431,7 +432,7 @@ make_initialization_status_window(void)
 			      NULL);
 	  gtk_window_set_wmclass (GTK_WINDOW(win_initstatus), "startup", PROGRAM_NAME);
 	  gtk_window_set_title(GTK_WINDOW(win_initstatus),
-		               "CinePaint Startup");
+		               _("CinePaint Startup"));
 
 	  if (no_splash_image == FALSE && splash_logo_load_size (win_initstatus))
 	    {
@@ -584,6 +585,8 @@ app_init (void)
       }
     }
 
+  app_update_prefix();
+
   RESET_BAR();
   file_ops_pre_init ();    /*  pre-initialize the file types  */
   RESET_BAR();
@@ -591,7 +594,7 @@ app_init (void)
   xcf_init ();             /*  initialize the xcf file format routines */
   cms_init();              /*  initialize colour management */
 
-  app_init_update_status ("Looking for data files", "Brushes", 0.00);
+  app_init_update_status (_("Looking for data files"), "Brushes", 0.00);
   brushes_init (no_data);         /*  initialize the list of gimp brushes  */
   app_init_update_status (NULL, "Patterns", 0.25);
   patterns_init (no_data);        /*  initialize the list of gimp patterns  */
@@ -705,7 +708,75 @@ app_exit (int kill_it)
 
 /*  app_exit_finish ();
 */
+}
+
+void
+app_update_prefix (void)
+{
+    if(strcmp(GetDirStaticPrefix(), GetDirPrefix()) != 0)
+    {
+      int len = 4096;
+      char *n_path = malloc( len );
+
+      snprintf( n_path,len, "%s%s%s%s%s", GetDirPrefix(),
+                GetDirSeparator(), GetDirDataSuffix(), GetDirSeparator(),
+                "brushes" );
+      if(brush_path)
+      { snprintf( &n_path[strlen(n_path)] ,len, ":%s", brush_path );
+        free(brush_path);
+      }
+      brush_path = n_path;
+
+      n_path = malloc( len );
+      snprintf( n_path,len, "%s%s%s%s%s", GetDirPrefix(),
+                GetDirSeparator(), GetDirDataSuffix(), GetDirSeparator(),
+                "patterns" );
+      if(pattern_path)
+      { snprintf( &n_path[strlen(n_path)] ,len, ":%s", pattern_path );
+        free(pattern_path);
+        pattern_path = n_path;
+      }
+
+      n_path = malloc( len );
+      snprintf( n_path,len, "%s%s%s%s%s", GetDirPrefix(),
+                GetDirSeparator(), GetDirDataSuffix(), GetDirSeparator(),
+                "palettes" );
+      if(palette_path)
+      { snprintf( &n_path[strlen(n_path)] ,len, ":%s", palette_path );
+        free(palette_path);
+      }
+      palette_path = n_path;
+
+      n_path = malloc( len );
+      snprintf( n_path,len, "%s%s%s%s%s", GetDirPrefix(),
+                GetDirSeparator(), GetDirDataSuffix(), GetDirSeparator(),
+                "gradients" );
+      if(gradient_path)
+      { snprintf( &n_path[strlen(n_path)] ,len, ":%s", gradient_path );
+        free(gradient_path);
+      }
+      gradient_path = n_path;
+
+      n_path = malloc( len );
+      snprintf( n_path,len, "%s%s%s%s%s", GetDirPrefix(),
+                GetDirSeparator(), GetDirPluginSuffix(), GetDirSeparator(),
+                "plug-ins");
+      if(plug_in_path)
+      { snprintf( &n_path[strlen(n_path)] ,len, ":%s", plug_in_path );
+        free(plug_in_path);
+      }
+      plug_in_path = n_path;
+
+      printf("Using new paths:\n  %s\n  %s\n  %s\n  %s\n  %s\n",
+             brush_path, pattern_path, palette_path,
+             gradient_path, plug_in_path );
     }
+  
+# ifdef DEBUG_
+    printf("currently at: %s %s %s\n", getenv("PWD")?getenv("PWD"):"?", GetDirPrefix(), GetDirData());
+# endif
+}
+
 
 /********************************************************
  *   Routines to query exiting the application          *
@@ -761,7 +832,7 @@ really_quit_dialog ()
 
   dialog = gtk_dialog_new ();
   gtk_window_set_wmclass (GTK_WINDOW (dialog), "really_quit", PROGRAM_NAME);
-  gtk_window_set_title (GTK_WINDOW (dialog), "Really Quit?");
+  gtk_window_set_title (GTK_WINDOW (dialog), _("Really Quit?"));
   gtk_window_set_policy (GTK_WINDOW (dialog), FALSE, FALSE, FALSE);
 
   gtk_widget_set_uposition(dialog, generic_window_x, generic_window_y);
@@ -779,11 +850,15 @@ really_quit_dialog ()
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox),
       vbox, TRUE, TRUE, 0);
 
-  label = gtk_label_new ("Really quit? -- Not all is saved."); 
+  label = gtk_label_new (_("Really quit? -- Not all is saved.")); 
   gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 4);
   gtk_misc_set_alignment (GTK_MISC (label), 0.5, 0.5);
   gtk_widget_show (label);
 
+  { int i = 0;
+    for (;i<2;++i)
+      quit_action_items[i].label = _(quit_action_items[i].label);
+  }
   quit_action_items[0].user_data = dialog;
   quit_action_items[1].user_data = dialog;
   build_action_area (GTK_DIALOG (dialog), quit_action_items, 2, 0);
