@@ -1,6 +1,17 @@
-/*
+/*  
+ * BASE FRAME MANAGER
  *
- */
+  
+  CHANGE-LOG (started 2006/03)
+  ============================
+  2006/03  -hsbo [hartmut.sbosny@gmx.de]
+   - brief function descriptions (started)
+   - clearing and renaming:
+      -> bfm_get_fg_ID()     (the former bfm_get_fg_display())
+      -> bfm_get_bg_ID()     (new)
+      -> bfm_getset_bg_ID()  (the former bfm_get_bg_display())
+   - bfm_check() has become public
+*/ 
 
 #include "base_frame_manager.h"
 #include "store_frame_manager.h"
@@ -14,8 +25,8 @@
 
 static int success; 
 
-
-static char
+/** @return 1, if display has bfm, 0 else. NULL-arg allowed. */
+/*static*/ char
 bfm_check (GDisplay *disp)
 {
   if (!disp)
@@ -25,6 +36,7 @@ bfm_check (GDisplay *disp)
   return 0;
 }
 
+/** @return 1, if display has an image, 0 else */
 static char
 bfm_check_disp (GDisplay *disp)
 {
@@ -32,9 +44,9 @@ bfm_check_disp (GDisplay *disp)
     return 0;
   if (!disp->gimage)
     return 0;
-  return 1;
+  return 1;             
 
-  if (!disp->gimage->filename)
+  if (!disp->gimage->filename)  /* ?? - unreachable */
     return 0;
   return 1;
 }
@@ -47,7 +59,7 @@ typedef void (*CheckCallback) (GtkWidget *, gpointer);
 static void
 bfm_init_varibles (GDisplay *disp)
 {
-  disp->bfm->onionskin = 0;
+  disp->bfm->onionskin_b = 0;
   disp->bfm->fg = 0;
   disp->bfm->bg = 0;
 }
@@ -55,34 +67,26 @@ bfm_init_varibles (GDisplay *disp)
 void
 bfm_create_sfm (GDisplay *disp)
 {
-
   double scale;
   
- if(!bfm_check_disp (disp))
-   return;
+  if(!bfm_check_disp (disp))
+    return;
 
- disp->bfm = (base_frame_manager*) g_malloc_zero (sizeof(base_frame_manager)); 
- disp->bfm->sfm = (store_frame_manager*) g_malloc_zero (sizeof(store_frame_manager));
- disp->bfm->cfm = 0;
- bfm_init_varibles (disp);
+  if (disp->bfm)
+    {
+      g_message("Only one Flipbook per display is allowed.");
+      return;
+    }
+  
+  scale = ((double) SCALESRC (disp) / (double)SCALEDEST (disp));
 
- disp->bfm->sfm->stores = 0;
- disp->bfm->sfm->bg = -1;
- disp->bfm->sfm->fg = 0;
- disp->bfm->sfm->add_dialog = 0;
- disp->bfm->sfm->chg_frame_dialog = 0;
- disp->bfm->sfm->readonly = 0; 
- disp->bfm->sfm->play = 0; 
- disp->bfm->sfm->load_smart = 0; 
-
- scale = ((double) SCALESRC (disp) / (double)SCALEDEST (disp));
- disp->bfm->sfm->s_x = disp->bfm->sfm->sx = 0;
- disp->bfm->sfm->s_y = disp->bfm->sfm->sy = 0;
- disp->bfm->sfm->e_x = disp->bfm->sfm->ex = disp->gimage->width;
- disp->bfm->sfm->e_y = disp->bfm->sfm->ey = disp->gimage->height;
- /* GUI */
- sfm_create_gui (disp);
+  disp->bfm = (base_frame_manager*) g_malloc_zero (sizeof(base_frame_manager)); 
+  disp->bfm->sfm = (store_frame_manager*) g_malloc_zero (sizeof(store_frame_manager));
+  disp->bfm->cfm = 0;
+  bfm_init_varibles (disp);
 
+  /* GUI */
+  sfm_create_gui (disp);
 }
 
 void
@@ -116,9 +120,10 @@ bfm_dirty (GDisplay *disp)
     }
   else
     if(disp->bfm->sfm)
-      sfm_dirty (disp);
+      sfm_dirty (disp, disp->bfm->sfm->fg);
 }
 
+/** @return 1, if `disp' has bfm, 0 else. NULL-arg not allowed! */
 int
 bfm (GDisplay *disp)
 {
@@ -126,22 +131,24 @@ bfm (GDisplay *disp)
     return 1;
   return 0; 
 }
+
 /*
  * ONIONSKINNIG
  */
 
+/** @return 1 if `disp' has bfm and onionskin is on, 0 else */
 char 
 bfm_onionskin (GDisplay *disp)
 {
   if (!bfm_check (disp))
     return 0;
-  return disp->bfm->onionskin;
+  return disp->bfm->onionskin_b;
 }
 
 void 
 bfm_onionskin_set_offset (GDisplay *disp, int x, int y)
 {
-  if (!bfm_check (disp)  || !disp->bfm->onionskin)
+  if (!bfm_check (disp)  || !disp->bfm->onionskin_b)
     return;
   
   if(disp->bfm->cfm)
@@ -156,7 +163,7 @@ bfm_onionskin_set_offset (GDisplay *disp, int x, int y)
 void 
 bfm_onionskin_rm (GDisplay *disp)
 {
-  if (!bfm_check (disp) || !disp->bfm->onionskin)
+  if (!bfm_check (disp) || !disp->bfm->onionskin_b)
     return;
 
   if(disp->bfm->cfm)
@@ -164,8 +171,13 @@ bfm_onionskin_rm (GDisplay *disp)
       /*cfm_onionskin_rm (disp->bfm->cfm);*/
     }
   else
-    if(disp->bfm->sfm && disp->bfm->onionskin)
+    if(disp->bfm->sfm && disp->bfm->onionskin_b)
       {
+        disp->bfm->sfm->old_offset_x = GIMP_DRAWABLE (disp->bfm->bg->active_layer)->offset_x;
+        disp->bfm->sfm->old_offset_y = GIMP_DRAWABLE (disp->bfm->bg->active_layer)->offset_y;
+        disp->bfm->sfm->old_ex = disp->bfm->sfm->ex;
+        disp->bfm->sfm->old_ey = disp->bfm->sfm->ey;
+        disp->bfm->sfm->old_opacity = disp->bfm->fg->active_layer->opacity;
 
 	disp->bfm->fg->active_layer->opacity = 1;
 	gimage_remove_layer (disp->bfm->fg, (disp->bfm->bg->active_layer));
@@ -173,21 +185,22 @@ bfm_onionskin_rm (GDisplay *disp)
 	GIMP_DRAWABLE (disp->bfm->bg->active_layer)->offset_x = 0;
 	GIMP_DRAWABLE (disp->bfm->bg->active_layer)->offset_y = 0;
 	GIMP_DRAWABLE(disp->bfm->bg->active_layer)->gimage_ID = disp->bfm->bg->ID;
-	disp->bfm->onionskin = 0;
+	disp->bfm->onionskin_b = 0;
 	sfm_onionskin_rm (disp);
 
       }
 }
 
+/** @return fg gimage if `disp' has bfm, NULL else */
 GImage* 
 bfm_get_fg (GDisplay *disp)
 {
   if (!bfm_check (disp))
     return NULL;
-
   return disp->bfm->fg;
 }
 
+/** @return bg gimage (can be NULL) if `disp' has bfm, NULL else */
 GImage* 
 bfm_get_bg (GDisplay *disp)
 {
@@ -196,53 +209,71 @@ bfm_get_bg (GDisplay *disp)
   return disp->bfm->bg;
 }
 
+/** @return fg drawable if `disp' has bfm, NULL else */
 CanvasDrawable* 
 bfm_get_fg_drawable (GDisplay *disp)
 {
   if (!bfm_check (disp))
     return NULL;
   return GIMP_DRAWABLE (disp->bfm->fg->active_layer); 
-}
+}                               /* relies on fg!=NULL */
 
+/** @return bg drawable if `disp' has bfm, NULL else */
 CanvasDrawable* 
 bfm_get_bg_drawable (GDisplay *disp)
 {
   if (!bfm_check (disp))
     return NULL;
-  return GIMP_DRAWABLE (disp->bfm->bg->active_layer); 
+  if (!disp->bfm->bg) 
+    return NULL;  
+  return GIMP_DRAWABLE (disp->bfm->bg->active_layer);
 }
 
+/** @return fg imageID if `disp' has bfm, -1 else */
 int 
-bfm_get_fg_display (GDisplay *disp)
+bfm_get_fg_ID (GDisplay *disp)
 {
    if (!bfm_check (disp))
-         return -1;
-   return disp->bfm->fg->ID;
+        return -1;
+   return disp->bfm->fg->ID;    /* relies on fg!=NULL */
 }
 
+/** @return bg imageID (can be -1) if `disp' has bfm, -1 else */
 int 
-bfm_get_bg_display (GDisplay *disp)
+bfm_get_bg_ID (GDisplay *disp)
 {
    if (!bfm_check (disp))
-         return -1;
+        return -1;
+   return disp->bfm->bg ? disp->bfm->bg->ID : -1;
+}
+
+/** If `disp' has bfm and bg not set, set bg=fg and update sfm.
+    @return [old/new] bg imageID, if `disp' has bfm, -1 else. */
+int 
+bfm_getset_bg_ID (GDisplay *disp)
+{
+   if (!bfm_check (disp))
+        return -1;
    if (!disp->bfm->bg)
    {
-	   disp->bfm->bg = disp->bfm->fg;
-	   sfm_set_bg (disp);
+     disp->bfm->bg = disp->bfm->fg;
+     sfm_set_bg (disp, -1);          /* unsets bg in sfm - if no bg was set in bfm??? */
+     //sfm_set_bg (disp, sfm_pos_of_ID(disp, disp->bfm->bg->ID)); // disp->bfm->bg==NULL!
    }
-	return disp->bfm->bg->ID;
+   return disp->bfm->bg->ID;
 }
 
+/** If `disp' has bfm, set bfm->fg to fg */
 void
 bfm_set_fg (GDisplay *disp, GImage *fg)
 {
-  if (!bfm_check (disp))
+   if (!bfm_check (disp))
         return;
 
-  disp->bfm->fg = fg;
-
+   disp->bfm->fg = fg;
 }
 
+/** If `disp' has bfm, set bfm->bg to bg */
 void
 bfm_set_bg (GDisplay *disp, GImage *bg)
 {
@@ -250,13 +281,12 @@ bfm_set_bg (GDisplay *disp, GImage *bg)
         return;
 
   disp->bfm->bg = bg;
-
 }
 
 void
 bfm_onionskin_unset (GDisplay *disp)
 {
-  disp->bfm->onionskin = 0; 
+  disp->bfm->onionskin_b = 0; 
 }
 
 void 
@@ -270,7 +300,7 @@ bfm_onionskin_display (GDisplay *disp, double val, int sx, int sy, int ex, int e
 
   disp->bfm->fg->active_layer->opacity = val;
 
-  if (!disp->bfm->onionskin)
+  if (!disp->bfm->onionskin_b)
     {
       d_printf ("add layer \n");
       if (active_tool->type == CLONE)
@@ -287,7 +317,7 @@ bfm_onionskin_display (GDisplay *disp, double val, int sx, int sy, int ex, int e
 	      }
       gimage_set_active_layer (disp->bfm->fg, layer);
       sfm_onionskin_set_offset (disp, x, y);
-      disp->bfm->onionskin = 1;
+      disp->bfm->onionskin_b = 1;
     }
 
   drawable_update (GIMP_DRAWABLE(disp->bfm->fg->active_layer),
@@ -412,7 +442,7 @@ bfm_set_dir_dest (GDisplay *disp, char *filename)
   #else
   /* Rob Williams */
   if (strstr(filename, "cp_out"))
-  // we are already in the output dir
+  /* we are already in the output dir */
   {
     disp->bfm->dest_dir = strdup (prune_pathname(filename));
   }
@@ -420,7 +450,7 @@ bfm_set_dir_dest (GDisplay *disp, char *filename)
   {
     pathtmp = g_string_new (prune_pathname(filename));
     g_string_append(pathtmp, "cp_out/");
-  // error conditions: already exists == good, cannot create == not our problem.
+  /* error conditions: already exists == good, cannot create == not our problem. */
     mkdir (pathtmp->str, 00777);
     disp->bfm->dest_dir = strdup (pathtmp->str);
   }
