@@ -19,6 +19,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
+#include "libgimp/gimpintl.h"
 #include "config.h"
 #include "brush.h"
 #include "brushlist.h"
@@ -225,7 +226,7 @@ gimp_brush_load(char *filename)
     }
   else if (header.version != FILE_VERSION)
     {
-      g_message ("Unknown GIMP version %d in \"%s\"\n", header.version, filename);
+      g_message (_("Unknown GIMP version %d in \"%s\"\n"), header.version, filename);
       fclose (fp);
       return NULL;
     }
@@ -245,13 +246,13 @@ gimp_brush_load(char *filename)
     brushname = (char *) g_malloc (sizeof (char) * bn_size);
     if ((fread (brushname, 1, bn_size, fp)) < CAST(size_t) bn_size)
     {
-      g_message ("Error in GIMP brush file...aborting.");
+      g_message (_("Error in GIMP brush file...aborting."));
       fclose (fp);
       return NULL;
     }
   }
   else
-    brushname = g_strdup ("Untitled");
+    brushname = g_strdup (_("Untitled"));
 
   switch(header.version)
   {
@@ -271,7 +272,7 @@ gimp_brush_load(char *filename)
      data = canvas_portion_data (brushmask,0,0);
      if ((fread (data, 1, header.width * header.height * bytes, fp)) 		
 	 < header.width * header.height * bytes)
-     	g_message ("GIMP brush file appears to be truncated.");
+     	g_message (_("GIMP brush file appears to be truncated."));
 #ifndef WORDS_BIGENDIAN
    /*  if(strcmp(PLATFORM, "linux6-i386-std"))*/
   {
@@ -286,7 +287,7 @@ gimp_brush_load(char *filename)
      canvas_portion_unref (brushmask, 0, 0); 
      break;
    default:
-     g_message ("Unknown brush format version #%d in \"%s\"\n", header.version, filename);
+     g_message (_("Unknown brush format version #%d in \"%s\"\n"), header.version, filename);
      fclose (fp);
      return NULL;
   }
@@ -312,7 +313,7 @@ gimp_brush_load(char *filename)
 #if 1 
   {
     char * basename = strrchr (filename, '/' );
-    if (basename) 
+    if (basename && default_brush)
       {
 	basename++; 
 	if (strcmp(default_brush, basename) == 0) 
