@@ -31,6 +31,7 @@
 #include <sys/types.h>
 #include <math.h>
 
+#include "libgimp/gimpintl.h"
 #include "appenv.h"
 #include "brushgenerated.h"
 #include "brush_header.h"
@@ -175,7 +176,7 @@ brush_load(char *filename)
     if (brush != NULL)
       gimp_brush_list_add(brush_list, GIMP_BRUSH(brush));
     else
-      g_print("Warning: failed to load brush \"%s\"", filename);
+      g_print(_("Warning: failed to load brush \"%s\""), filename);
   }
 }
 
@@ -288,7 +289,7 @@ get_active_brush ()
   else if (! active_brush && brush_list){
     /* need a gimp_list_get_first() type function */
     if (GIMP_LIST(brush_list)->list == NULL){
-	message_func("Couldn't find any brushes, creating a default brush!\n");
+	message_func(_("Couldn't find any brushes, creating a default brush!\n"));
       create_default_brush(); 
       return active_brush;
     }
