@@ -18,6 +18,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include "../lib/version.h"
+#include "libgimp/gimpintl.h"
 #include "gdk/gdkkeysyms.h"
 #include "appenv.h"
 #include "actionarea.h"
@@ -98,7 +99,7 @@ struct ChannelsDialog {
 
   int num_components;
   Format format;
-  ChannelType components[3];
+  ChannelType components[4];
   double ratio;
   int image_width, image_height;
   int gimage_width, gimage_height;
@@ -151,8 +152,8 @@ static void edit_channel_use_opacity_clicked (ChannelWidget *);
 /*  Only one channels dialog  */
 static ChannelsDialog *channelsD = NULL;
 
-static GdkPixmap *eye_pixmap[3] = { NULL, NULL, NULL };
-static GdkPixmap *channel_pixmap[3] = { NULL, NULL, NULL };
+static GdkPixmap *eye_pixmap[4] = { NULL, NULL, NULL, NULL };
+static GdkPixmap *channel_pixmap[4] = { NULL, NULL, NULL, NULL };
 
 static int suspend_gimage_notify = 0;
 
@@ -219,6 +220,22 @@ channels_dialog_create ()
   GtkWidget *listbox;
   GtkWidget *button_box;
 
+  /* translate menu items */
+  channels_ops[0].label = _("New Channel");
+  channels_ops[1].label = _("Raise Channel");
+  channels_ops[2].label = _("Lower Channel");
+  channels_ops[3].label = _("Duplicate Channel");
+  channels_ops[4].label = _("Delete Channel");
+  channels_ops[5].label = _("Channel To Selection");
+
+  channels_ops_buttons[0].tooltip = _("New Channel");
+  channels_ops_buttons[1].tooltip = _("Raise Channel");
+  channels_ops_buttons[2].tooltip = _("Lower Channel");
+  channels_ops_buttons[3].tooltip = _("Duplicate Channel");
+  channels_ops_buttons[4].tooltip = _("Delete Channel");
+
+  
+
   if (!channelsD)
     {
       channelsD = g_malloc_zero (sizeof (ChannelsDialog));
@@ -412,8 +429,20 @@ channels_dialog_update (int gimage_id)
 
   if (!channelsD)
     return;
-  if (channelsD->gimage_id == gimage_id)
-    return;
+
+  {
+    GImage *g;
+    gint cchannels = 0;
+
+    if (! (g = gimage_get_ID (gimage_id)))
+      return;
+
+    cchannels = gimage_get_num_color_channels(g);
+    if (channelsD->gimage_id == gimage_id &&
+        channelsD->num_components == (
+           cchannels + g_slist_length(gimage_channels(g)) ) )
+      return;
+  }
 
   channelsD->gimage_id = gimage_id;
 
@@ -461,6 +490,15 @@ channels_dialog_update (int gimage_id)
       item_list = g_list_append (item_list, cw->list_item);
       channelsD->components[2] = Blue;
       channelsD->num_components = 3;
+
+      if (tag_alpha(drawable_tag (GIMP_DRAWABLE(gimage->active_layer))) == ALPHA_YES)
+      {
+        cw = create_channel_widget (gimage, NULL, Matte);
+        channelsD->channel_widgets = g_slist_append (channelsD->channel_widgets, cw);
+        item_list = g_list_append (item_list, cw->list_item);
+        channelsD->components[3] = Matte;
+        ++channelsD->num_components;
+      }
       break;
 
     case FORMAT_GRAY:
@@ -482,7 +520,7 @@ channels_dialog_update (int gimage_id)
       break;
 
     case FORMAT_NONE:
-      g_warning ("channels_dialog_update: gimage has FORMAT_NONE");
+      g_warning (_("channels_dialog_update: gimage has FORMAT_NONE"));
       return;
     }
 
@@ -660,8 +698,10 @@ channels_dialog_set_channel (ChannelWidget *channel_widget)
 	    case Blue:
 	      gtk_list_select_item (GTK_LIST (channelsD->channel_list), 2);
 	      break;
+        case Matte:
+	      gtk_list_select_item (GTK_LIST (channelsD->channel_list), 3);
+	      break;
 	    case Auxillary:
-       case Matte:
 	      g_error ("error Matte in %s at %d: this shouldn't happen.",
 		       __FILE__, __LINE__);
 	      break;
@@ -715,8 +755,10 @@ channels_dialog_unset_channel (ChannelWidget * channel_widget)
 	    case Blue:
 	      gtk_list_unselect_item (GTK_LIST (channelsD->channel_list), 2);
 	      break;
+        case Matte:
+	      gtk_list_unselect_item (GTK_LIST (channelsD->channel_list), 3);
+	      break;
 	    case Auxillary:
-       case Matte:
 	      g_error ("error Matte[2] in %s at %d: this shouldn't happen.",
 		       __FILE__, __LINE__);
 	      break;
@@ -1044,13 +1086,20 @@ create_channel_widget (GImage      *gimage,
   GtkWidget *vbox;
   GtkWidget *alignment;
   CMSProfile *profile = gimage_get_cms_profile(gimage);
-  static const char* color_space_channel_names_[8] = {"Red","Green","Blue",""};
+  static const char* color_space_channel_names_[8];
   const char** color_space_channel_names = color_space_channel_names_;
+  color_space_channel_names_[0] = _("Red");
+  color_space_channel_names_[1] = _("Green");
+  color_space_channel_names_[2] = _("Blue");
+  color_space_channel_names_[3] = _("Alpha");
+  color_space_channel_names_[4] = "";
   if(profile)
     {
       color_space_channel_names = cms_get_profile_info(profile)->color_space_channel_names;
     }
-  
+# ifdef DEBUG
+  printf("%s:%d %s %s %s %s %s %s\n", __FILE__,__LINE__, profile ? "ja":"nein", color_space_channel_names_[0], color_space_channel_names_[1], color_space_channel_names_[2], color_space_channel_names_[3], color_space_channel_names_[4]);
+# endif
 
   list_item = gtk_list_item_new ();
 
@@ -1120,9 +1169,10 @@ create_channel_widget (GImage      *gimage,
     case Red:       channel_widget->label = gtk_label_new (color_space_channel_names[0]); break;
     case Green:     channel_widget->label = gtk_label_new (color_space_channel_names[1]); break;
     case Blue:      channel_widget->label = gtk_label_new (color_space_channel_names[2]); break;
-    case Gray:      channel_widget->label = gtk_label_new ("Gray"); break;
-    case Indexed:   channel_widget->label = gtk_label_new ("Indexed"); break;
-    case Matte:     channel_widget->label = gtk_label_new ("Matte"); break;
+    case Matte:     channel_widget->label = gtk_label_new (color_space_channel_names[3]); break;
+    case Gray:      channel_widget->label = gtk_label_new (_("Gray")); break;
+    case Indexed:   channel_widget->label = gtk_label_new (_("Indexed")); break;
+    /*case Matte:     channel_widget->label = gtk_label_new (_("Matte")); break;*/
     case Auxillary: channel_widget->label = gtk_label_new (GIMP_DRAWABLE(channel)->name); break;
     }
 
@@ -1434,6 +1484,7 @@ channel_widget_preview_redraw (ChannelWidget *channel_widget)
     case Red:       channel = RED_PIX; break;
     case Green:     channel = GREEN_PIX; break;
     case Blue:      channel = BLUE_PIX; break;
+    case Matte:     channel = ALPHA_PIX; break;
     case Gray:      channel = GRAY_PIX; break;
     case Indexed:   channel = INDEXED_PIX; break;
     case Auxillary: channel = -1; break;
@@ -1442,6 +1493,7 @@ channel_widget_preview_redraw (ChannelWidget *channel_widget)
   
   render_preview (preview_buf,
 		  channelsD->preview,
+                  NULL,
 		  channelsD->image_width,
 		  channelsD->image_height,
 		  channel);
@@ -1869,7 +1921,7 @@ channels_dialog_new_channel_query (int gimage_id)
   /*  the dialog  */
   options->query_box = gtk_dialog_new ();
   gtk_window_set_wmclass (GTK_WINDOW (options->query_box), "new_channel_options", PROGRAM_NAME);
-  gtk_window_set_title (GTK_WINDOW (options->query_box), "New Channel Options");
+  gtk_window_set_title (GTK_WINDOW (options->query_box), _("New Channel Options"));
   gtk_window_position (GTK_WINDOW (options->query_box), GTK_WIN_POS_MOUSE);
   minimize_register(options->query_box);
 
@@ -1888,7 +1940,7 @@ channels_dialog_new_channel_query (int gimage_id)
   gtk_box_pack_start (GTK_BOX (vbox), table, TRUE, TRUE, 0);
 
   /*  the name entry hbox, label and entry  */
-  label = gtk_label_new ("Channel name: ");
+  label = gtk_label_new (_("Channel name: "));
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK, 0, 1);
@@ -1898,11 +1950,11 @@ channels_dialog_new_channel_query (int gimage_id)
   gtk_widget_set_usize (options->name_entry, 75, 0);
   gtk_table_attach (GTK_TABLE (table), options->name_entry, 1, 2, 0, 1,
 		    GTK_EXPAND | GTK_SHRINK | GTK_FILL, GTK_SHRINK, 1, 1);
-  gtk_entry_set_text (GTK_ENTRY (options->name_entry), (channel_name ? channel_name : "New Channel"));
+  gtk_entry_set_text (GTK_ENTRY (options->name_entry), (channel_name ? channel_name : _("New Channel")));
   gtk_widget_show (options->name_entry);
 
   /*  the opacity scale  */
-  label = gtk_label_new ("Display Opacity: ");
+  label = gtk_label_new (_("Display Opacity: "));
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK, 0, 1);
@@ -1927,6 +1979,10 @@ channels_dialog_new_channel_query (int gimage_id)
 		    2, 3, 0, 2, GTK_EXPAND, GTK_EXPAND, 4, 2);
   gtk_widget_show (options->color_panel->color_panel_widget);
 
+  { int i;
+    for(i = 0; i < 2; ++i)
+      action_items[i].label = _(action_items[i].label);
+  }
   action_items[0].user_data = options;
   action_items[1].user_data = options;
   build_action_area (GTK_DIALOG (options->query_box), action_items, 2, 0);
@@ -2160,7 +2216,7 @@ channels_dialog_edit_channel_query (ChannelWidget *channel_widget)
   /*  the dialog  */
   options->query_box = gtk_dialog_new ();
   gtk_window_set_wmclass (GTK_WINDOW (options->query_box), "edit_channel_atributes", PROGRAM_NAME);
-  gtk_window_set_title (GTK_WINDOW (options->query_box), "Channel Attributes");
+  gtk_window_set_title (GTK_WINDOW (options->query_box), _("Channel Attributes"));
   gtk_window_position (GTK_WINDOW (options->query_box), GTK_WIN_POS_MOUSE);
   minimize_register(options->query_box);
 
@@ -2181,7 +2237,7 @@ channels_dialog_edit_channel_query (ChannelWidget *channel_widget)
   hbox = gtk_hbox_new (FALSE, 1);
   gtk_table_attach (GTK_TABLE (table), hbox, 0, 1, 0, 1,
 		    GTK_EXPAND | GTK_FILL, 0, 2, 2);
-  label = gtk_label_new ("Channel name:");
+  label = gtk_label_new (_("Channel name:"));
   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
   options->name_entry = gtk_entry_new ();
@@ -2200,7 +2256,7 @@ channels_dialog_edit_channel_query (ChannelWidget *channel_widget)
   hbox = gtk_hbox_new (FALSE, 1);
   gtk_box_pack_start (GTK_BOX (vbox1), hbox, FALSE, FALSE, 0);
 
-  label = gtk_label_new ("Display Opacity");
+  label = gtk_label_new (_("Display Opacity"));
   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
 
@@ -2221,7 +2277,7 @@ channels_dialog_edit_channel_query (ChannelWidget *channel_widget)
 
   if(index == 0) 
   {
-    button = gtk_check_button_new_with_label("Enable RGBM painting");
+    button = gtk_check_button_new_with_label(_("Enable RGBM painting"));
     gtk_signal_connect (GTK_OBJECT (button), "clicked",
 			(GtkSignalFunc) edit_channel_query_button_clicked,
 			options);
@@ -2231,7 +2287,7 @@ channels_dialog_edit_channel_query (ChannelWidget *channel_widget)
 
     hbox = gtk_hbox_new (FALSE, 1);
     gtk_box_pack_start (GTK_BOX (vbox1), hbox, FALSE, FALSE, 0);
-    label = gtk_label_new ("Matte color for RGBM paint");
+    label = gtk_label_new (_("Matte color for RGBM paint"));
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
     gtk_widget_show (label);
     link_paint_opacity_scale_data = gtk_adjustment_new (
@@ -2250,7 +2306,7 @@ channels_dialog_edit_channel_query (ChannelWidget *channel_widget)
 
 
   /* use channel as opacity */
-  button = gtk_check_button_new_with_label("Use this channel as opacity");
+  button = gtk_check_button_new_with_label(_("Use this channel as opacity"));
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
       (GtkSignalFunc) edit_channel_as_opacity_clicked,
       options);
@@ -2266,6 +2322,10 @@ channels_dialog_edit_channel_query (ChannelWidget *channel_widget)
 
   gtk_widget_show (options->color_panel->color_panel_widget);
 
+  { int i;
+    for(i = 0; i < 1; ++i)
+      action_items[i].label = _(action_items[i].label);
+  }
   action_items[0].user_data = options;
 #if 0
   action_items[1].user_data = options;
