@@ -151,7 +151,8 @@ DWORD cms_get_lcms_format(Tag tag, CMSProfile *profile);
 */
 CMSTransform *cms_get_transform(GSList *profiles,
 				DWORD lcms_input_format, DWORD lcms_output_format,
-				int lcms_intent, DWORD lcms_flags);
+				int lcms_intent, DWORD lcms_flags, int proof_intent,
+                CMSTransform **expensive_transform);
 
 /*
  * for convenience: get a transform usable for a canvas
@@ -159,7 +160,8 @@ CMSTransform *cms_get_transform(GSList *profiles,
  * returns NULL on error
  */
 CMSTransform *cms_get_canvas_transform(GSList *profiles, Canvas *canvas, 
-				       int lcms_intent, DWORD lcms_flags);
+				       int lcms_intent, DWORD lcms_flags, int proof_intent,
+                       CMSTransform **expensive_transform);
 
 /*
  * Set if the source profile has 4 colors and is converted to less color
@@ -189,6 +191,7 @@ gboolean cms_set_display_profile(CMSProfile *profile);
  * loads input and display profile 
  * and calculates standard display transform (input->display)
  * called from app_procs.c:app_init()
+ * called from the preferences dialog
  */
 void cms_init();
 
