@@ -115,11 +115,11 @@ color_correction_init_lab_transforms (GImage *image)
     profiles = g_slist_append(profiles, image_profile);
     profiles = g_slist_append(profiles, lab_profile);
     lcms_format = cms_get_lcms_format(t, image_profile);
-    color_correction_to_lab_transform = cms_get_transform(profiles, lcms_format, TYPE_Lab_16, INTENT_PERCEPTUAL, 0);
+    color_correction_to_lab_transform = cms_get_transform(profiles, lcms_format, TYPE_Lab_16, INTENT_PERCEPTUAL, 0, 0, NULL);
     
     profiles = g_slist_remove(profiles, image_profile);
     profiles = g_slist_append(profiles, image_profile);
-    color_correction_from_lab_transform = cms_get_transform(profiles, TYPE_Lab_16, lcms_format, INTENT_PERCEPTUAL, 0);  
+    color_correction_from_lab_transform = cms_get_transform(profiles, TYPE_Lab_16, lcms_format, INTENT_PERCEPTUAL, 0, 0, NULL);
     
     g_slist_free(profiles);   
 }
