@@ -252,6 +252,11 @@ color_correction_gui (GDisplay *display)
         return;
     }
 
+    if( tag_precision (drawable_tag (gimage_active_drawable(display->gimage))) != PRECISION_U8)
+    {   g_message ("Color correction operates only on 8 bit RGB color drawables.");
+        return;
+    }
+
     data = g_new(_ColorCorrectionGui, 1);
     data->display = display;
     data->active=TRUE;
@@ -281,12 +286,12 @@ _color_correction_gui_create (_ColorCorrectionGui *data)
     GtkWidget *label =NULL;
     GtkWidget *notebook = NULL;
     GtkWidget *frame = NULL;
-	GtkObject *hue_adjustment = gtk_adjustment_new(0.0, 0.0, 360.0, 1.0, 0.0, 0.0);
-	GtkObject *saturation_adjustment = gtk_adjustment_new(0.0, 0.0, 100.0, 1.0, 0.0, 0.0);
-	GtkObject *lightness_adjustment = gtk_adjustment_new(0.0, 0.0, 100.0, 1.0, 0.0, 0.0);
-	_ColorCorrectionGuiSpin *spin_data = g_new(_ColorCorrectionGuiSpin, 1);
-	_ColorCorrectionGuiWheel *wheel_data=g_new(_ColorCorrectionGuiWheel, 1);
-	_ColorCorrectionGuiLSlider *lslider_data = g_new(_ColorCorrectionGuiLSlider, 1);
+	GtkObject *hue_adjustment;
+	GtkObject *saturation_adjustment;
+	GtkObject *lightness_adjustment;
+	_ColorCorrectionGuiSpin *spin_data;
+	_ColorCorrectionGuiWheel *wheel_data;
+	_ColorCorrectionGuiLSlider *lslider_data;
     int i;
        
 
@@ -332,15 +337,16 @@ _color_correction_gui_create (_ColorCorrectionGui *data)
 	gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE, 3);
 
 	hbox = gtk_hbox_new(FALSE, 0);
-	/*	GtkStyle *style= gtk_style_new(); */
-	/*style->fg[GTK_STATE_NORMAL]=style->dark[GTK_STATE_NORMAL]; */
-	/*gtk_widget_set_style(hbox, style); */
+	/*	GtkStyle *style= gtk_style_new();
+	style->fg[GTK_STATE_NORMAL]=style->dark[GTK_STATE_NORMAL];
+	gtk_widget_set_style(hbox, style); */
 
 	gtk_container_add(GTK_CONTAINER(frame), hbox);    
 
 	/* WHEEL */
 	data->color_wheels[i] = gtk_drawing_area_new ();
 	gtk_drawing_area_size(GTK_DRAWING_AREA(data->color_wheels[i]), WHEEL_RADIUS*2+2,WHEEL_RADIUS*2+2); 
+    wheel_data = g_new(_ColorCorrectionGuiWheel, 1);
 	wheel_data->range = i;
 	wheel_data->pixmap = NULL;
 	wheel_data->display_buffer = NULL;
@@ -372,6 +378,7 @@ _color_correction_gui_create (_ColorCorrectionGui *data)
 	/*	gtk_widget_set_style(frame, style); */
 
 	data->lsliders[i] = gtk_drawing_area_new();    
+    lslider_data = g_new(_ColorCorrectionGuiLSlider, 1);
 	lslider_data->range= i;
 	lslider_data->gc = NULL;
 	lslider_data->pixmap = NULL;
@@ -389,11 +396,14 @@ _color_correction_gui_create (_ColorCorrectionGui *data)
 
 
 	/* INPUTS */
+	hue_adjustment = gtk_adjustment_new(0.0, 0.0, 360.0, 1.0, 0.0, 0.0);
+	saturation_adjustment = gtk_adjustment_new(0.0, 0.0, 100.0, 1.0, 0.0, 0.0);
+	lightness_adjustment = gtk_adjustment_new(0.0, 0.0, 100.0, 1.0, 0.0, 0.0);
 
 	hbox = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 3);    
 
-
+	spin_data = g_new(_ColorCorrectionGuiSpin, 1);
 	spin_data->range = i;
 	spin_data->attribute = HUE;
 	label = gtk_label_new("H");
