@@ -61,6 +61,7 @@
 #include <string.h>
 #include <math.h>
 
+#include "libgimp/gimpintl.h"
 #include "appenv.h"
 #include "actionarea.h"
 #include "canvas.h"
@@ -111,7 +112,7 @@ convert_to_grayscale (void *gimage_ptr)
 void
 convert_to_indexed (void *gimage_ptr)
 {
-  g_message ("indexed image support has been dropped for the moment");
+  g_message (_("indexed image support has been dropped for the moment"));
   return;
 }
 
@@ -304,11 +305,12 @@ convert_image_precision (void *gimage_ptr,
    lcms_intent is littlecms intent parameter */
 void
 convert_image_colorspace (void *gimage_ptr, CMSProfile *new_profile,
-                          int lcms_intent)
+                          int lcms_intent, int flags)
 {   GImage *image = (GImage *) gimage_ptr;
     DWORD lcms_format_in;
     DWORD lcms_format_out;
     CMSTransform *transform;
+    DWORD cms_flags = 0;
 
     /*  get the profiles */
     GSList *profiles = NULL;
@@ -320,23 +322,44 @@ convert_image_colorspace (void *gimage_ptr, CMSProfile *new_profile,
     profiles = g_slist_append(profiles, (gpointer)image_profile);
     profiles = g_slist_append(profiles, (gpointer)new_profile);
 
+    /* add alpha if needed */
+    if( strstr(cms_get_profile_info(new_profile)->color_space_name,"Cmyk") &&
+        !layer_has_alpha( image->active_layer ))
+    { layer_add_alpha( image->active_layer );
+    }
+
     /* assuming all layers have homogenous alpha */
     lcms_format_in  = cms_get_lcms_format(
                               drawable_tag(GIMP_DRAWABLE(image->active_layer)),
-                              gimage_get_cms_profile(image)  );
+                              image_profile  );
     lcms_format_out = cms_get_lcms_format(
                               drawable_tag(GIMP_DRAWABLE(image->active_layer)),
                               new_profile  );
     if  (!(int)lcms_format_in || !(int)lcms_format_out)
     {   g_warning("%s:%d %s(): wrong lcms_format %d|%d",
-                  __FILE__,__LINE__,__func__,  lcms_format_in, lcms_format_out);
+                  __FILE__,__LINE__,__func__,
+                  (int) lcms_format_in, (int) lcms_format_out);
         return;
-    } 
+    }
 
-    transform = cms_get_transform(profiles, lcms_format_in, lcms_format_out, lcms_intent, cms_default_flags);
+    cms_flags = cms_default_flags;
+    if(flags & cmsFLAGS_WHITEBLACKCOMPENSATION)
+      cms_flags = cms_flags | cmsFLAGS_WHITEBLACKCOMPENSATION;
+    else
+      cms_flags = cms_flags & (~cmsFLAGS_WHITEBLACKCOMPENSATION);
+
+    cms_flags = cms_flags & (~cmsFLAGS_SOFTPROOFING);
+
+    transform = cms_get_transform(profiles, lcms_format_in, lcms_format_out,
+                                            lcms_intent, cms_flags,
+                                            0, NULL);
     g_slist_free(profiles);
+    if(!transform)
+    {   g_warning("%s:%d %s(): transform failed", __FILE__,__LINE__,__func__);
+        return;
+    }
     gimage_transform_colors(image, transform, TRUE);
-    cms_return_transform(transform);    
+    cms_return_transform(transform);
 
     gimage_set_cms_profile(image, new_profile);
 
@@ -510,8 +533,8 @@ static void palette_entries_callback(GtkWidget *w, gpointer client_data);
 /*  the action area structure  */
 static ActionAreaItem action_items[] =
 {
-  { "OK", indexed_ok_callback, NULL, NULL },
-  { "Cancel", indexed_cancel_callback, NULL, NULL }
+  { _("OK"), indexed_ok_callback, NULL, NULL },
+  { _("Cancel"), indexed_cancel_callback, NULL, NULL }
 };
 
 
@@ -551,7 +574,7 @@ convert_to_indexed (void *gimage_ptr)
       dialog->num_cols = 255;
       if (!shown_message_already)
 	{
-	  g_message ("Note:  You are attempting to convert an image\nwith alpha/layers.  It is recommended that you quantize\nto no more than 255 colors if you wish to make\na transparent or animated GIF from it.\n\nYou won't get this message again\nuntil the next time you run GIMP.\nHave a nice day!");
+	  g_message (_("Note:  You are attempting to convert an image\nwith alpha/layers.  It is recommended that you quantize\nto no more than 255 colors if you wish to make\na transparent or animated GIF from it.\n\nYou won't get this message again\nuntil the next time you run GIMP.\nHave a nice day!"));
 	  shown_message_already = True;
 	}
     }
@@ -562,13 +585,13 @@ convert_to_indexed (void *gimage_ptr)
   dialog->reusepal_flag = FALSE;
   dialog->shell = gtk_dialog_new ();
   gtk_window_set_wmclass (GTK_WINDOW (dialog->shell), "indexed_color_conversion", PROGRAM_NAME);
-  gtk_window_set_title (GTK_WINDOW (dialog->shell), "Indexed Color Conversion");
+  gtk_window_set_title (GTK_WINDOW (dialog->shell), _("Indexed Color Conversion"));
   gtk_signal_connect (GTK_OBJECT (dialog->shell), "delete_event",
 		      GTK_SIGNAL_FUNC (indexed_delete_callback),
 		      dialog);
   minimize_register(dialog_shell);
 
-  frame = gtk_frame_new ("Palette Options");
+  frame = gtk_frame_new (_("Palette Options"));
   gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
   gtk_container_border_width (GTK_CONTAINER (frame), 2);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog->shell)->vbox), frame, TRUE, TRUE, 0);
@@ -585,7 +608,7 @@ convert_to_indexed (void *gimage_ptr)
   gtk_container_border_width (GTK_CONTAINER (vbox), 2);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-  toggle = gtk_radio_button_new_with_label (group, "Generate optimal palette: ");
+  toggle = gtk_radio_button_new_with_label (group, _("Generate optimal palette: "));
   group = gtk_radio_button_group (GTK_RADIO_BUTTON (toggle));
   gtk_box_pack_start (GTK_BOX (hbox), toggle, TRUE, TRUE, 0);
   gtk_signal_connect (GTK_OBJECT (toggle), "toggled",
@@ -593,7 +616,7 @@ convert_to_indexed (void *gimage_ptr)
 		      &(dialog->makepal_flag));
   gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (toggle), dialog->makepal_flag);
   gtk_widget_show (toggle);
-  label = gtk_label_new ("# of colors: ");
+  label = gtk_label_new (_("# of colors: "));
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, FALSE, 0);
   gtk_widget_show (label);
@@ -627,7 +650,7 @@ convert_to_indexed (void *gimage_ptr)
       hbox = gtk_hbox_new (FALSE, 1);
       gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
       toggle =
-	gtk_radio_button_new_with_label (group, "Use WWW-optimised palette");
+	gtk_radio_button_new_with_label (group, _("Use WWW-optimised palette"));
       group = gtk_radio_button_group (GTK_RADIO_BUTTON (toggle));
       gtk_box_pack_start (GTK_BOX (hbox), toggle, TRUE, TRUE, 0);
       gtk_signal_connect (GTK_OBJECT (toggle), "toggled",
@@ -642,7 +665,7 @@ convert_to_indexed (void *gimage_ptr)
           /* 'custom' palette from dialog */
           hbox = gtk_hbox_new (FALSE, 1);
           gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
-          toggle = gtk_radio_button_new_with_label (group, "Use custom palette");
+          toggle = gtk_radio_button_new_with_label (group, _("Use custom palette"));
           group = gtk_radio_button_group (GTK_RADIO_BUTTON (toggle));
           gtk_box_pack_start (GTK_BOX (hbox), toggle, TRUE, TRUE, 0);
           gtk_signal_connect (GTK_OBJECT (toggle), "toggled",
@@ -666,7 +689,7 @@ convert_to_indexed (void *gimage_ptr)
   hbox = gtk_hbox_new (FALSE, 1);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
   toggle =
-    gtk_radio_button_new_with_label (group, "Use black/white (1-bit) palette");
+    gtk_radio_button_new_with_label (group, _("Use black/white (1-bit) palette"));
   group = gtk_radio_button_group (GTK_RADIO_BUTTON (toggle));
   gtk_box_pack_start (GTK_BOX (hbox), toggle, TRUE, TRUE, 0);
   gtk_signal_connect (GTK_OBJECT (toggle), "toggled",
@@ -676,7 +699,7 @@ convert_to_indexed (void *gimage_ptr)
   gtk_widget_show (toggle);
   gtk_widget_show (hbox);
 
-  frame = gtk_frame_new ("Dither Options");
+  frame = gtk_frame_new (_("Dither Options"));
   gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
   gtk_container_border_width (GTK_CONTAINER (frame), 2);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog->shell)->vbox), frame, TRUE, TRUE, 0);
@@ -690,7 +713,7 @@ convert_to_indexed (void *gimage_ptr)
   hbox = gtk_hbox_new (FALSE, 1);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-  toggle = gtk_check_button_new_with_label ("Enable Floyd-Steinberg dithering");
+  toggle = gtk_check_button_new_with_label (_("Enable Floyd-Steinberg dithering"));
   gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (toggle), dialog->dither);
   gtk_box_pack_start (GTK_BOX (hbox), toggle, TRUE, FALSE, 0);
   gtk_signal_connect (GTK_OBJECT (toggle), "toggled",
@@ -2714,7 +2737,7 @@ ProcArg convert_rgb_args[] =
 {
   { PDB_IMAGE,
     "image",
-    "the image"
+    "The Image"
   }
 };
 
@@ -2772,7 +2795,7 @@ ProcArg convert_grayscale_args[] =
 {
   { PDB_IMAGE,
     "image",
-    "the image"
+    "The Image"
   }
 };
 
@@ -2830,7 +2853,7 @@ ProcArg convert_indexed_args[] =
 {
   { PDB_IMAGE,
     "image",
-    "the image"
+    "The Image"
   },
   { PDB_INT32,
     "dither",
@@ -2906,7 +2929,7 @@ ProcArg convert_indexed_palette_args[] =
 {
   { PDB_IMAGE,
     "image",
-    "the image"
+    "The Image"
   },
   { PDB_INT32,
     "dither",
