@@ -17,6 +17,7 @@
  */
 #include <stdlib.h>
 #include <stdio.h>
+#include "libgimp/gimpintl.h"
 #include "gdk/gdkkeysyms.h"
 #include "appenv.h"
 #include "actionarea.h"
@@ -508,7 +509,7 @@ tools_new_crop ()
   Crop * private;
 
   if (! crop_options)
-    crop_options = tools_register_no_options (CROP, "Crop Tool Options");
+    crop_options = tools_register_no_options (CROP, _("Crop Tool Options"));
 
   tool = (Tool *) g_malloc_zero (sizeof (Tool));
   private = (Crop *) g_malloc_zero (sizeof (Crop));
@@ -700,16 +701,21 @@ static ActionAreaItem action_items[3] =
 static void
 crop_info_create (Tool *tool)
 {
+  { int i;
+    for(i = 0; i < 3; ++i)
+      action_items[i].label = _(action_items[i].label);
+  }
+
   /*  create the info dialog  */
-  crop_info = info_dialog_new ("Crop Information",
+  crop_info = info_dialog_new (_("Crop Information"),
 					    gimp_standard_help_func,
-					    "UNKNOWN");
+					    _("UNKNOWN"));
 
   /*  add the information fields  */
-  info_dialog_add_field (crop_info, "X Origin: ", orig_x_buf);
-  info_dialog_add_field (crop_info, "Y Origin: ", orig_y_buf);
-  info_dialog_add_field (crop_info, "Width: ", width_buf);
-  info_dialog_add_field (crop_info, "Height: ", height_buf);
+  info_dialog_add_field (crop_info, _("X Origin: "), orig_x_buf);
+  info_dialog_add_field (crop_info, _("Y Origin: "), orig_y_buf);
+  info_dialog_add_field (crop_info, _("Width: "), width_buf);
+  info_dialog_add_field (crop_info, _("Height: "), height_buf);
 
   /* Create the action area  */
   build_action_area (GTK_DIALOG (crop_info->shell), action_items, 3, 0);
@@ -815,7 +821,7 @@ ProcArg crop_args[] =
 {
   { PDB_IMAGE,
     "image",
-    "the image"
+    "The Image"
   },
   { PDB_INT32,
     "new_width",
