@@ -33,6 +33,7 @@
 #include "../pixelarea.h"
 #include "../pixelrow.h"
 #include "../pixel_region.h"
+#include "libgimp/gimpintl.h"
 
 #define BEZIER_START     1
 #define BEZIER_ADD       2
@@ -347,7 +348,7 @@ bezier_select_button_press (Tool           *tool,
       break;
     case BEZIER_EDIT:
       if (!bezier_sel->closed)
-	fatal_error ("tried to edit on open bezier curve");
+	fatal_error (_("tried to edit on open bezier curve"));
 
       /* erase the handles */
       bezier_sel->draw = BEZIER_DRAW_HANDLES;
@@ -555,7 +556,7 @@ bezier_select_motion (Tool           *tool,
 	    }
 
 	  if (!anchor)
-	    fatal_error ("Encountered orphaned bezier control point");
+	    fatal_error (_("Encountered orphaned bezier control point"));
 
 	  if (opposite_control)
 	    {
@@ -904,7 +905,7 @@ bezier_draw_segment (BezierSelect     *bezier_sel,
   for (i = 0; i < 4; i++)
     {
       if (!points)
-	fatal_error ("bad bezier segment");
+	fatal_error (_("bad bezier segment"));
 
       switch (space)
 	{
@@ -921,7 +922,7 @@ bezier_draw_segment (BezierSelect     *bezier_sel,
 	  geometry[i][1] = points->sy;
 	  break;
 	default:
-	  fatal_error ("unknown coordinate space: %d", space);
+	  fatal_error (_("unknown coordinate space: %d"), space);
 	  break;
 	}
 
@@ -1058,7 +1059,7 @@ bezier_convert (BezierSelect *bezier_sel,
   int i;
 
   if (!bezier_sel->closed)
-    fatal_error ("tried to convert an open bezier curve");
+    fatal_error (_("tried to convert an open bezier curve"));
 
   /* destroy previous mask */
   if (bezier_sel->mask)
@@ -1345,7 +1346,7 @@ bezier_convert_helper_u8 (
           x = (long) list->data;
           list = list->next;
           if (!list)
-	    g_message ("cannot properly scanline convert bezier curve: %d", i);
+	    g_message (_("cannot properly scanline convert bezier curve: %d"), i);
           else
             {
 	      /*  bounds checking  */
@@ -1444,7 +1445,7 @@ bezier_convert_helper_u16 (
           x = (long) list->data;
           list = list->next;
           if (!list)
-	    g_message ("cannot properly scanline convert bezier curve: %d", i);
+	    g_message (_("cannot properly scanline convert bezier curve: %d"), i);
           else
             {
 	      /*  bounds checking  */
@@ -1541,7 +1542,7 @@ bezier_convert_helper_float  (
           x = (long) list->data;
           list = list->next;
           if (!list)
-	    g_message ("cannot properly scanline convert bezier curve: %d", i);
+	    g_message (_("cannot properly scanline convert bezier curve: %d"), i);
           else
             {
 	      /*  bounds checking  */
@@ -1642,7 +1643,7 @@ bezier_convert_helper_float16  (
           x = (long) list->data;
           list = list->next;
           if (!list)
-	    g_message ("cannot properly scanline convert bezier curve: %d", i);
+	    g_message (_("cannot properly scanline convert bezier curve: %d"), i);
           else
             {
 	      /*  bounds checking  */
@@ -1740,7 +1741,7 @@ bezier_convert_helper_bfp (
           x = (long) list->data;
           list = list->next;
           if (!list)
-	    g_message ("cannot properly scanline convert bezier curve: %d", i);
+	    g_message (_("cannot properly scanline convert bezier curve: %d"), i);
           else
             {
 	      /*  bounds checking  */
@@ -1832,7 +1833,7 @@ bezier_convert_helper (
                                    height);
       break;
     case PRECISION_NONE:
-      g_warning ("bezier_convert_helper bad precision");
+      g_warning (_("bezier_convert_helper bad precision"));
       break;
     }
 }
