@@ -19,6 +19,7 @@
 #include <string.h>
 #include <math.h>
 #include "../lib/version.h"
+#include "libgimp/gimpintl.h"
 #include "../appenv.h"
 #include "../actionarea.h"
 #include "../brightness_contrast.h"
@@ -671,7 +672,7 @@ tools_new_brightness_contrast ()
   /*  The tool options  */
   if (!brightness_contrast_options)
     brightness_contrast_options = tools_register_no_options (BRIGHTNESS_CONTRAST,
-							     "Brightness-Contrast Options");
+							     _("Brightness-Contrast Options"));
 
   tool = (Tool *) g_malloc_zero (sizeof (Tool));
   private = (BrightnessContrast *) g_malloc_zero (sizeof (BrightnessContrast));
@@ -718,7 +719,7 @@ brightness_contrast_initialize (void *gdisp_ptr)
 
   if (drawable_indexed (gimage_active_drawable (gdisp->gimage)))
     {
-      g_message ("Brightness-Contrast does not operate on indexed drawables.");
+      g_message (_("Brightness-Contrast does not operate on indexed drawables."));
       return;
     }
 
@@ -779,7 +780,7 @@ brightness_contrast_new_dialog ()
   /*  The shell and main vbox  */
   bcd->shell = gtk_dialog_new ();
   gtk_window_set_wmclass (GTK_WINDOW (bcd->shell), "brightness_contrast", PROGRAM_NAME);
-  gtk_window_set_title (GTK_WINDOW (bcd->shell), "Brightness-Contrast");
+  gtk_window_set_title (GTK_WINDOW (bcd->shell), _("Brightness-Contrast"));
   minimize_register(bcd->shell);
   
   /* handle wm close signal */
@@ -796,7 +797,7 @@ brightness_contrast_new_dialog ()
   gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, FALSE, 0);
 
   /*  Create the brightness scale widget  */
-  label = gtk_label_new ("Brightness");
+  label = gtk_label_new (_("Brightness"));
   gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 2, 2);
@@ -830,7 +831,7 @@ brightness_contrast_new_dialog ()
 
 
   /*  Create the contrast scale widget  */
-  label = gtk_label_new ("Contrast");
+  label = gtk_label_new (_("Contrast"));
   gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 2, 2);
@@ -868,7 +869,7 @@ brightness_contrast_new_dialog ()
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
   /*  The preview toggle  */
-  toggle = gtk_check_button_new_with_label ("Preview");
+  toggle = gtk_check_button_new_with_label (_("Preview"));
   gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (toggle), bcd->preview);
   gtk_box_pack_start (GTK_BOX (hbox), toggle, TRUE, FALSE, 0);
   gtk_signal_connect (GTK_OBJECT (toggle), "toggled",
@@ -881,6 +882,8 @@ brightness_contrast_new_dialog ()
 
 
   /*  The action area  */
+  action_items[0].label = _(action_items[0].label);
+  action_items[1].label = _(action_items[1].label);
   action_items[0].user_data = bcd;
   action_items[1].user_data = bcd;
   build_action_area (GTK_DIALOG (bcd->shell), action_items, 2, 0);
@@ -924,7 +927,7 @@ static void
 brightness_contrast_preview (BrightnessContrastDialog *bcd)
 {
   if (!bcd->image_map)
-    g_message ("brightness_contrast_preview(): No image map");
+    g_message (_("brightness_contrast_preview(): No image map"));
   active_tool->preserve = TRUE;
   (*brightness_contrast_init_transfers) ((void *)bcd); 
   image_map_apply (bcd->image_map, brightness_contrast, (void *) bcd);
@@ -1124,11 +1127,11 @@ ProcArg brightness_contrast_args[] =
 {
   { PDB_IMAGE,
     "image",
-    "the image"
+    "The Image"
   },
   { PDB_DRAWABLE,
     "drawable",
-    "the drawable"
+    "The Drawable"
   },
   { PDB_INT32,
     "brightness",
