@@ -20,6 +20,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include "../lib/version.h"
+#include "libgimp/gimpintl.h"
 #include "../appenv.h"
 #include "../actionarea.h"
 #include "../brushlist.h"
@@ -162,7 +163,9 @@ create_paint_mode_menu (MenuItemCallback callback, gpointer udata)
   int i;
 
   for (i = 0; i <= VALUE_MODE; i++)
-    option_items[i].callback = callback;
+  { option_items[i].callback = callback;
+    option_items[i].label = _(option_items[i].label);
+  }
 
   menu = build_menu (option_items, NULL);
 
@@ -245,7 +248,7 @@ brush_select_new (gchar * title,
 
   if(!title)
     {
-      gtk_window_set_title (GTK_WINDOW (bsp->shell), "Brush Selection");
+      gtk_window_set_title (GTK_WINDOW (bsp->shell), _("Brush Selection"));
     }
   else
     {
@@ -314,9 +317,9 @@ brush_select_new (gchar * title,
   util_box = gtk_hbox_new (FALSE, 5);
   gtk_box_pack_start (GTK_BOX (bsp->options_box), util_box, FALSE, FALSE, 0);
 
-  bsp->brush_name = gtk_label_new ("Active");
+  bsp->brush_name = gtk_label_new (_("Active"));
   gtk_box_pack_start (GTK_BOX (util_box), bsp->brush_name, FALSE, FALSE, 2);
-  bsp->brush_size = gtk_label_new ("(0x0)");
+  bsp->brush_size = gtk_label_new (_("(0x0)"));
   gtk_box_pack_start (GTK_BOX (util_box), bsp->brush_size, FALSE, FALSE, 2);
 
   gtk_widget_show (bsp->brush_name);
@@ -326,7 +329,7 @@ brush_select_new (gchar * title,
   /*  Create the paint mode option menu  */
   util_box = gtk_hbox_new (FALSE, 2);
   gtk_box_pack_start (GTK_BOX (bsp->options_box), util_box, FALSE, FALSE, 0);
-  label = gtk_label_new ("Mode:");
+  label = gtk_label_new (_("Mode:"));
   gtk_box_pack_start (GTK_BOX (util_box), label, FALSE, FALSE, 2);
   menu = create_paint_mode_menu (paint_mode_menu_callback, (gpointer)bsp);
   bsp->option_menu =
@@ -341,7 +344,7 @@ brush_select_new (gchar * title,
   /*  Create the opacity scale widget  */
   util_box = gtk_hbox_new (FALSE, 2);
   gtk_box_pack_start (GTK_BOX (bsp->options_box), util_box, FALSE, FALSE, 0);
-  label = gtk_label_new ("Opacity:");
+  label = gtk_label_new (_("Opacity:"));
   gtk_box_pack_start (GTK_BOX (util_box), label, FALSE, FALSE, 2);
   bsp->opacity_data = 
     GTK_ADJUSTMENT (gtk_adjustment_new ((active)?(init_opacity*100.0):100.0, 0.0, 100.0, 1.0, 1.0, 0.0));
@@ -358,7 +361,7 @@ brush_select_new (gchar * title,
 
   util_box = gtk_hbox_new (FALSE, 2);
   gtk_box_pack_start (GTK_BOX (bsp->options_box), util_box, FALSE, FALSE, 0);
-  label = gtk_label_new ("Spacing:");
+  label = gtk_label_new (_("Spacing:"));
   gtk_box_pack_start (GTK_BOX (util_box), label, FALSE, FALSE, 2);
   bsp->spacing_data = GTK_ADJUSTMENT (gtk_adjustment_new (0.0, 1.0, 1000.0, 1.0, 1.0, 0.0));
   slider = gtk_hscale_new (bsp->spacing_data);
@@ -373,7 +376,7 @@ brush_select_new (gchar * title,
   gtk_widget_show (util_box);
 
   /* The noise toggle */
-  noise_button = gtk_check_button_new_with_label ("Noise");                                          
+  noise_button = gtk_check_button_new_with_label (_("Noise"));                                          
   gtk_box_pack_start (GTK_BOX (bsp->options_box), noise_button, FALSE, FALSE, 0);                                  
   gtk_signal_connect (GTK_OBJECT(noise_button), "toggled",                                             
 			GTK_SIGNAL_FUNC(button_toggled), bsp);                                  
@@ -386,7 +389,7 @@ brush_select_new (gchar * title,
   /* noise freq slider */
   util_box = gtk_hbox_new (FALSE, 2);
   gtk_box_pack_start (GTK_BOX (bsp->noise_options_box), util_box, FALSE, FALSE, 0);
-  label = gtk_label_new ("Noise Freq:");
+  label = gtk_label_new (_("Noise Freq:"));
   gtk_box_pack_start (GTK_BOX (util_box), label, FALSE, FALSE, 2);
 #if 0
   bsp->noise_freq_data = 
@@ -408,7 +411,7 @@ brush_select_new (gchar * title,
   /* noise step start slider */
   util_box = gtk_hbox_new (FALSE, 2);
   gtk_box_pack_start (GTK_BOX (bsp->noise_options_box), util_box, FALSE, FALSE, 0);
-  label = gtk_label_new ("Strength:");
+  label = gtk_label_new (_("Strength:"));
   gtk_box_pack_start (GTK_BOX (util_box), label, FALSE, FALSE, 2);
   bsp->noise_step_start_data = 
     GTK_ADJUSTMENT (gtk_adjustment_new (init_noise_step_start, 0.0, 1.01, .001, .01, .01));
@@ -428,7 +431,7 @@ brush_select_new (gchar * title,
   /* noise step width slider */
   util_box = gtk_hbox_new (FALSE, 2);
   gtk_box_pack_start (GTK_BOX (bsp->noise_options_box), util_box, FALSE, FALSE, 0);
-  label = gtk_label_new ("Sharpness:");
+  label = gtk_label_new (_("Sharpness:"));
   gtk_box_pack_start (GTK_BOX (util_box), label, FALSE, FALSE, 2);
   bsp->noise_step_width_data = 
     GTK_ADJUSTMENT (gtk_adjustment_new (init_noise_step_width, 0.0, 1.01, .001, .01, .01));
@@ -448,7 +451,7 @@ brush_select_new (gchar * title,
   /*  Create the edit/new buttons  */
   util_box = gtk_hbox_new (FALSE, 2);
   gtk_box_pack_start (GTK_BOX (bsp->options_box), util_box, FALSE, FALSE, 0);
-  bsp->edit_button =  gtk_button_new_with_label ("Edit Brush");
+  bsp->edit_button =  gtk_button_new_with_label (_("Edit Brush"));
   gtk_signal_connect (GTK_OBJECT (bsp->edit_button), "clicked",
 		      (GtkSignalFunc) edit_brush_callback,
 		      NULL);
@@ -457,7 +460,7 @@ brush_select_new (gchar * title,
 
   gtk_box_pack_start (GTK_BOX (util_box), bsp->edit_button, TRUE, TRUE, 5);
 
-  button2 =  gtk_button_new_with_label ("New Brush");
+  button2 =  gtk_button_new_with_label (_("New Brush"));
   gtk_signal_connect (GTK_OBJECT (button2), "clicked",
 		      (GtkSignalFunc) new_brush_callback,
 		      NULL);
@@ -474,6 +477,10 @@ brush_select_new (gchar * title,
     }
 
   /*  The action area  */
+  { int i;
+    for(i = 0; i < 2; ++i)
+      action_items[i].label = _(action_items[i].label);
+  }
   action_items[0].user_data = bsp;
   action_items[1].user_data = bsp;
   build_action_area (GTK_DIALOG (bsp->shell), action_items, 2, 0);
@@ -630,7 +637,7 @@ brush_change_callbacks(BrushSelectP bsp, gint closing)
 					    PDB_END);
  
       if (!return_vals || return_vals[0].value.pdb_int != PDB_SUCCESS)
-	g_message ("failed to run brush callback function");
+	g_message (_("failed to run brush callback function"));
       
       procedural_db_destroy_args (return_vals, nreturn_vals);
     }
@@ -860,7 +867,7 @@ display_brush_get_row_funcs (Tag t)
       return display_brush_get_row_bfp;
     case PRECISION_NONE:
     default:
-      g_warning ("display_brush_get_row_funcs: bad precision");
+      g_warning (_("display_brush_get_row_funcs: bad precision"));
     }
   return NULL;
 }
@@ -1364,7 +1371,7 @@ edit_brush_callback (GtkWidget *w, GdkEvent *e, gpointer data)
     }
   }
   else
-    g_message("Active brush is not generated\n");
+    g_message(_("Active brush is not generated\n"));
   return TRUE;
 }
 
