@@ -25,6 +25,7 @@
 #include <math.h>
 #include <stdio.h>
 #include <string.h>
+#include "libgimp/gimpintl.h"
 
 #ifdef WIN32
 #include "extra.h"
@@ -130,7 +131,7 @@ GimpBrushGenerated *gimp_brush_generated_new(float radius, float hardness,
 /* set up normal brush data */
   brush = GIMP_BRUSH_GENERATED(gimp_type_new(gimp_brush_generated_get_type ()));
 
-  GIMP_BRUSH(brush)->name = g_strdup ("Untitled");
+  GIMP_BRUSH(brush)->name = g_strdup (_("Untitled"));
   GIMP_BRUSH(brush)->spacing = 20;
 
 /* set up gimp_brush_generated data */
@@ -194,7 +195,7 @@ gimp_brush_generated_load (const char *file_name)
 #if 1 
   {
     char * basename = strrchr (file_name, '/' );
-    if (basename) 
+    if (basename && default_brush) 
       {
 	basename++; 
 	if (strcmp(default_brush, basename) == 0) 
@@ -382,7 +383,13 @@ gimp_brush_generated_generate(GimpBrushGenerated *brush)
 
   
   tag = tag_new ( default_precision, FORMAT_GRAY, ALPHA_NO ); 
-  (*gimp_brush_generated_compute_funcs(tag))(brush, width, height, lookup);
+  { /* use the PRECISION_FLOAT16 variant only */
+    int w = 0;
+    if (w)
+      (*gimp_brush_generated_compute_funcs(tag))(brush, width, height, lookup);
+    else
+      gimp_brush_generated_compute_float16 (brush, width, height, lookup);
+  }
 
   g_free (lookup);
   gtk_signal_emit_by_name(GTK_OBJECT(brush), "dirty");
@@ -430,7 +437,7 @@ gimp_brush_generated_compute_float16(
   guint16 val;
   gint w = width;
   gint h = height;
-  Tag tag = tag_new ( default_precision, FORMAT_GRAY, ALPHA_NO ); 
+  Tag tag = tag_new ( PRECISION_FLOAT16, FORMAT_GRAY, ALPHA_NO ); 
   ShortsFloat u;
 
   /* make the canvas */
@@ -482,7 +489,7 @@ gimp_brush_generated_compute_float(
   gfloat *data;
   gint w = width;
   gint h = height;
-  Tag tag = tag_new ( default_precision, FORMAT_GRAY, ALPHA_NO ); 
+  Tag tag = tag_new ( PRECISION_FLOAT, FORMAT_GRAY, ALPHA_NO ); 
 
   /* make the canvas */
   gbrush->mask = canvas_new( tag, width*2 + 1, height*2 + 1, STORAGE_FLAT);
@@ -532,7 +539,7 @@ gimp_brush_generated_compute_u16(
   guint16 *data;
   gint w = width;
   gint h = height;
-  Tag tag = tag_new ( default_precision, FORMAT_GRAY, ALPHA_NO ); 
+  Tag tag = tag_new ( PRECISION_U16, FORMAT_GRAY, ALPHA_NO ); 
 
   /* make the canvas */
   gbrush->mask = canvas_new( tag, width*2 + 1, height*2 + 1, STORAGE_FLAT);
@@ -582,7 +589,7 @@ gimp_brush_generated_compute_u8(
   guint8 *data;
   gint w = width;
   gint h = height;
-  Tag tag = tag_new ( default_precision, FORMAT_GRAY, ALPHA_NO ); 
+  Tag tag = tag_new ( PRECISION_U8, FORMAT_GRAY, ALPHA_NO ); 
 
   /* make the canvas */
   gbrush->mask = canvas_new( tag, width*2 + 1, height*2 + 1, STORAGE_FLAT);
@@ -632,7 +639,7 @@ gimp_brush_generated_compute_bfp(
   guint16 *data;
   gint w = width;
   gint h = height;
-  Tag tag = tag_new ( default_precision, FORMAT_GRAY, ALPHA_NO ); 
+  Tag tag = tag_new ( PRECISION_BFP, FORMAT_GRAY, ALPHA_NO ); 
 
   /* make the canvas */
   gbrush->mask = canvas_new( tag, width*2 + 1, height*2 + 1, STORAGE_FLAT);
