@@ -20,6 +20,7 @@
 #include <string.h>
 #include <sys/types.h>
 #include <math.h>
+#include "libgimp/gimpintl.h"
 #include "../appenv.h"
 #include "../canvas.h"
 #include "../channel.h"
@@ -192,7 +193,7 @@ channel_copy (Channel *channel)
   
   /*  formulate the new channel name  */
   channel_name = (char *) g_malloc (strlen (GIMP_DRAWABLE(channel)->name) + 6);
-  sprintf (channel_name, "%s copy", GIMP_DRAWABLE(channel)->name);
+  sprintf (channel_name, _("%s copy"), GIMP_DRAWABLE(channel)->name);
 
   /*  allocate a new channel object  */
   new_channel = channel_new (GIMP_DRAWABLE(channel)->gimage_ID, 
@@ -580,7 +581,7 @@ channel_new_mask (int gimage_ID, int width, int height, Precision p)
   
   /*  Create the new channel  */
   new_channel = channel_new (gimage_ID, width, height, p,
-                             "Selection Mask", 0.5, &black);
+                             _("Selection Mask"), 0.5, &black);
 
   /*  Set the validate procedure  */
  canvas_portion_init_setup (GIMP_DRAWABLE(new_channel)->tiles,
@@ -717,7 +718,7 @@ channel_value (Channel *mask, int x, int y)
 
 	default:
     case PRECISION_NONE:
-      g_warning ("bad precision");
+      g_warning (_("bad precision"));
       break;
     }
       
@@ -880,7 +881,7 @@ channel_bounds (Channel *mask, int *x1, int *y1, int *x2, int *y2)
 		  break;
 
 		default:
-		  g_warning ("channel_bounds: bad precision");
+		  g_warning (_("channel_bounds: bad precision"));
 		  break;
 		}
 	      data += rowstride;
@@ -1015,7 +1016,7 @@ channel_is_empty (Channel *mask)
 	}
 	break;
       default:
-	g_warning ("channel_is_empty: bad precision");
+	g_warning (_("channel_is_empty: bad precision"));
 	break;
       } 
     }
@@ -1180,7 +1181,7 @@ channel_add_segment (Channel *mask, int x, int y, int width, gfloat value)
       break;
 
     default:
-      g_warning ("channel_add_segment: bad precision");
+      g_warning (_("channel_add_segment: bad precision"));
       break;
     }
 }
@@ -1324,7 +1325,7 @@ channel_sub_segment (Channel *mask, int x, int y, int width, gfloat value)
       break;
 
     case PRECISION_NONE:
-      g_warning ("channel_sub_segment: bad precision");
+      g_warning (_("channel_sub_segment: bad precision"));
       break;
     }
 }
@@ -1458,7 +1459,7 @@ channel_inter_segment (Channel *mask, int x, int y, int width, gfloat value)
       break;
 
     case PRECISION_NONE:
-      g_warning ("channel_inter_segment: bad precision");
+      g_warning (_("channel_inter_segment: bad precision"));
       break;
     }
 }
@@ -1941,7 +1942,7 @@ channel_sharpen (Channel *mask)
 	  break;
 	
 	case PRECISION_NONE:
-	  g_warning ("bad precision");
+	  g_warning (_("bad precision"));
 	  break;
 	}
     }
