@@ -18,6 +18,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include "../lib/version.h"
+#include "libgimp/gimpintl.h"
 #include "../appenv.h"
 #include "../actionarea.h"
 #include "../color_select.h"
@@ -195,7 +196,7 @@ color_select_new (PixelRow           * col,
 
   csp->shell = gtk_dialog_new ();
   gtk_window_set_wmclass (GTK_WINDOW (csp->shell), "color_selection", PROGRAM_NAME);
-  gtk_window_set_title (GTK_WINDOW (csp->shell), "Color Selection");
+  gtk_window_set_title (GTK_WINDOW (csp->shell), _("Color Selection"));
   gtk_window_set_policy (GTK_WINDOW (csp->shell), FALSE, FALSE, FALSE);
   gtk_widget_set_uposition (csp->shell, color_select_x, color_select_y);
   layout_connect_window_position(csp->shell, &color_select_x, &color_select_y, TRUE);
@@ -297,6 +298,7 @@ color_select_new (PixelRow           * col,
   group = NULL;
   for (i = 0; i < 6; i++)
     {
+      toggle_titles[i] = _(toggle_titles[i]);
       csp->toggles[i] = gtk_radio_button_new_with_label (group, toggle_titles[i]);
       group = gtk_radio_button_group (GTK_RADIO_BUTTON (csp->toggles[i]));
       gtk_table_attach (GTK_TABLE (table), csp->toggles[i],
@@ -341,13 +343,13 @@ color_select_new (PixelRow           * col,
   action_items[1].user_data = csp;
   if (csp->wants_updates)
     {
-      action_items[0].label = "Close";
-      action_items[1].label = "Revert to Old Color";
+      action_items[0].label = _("Close");
+      action_items[1].label = _("Revert to Old Color");
     }
   else
     {
-      action_items[0].label = "OK";
-      action_items[1].label = "Cancel";
+      action_items[0].label = _("OK");
+      action_items[1].label = _("Cancel");
     }
   build_action_area (GTK_DIALOG (csp->shell), action_items, 2, 0);
 
@@ -818,14 +820,14 @@ color_select_update_colors (ColorSelectP csp,
       if (which)
 	{
 	  window = csp->orig_color->window;
-	  color.pixel = old_color_pixel;
+          cp_pixel_to_gdkcolor(&color, &old_color_pixel);
           pixelrow_init (&col, tag_new (PRECISION_FLOAT, FORMAT_RGB, ALPHA_NO),
                          (guchar *) csp->orig_values, 1);
 	}
       else
 	{
 	  window = csp->new_color->window;
-	  color.pixel = new_color_pixel;
+          cp_pixel_to_gdkcolor(&color, &new_color_pixel);
           pixelrow_init (&col, tag_new (PRECISION_FLOAT, FORMAT_RGB, ALPHA_NO),
                          (guchar *) &csp->values[3], 1);
 	}
@@ -833,6 +835,7 @@ color_select_update_colors (ColorSelectP csp,
       gdk_window_get_size (window, &width, &height);
 
       store_display_color (&color.pixel, &col);
+      cp_pixel_to_gdkcolor(&color, &color.pixel);
 
       if (csp->gc)
 	{
