@@ -41,6 +41,10 @@ display_u8_init(void)
       {
       }
       break;
+    case PRECISION_BFP:
+      {
+      }
+      break;
     case PRECISION_FLOAT16:
       {
         char *filmVar;
@@ -71,7 +75,9 @@ display_u8_init(void)
 	
 guint8 
 display_u8_alpha_from_float(gfloat code)
-{
+{	
+	code=CLAMP(code,0.0,1.0);
+
     switch ( default_precision )
     {
     case PRECISION_U8:
@@ -90,6 +96,10 @@ display_u8_alpha_from_float(gfloat code)
       {
 	return (guint8)(code * 255.0); 
       }
+    case PRECISION_BFP:
+      {
+	return (guint8)(code * 255.0); 
+      }
     case PRECISION_NONE:
     default:
       g_warning("display_u8_alpha_from_float: bad precision\n"); 
@@ -100,6 +110,8 @@ display_u8_alpha_from_float(gfloat code)
 guint8 
 display_u8_from_float(gfloat code)
 {
+	code=CLAMP(code,0.0,1.0);
+	
     switch ( default_precision )
     {
     case PRECISION_U8:
@@ -147,6 +159,10 @@ display_u8_from_float(gfloat code)
             return( IM_Gamma22Lookup[c - IM_GAMMA22LOOKUP_START] );
 	}
       }
+    case PRECISION_BFP:
+      {
+	return (guint8)(code * 255.0); 
+      }
     case PRECISION_NONE:
     default:
       g_warning("display_u8_from_float: bad precision\n"); 
