@@ -19,6 +19,7 @@
 #include <string.h>
 #include <math.h>
 #include "../lib/version.h"
+#include "libgimp/gimpintl.h"
 #include "../appenv.h"
 #include "../actionarea.h"
 #include "../gamma_expose.h"
@@ -756,10 +757,14 @@ gamma_expose_new_dialog (GammaExposeDialog * bcd)
   GtkWidget *forceexpose;
   GtkObject *data;
 
+  { int i = 0;
+    for (;i<2;++i)
+      action_items[i].label = _(action_items[i].label);
+  }
   /*  The shell and main vbox  */
   bcd->shell = gtk_dialog_new ();
   gtk_window_set_wmclass (GTK_WINDOW (bcd->shell), "gamma_expose",PROGRAM_NAME);
-  gtk_window_set_title (GTK_WINDOW (bcd->shell), "gamma-expose");
+  gtk_window_set_title (GTK_WINDOW (bcd->shell), _("Expose Image"));
   
   /* handle wm close signal */
   gtk_signal_connect (GTK_OBJECT (bcd->shell), "delete_event",
@@ -775,7 +780,7 @@ gamma_expose_new_dialog (GammaExposeDialog * bcd)
   gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, FALSE, 0);
 
   /*  Create the expose scale widget  */
-  label = gtk_label_new ("expose");
+  label = gtk_label_new (_("expose"));
   gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 2, 2);
@@ -809,7 +814,7 @@ gamma_expose_new_dialog (GammaExposeDialog * bcd)
 
 
   /*  Create the gamma scale widget  */
-  label = gtk_label_new ("gamma");
+  label = gtk_label_new (_("gamma"));
   gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 2, 2);
@@ -847,7 +852,7 @@ gamma_expose_new_dialog (GammaExposeDialog * bcd)
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
   /*  The preview toggle  */
-  toggle = gtk_check_button_new_with_label ("Preview");
+  toggle = gtk_check_button_new_with_label (_("Preview"));
   gtk_box_pack_start (GTK_BOX (hbox), toggle, TRUE, FALSE, 0);
   gtk_signal_connect (GTK_OBJECT (toggle), "toggled",
 		      (GtkSignalFunc) gamma_expose_preview_update,
@@ -859,7 +864,7 @@ gamma_expose_new_dialog (GammaExposeDialog * bcd)
   gtk_widget_show (hbox);
 
   /*  The expose toggle  */
-  forceexpose = gtk_check_button_new_with_label ("Clamp");
+  forceexpose = gtk_check_button_new_with_label (_("Clamp"));
   gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (forceexpose), bcd->forceexpose);
   gtk_box_pack_start (GTK_BOX (hbox), forceexpose, TRUE, FALSE, 0);
   gtk_signal_connect (GTK_OBJECT (forceexpose), "toggled",
