@@ -19,6 +19,7 @@
 #include <string.h>
 #include <math.h>
 #include "../lib/version.h"
+#include "libgimp/gimpintl.h"
 #include "../appenv.h"
 #include "../actionarea.h"
 #include "../canvas.h"
@@ -976,7 +977,7 @@ tools_new_hue_saturation ()
 
   /*  The tool options  */
   if (!hue_saturation_options)
-    hue_saturation_options = tools_register_no_options (HUE_SATURATION,	"Hue-Saturation Options");
+    hue_saturation_options = tools_register_no_options (HUE_SATURATION,	_("Hue-Saturation Options"));
 
   tool = (Tool *) g_malloc_zero (sizeof (Tool));
   private = (HueSaturation *) g_malloc_zero (sizeof (HueSaturation));
@@ -1024,7 +1025,7 @@ hue_saturation_initialize (void *gdisp_ptr)
 
   if (! drawable_color (gimage_active_drawable (gdisp->gimage)))
     {
-      g_message ("Hue-Saturation operates only on RGB color drawables.");
+      g_message (_("Hue-Saturation operates only on RGB color drawables."));
       return;
     }
 
@@ -1094,16 +1095,7 @@ hue_saturation_new_dialog ()
   GtkObject *data;
   GSList *group = NULL;
   int i;
-  char *hue_partition_names[7] =
-  {
-    "Master",
-    "R",
-    "Y",
-    "G",
-    "C",
-    "B",
-    "M"
-  };
+  char *hue_partition_names[7];
   ActionCallback hue_partition_callbacks[7] =
   {
     hue_saturation_master_callback,
@@ -1115,6 +1107,14 @@ hue_saturation_new_dialog ()
     hue_saturation_M_callback
   };
 
+  hue_partition_names[0] = _("Master");
+  hue_partition_names[1] = _("R");
+  hue_partition_names[2] = _("Y");
+  hue_partition_names[3] = _("G");
+  hue_partition_names[4] = _("C");
+  hue_partition_names[5] = _("B");
+  hue_partition_names[6] = _("M");
+
   hsd = g_malloc_zero (sizeof (HueSaturationDialog));
   hsd->hue_partition = 0;
   hsd->preview = TRUE;
@@ -1122,7 +1122,7 @@ hue_saturation_new_dialog ()
   /*  The shell and main vbox  */
   hsd->shell = gtk_dialog_new ();
   gtk_window_set_wmclass (GTK_WINDOW (hsd->shell), "hue_saturation", PROGRAM_NAME);
-  gtk_window_set_title (GTK_WINDOW (hsd->shell), "Hue-Saturation");
+  gtk_window_set_title (GTK_WINDOW (hsd->shell), _("Hue-Saturation"));
   minimize_register(hsd->shell);
 
   /* handle the wm close signal */
@@ -1185,7 +1185,7 @@ hue_saturation_new_dialog ()
   vbox = gtk_vbox_new (FALSE, 2);
   gtk_box_pack_start (GTK_BOX (main_hbox), vbox, FALSE, FALSE, 0);
 
-  label = gtk_label_new ("Hue / Lightness / Saturation Adjustments");
+  label = gtk_label_new (_("Hue / Lightness / Saturation Adjustments"));
   gtk_misc_set_alignment (GTK_MISC (label), 0.5, 0.5);
   gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
@@ -1195,7 +1195,7 @@ hue_saturation_new_dialog ()
   gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, FALSE, 0);
 
   /*  Create the hue scale widget  */
-  label = gtk_label_new ("Hue");
+  label = gtk_label_new (_("Hue"));
   gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 2, 2);
@@ -1229,7 +1229,7 @@ hue_saturation_new_dialog ()
 
 
   /*  Create the lightness scale widget  */
-  label = gtk_label_new ("Lightness");
+  label = gtk_label_new (_("Lightness"));
   gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 2, 2);
@@ -1263,7 +1263,7 @@ hue_saturation_new_dialog ()
 
 
   /*  Create the saturation scale widget  */
-  label = gtk_label_new ("Saturation");
+  label = gtk_label_new (_("Saturation"));
   gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 2, 2);
@@ -1301,7 +1301,7 @@ hue_saturation_new_dialog ()
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
   /*  The preview toggle  */
-  toggle = gtk_check_button_new_with_label ("Preview");
+  toggle = gtk_check_button_new_with_label (_("Preview"));
   gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (toggle), hsd->preview);
   gtk_box_pack_start (GTK_BOX (hbox), toggle, FALSE, FALSE, 0);
   gtk_signal_connect (GTK_OBJECT (toggle), "toggled",
@@ -1313,6 +1313,10 @@ hue_saturation_new_dialog ()
 
 
   /*  The action area  */
+  { int i;
+    for(i = 0; i < 2; ++i)
+      action_items[i].label = _(action_items[i].label);
+  }
   action_items[0].user_data = hsd;
   action_items[1].user_data = hsd;
   build_action_area (GTK_DIALOG (hsd->shell), action_items, 2, 0);
@@ -1403,7 +1407,7 @@ static void
 hue_saturation_preview (HueSaturationDialog *hsd)
 {
   if (!hsd->image_map)
-    g_message ("hue_saturation_preview(): No image map");
+    g_message (_("hue_saturation_preview(): No image map"));
   active_tool->preserve = TRUE;
   image_map_apply (hsd->image_map, hue_saturation, (void *) hsd);
   active_tool->preserve = FALSE;
