@@ -701,11 +701,13 @@ render_image_rgb (RenderInfo *info)
 	memcpy (info->dest, info->dest - info->dest_bpl, info->dest_width);
       else
 	{
+          int i = (xe - info->x) * 3;
 	  src = info->src;
 	  dest = info->dest;
 
 	  g_return_if_fail (src != NULL);
 	  
+# if 0
 	  /* replace this with memcpy, or better yet, avoid it altogether? */
 	  for (x = info->x; x < xe; x++)
 	    {
@@ -716,6 +718,11 @@ render_image_rgb (RenderInfo *info)
 	      src += 3;
 	      dest += 3;	      
 	    }
+# else
+          memcpy(dest, src, i);
+          src += i;
+          dest += i;
+# endif
 	}            
       info->dest += info->dest_bpl;
 
@@ -915,58 +922,17 @@ render_image_init_info (RenderInfo *info,
   if (tag_alpha (canvas_tag (info->src_canvas)) == ALPHA_YES)
     info->alpha = render_image_init_alpha (gimage_projection_opacity (gdisp->gimage));
 
-  /* if colormanaged, get the required transform */
-
-  if (info->gdisp->colormanaged)
-  {   /* combine profiles */
-      GSList *profiles = NULL;
-      CMSProfile *image_profile = gimage_get_cms_profile(info->gdisp->gimage);
-      CMSProfile *proof_profile = NULL;
-      CMSProfile *display_profile = cms_get_display_profile();
-      if (gdisplay_is_proofed(info->gdisp))
-      {
-          proof_profile = gimage_get_cms_proof_profile(info->gdisp->gimage);
-      }
-      if (image_profile == NULL)
-      {   g_warning("gdisplay_project: cannot colourmanage, image has no profile assigned");
-          transform_buffer = NULL;
-      }
-      else if (display_profile == NULL)
-      {   g_warning("gdisplay_project: cannot colourmanage, no display profile set");
-          transform_buffer = NULL;
-      }
-      else
-      {   profiles = g_slist_append(profiles, (gpointer)image_profile);
-          if(info->gdisp->look_profile_pipe)
-              profiles = g_slist_concat(profiles, g_slist_copy(info->gdisp->look_profile_pipe));
-          if (proof_profile)
-              profiles = g_slist_append(profiles, (gpointer)proof_profile);
-          profiles = g_slist_append(profiles, (gpointer)display_profile);
-
-          transform_buffer = cms_get_canvas_transform(profiles,
-                               info->src_canvas,
-	                           info->gdisp->cms_intent, info->gdisp->cms_flags);
-          g_slist_free(profiles);
-      }
-  }
-  /* if we have got look profiles ... */
-  else if (!info->gdisp->colormanaged && (info->gdisp->look_profile_pipe != NULL))
-  {   GSList *profiles = NULL;
-      CMSProfile *image_profile = gimage_get_cms_profile(info->gdisp->gimage);
-      if (image_profile == NULL)
-      {   image_profile = cms_get_srgb_profile();
-      }
-      profiles = g_slist_append(profiles, (gpointer)image_profile);
-      profiles = g_slist_concat(profiles, g_slist_copy(info->gdisp->look_profile_pipe));
-      profiles = g_slist_append(profiles, (gpointer)image_profile);
-      transform_buffer = cms_get_canvas_transform(profiles,
-                               info->src_canvas, 
-	                           info->gdisp->cms_intent, info->gdisp->cms_flags);
-      g_slist_free(profiles);
-  }
-
-  info->transform_buffer = transform_buffer;
-  
+  /* if colormanaged, get the required transform
+   */
+  info->transform_buffer =
+        gimage_get_cms_transform( info->gdisp->gimage,
+                                  info->gdisp->look_profile_pipe,
+                                  gdisplay_is_colormanaged(info->gdisp),
+                                  gdisplay_is_proofed(info->gdisp),
+                                  gdisplay_get_cms_intent(info->gdisp),
+                                  gdisplay_get_cms_flags(info->gdisp),
+                                  gdisplay_get_cms_proof_intent(info->gdisp),
+                                  info->gdisp->cms_expensive_transf );
 }
 
 static guint*
@@ -1179,8 +1145,8 @@ image_render_set_visible_channels(GImage *gimage,
     int visible[MAX_CHANNELS];
     SetVisibleChannelsFunc func=set_visible_channels_func(projection_tag);
     gint is_lab = 0, is_cmyk = 0;
-    gint  smask[4] = {0,1,2,3},
-          vmask[4] = {0,1,2,3};
+    gint  smask[4] = {0,1,2,3},    /**<@brief source mask */
+          vmask[4] = {0,1,2,3};    /**<@brief display colours mask */
 
     if (gimage->cms_profile)
     {   if (strstr("Lab",cms_get_profile_info(gimage->cms_profile)->color_space_name))
@@ -1190,14 +1156,16 @@ image_render_set_visible_channels(GImage *gimage,
             is_cmyk = 1;
     }
 
-    if (tag_alpha (projection_tag) == ALPHA_YES )
+    if (tag_alpha (projection_tag) == ALPHA_YES &&
+        !strstr("Cmyk",cms_get_profile_info(gimage->cms_profile)->color_space_name))
     {   num_inten--;
     }
 
     for(i = 0; i < num_inten; i++)
     {   visible[i] = gimage_get_component_visible (gimage, i); 
-    }	
-   
+    }
+
+    /* set single CIE*a und CIE*b visible channel to gray output */
     if (is_lab &&
       num_inten == 3 &&
       !visible[0] && 
@@ -1208,6 +1176,7 @@ image_render_set_visible_channels(GImage *gimage,
       vmask[1] = vmask[2] = 0;
     }
     else
+    /* set single 3 colour image to gray output */
     if (!is_lab && !is_cmyk &&
       num_inten == 3 &&
       (visible[0] + visible[1] + visible[2]) == 1 )
@@ -1218,6 +1187,18 @@ image_render_set_visible_channels(GImage *gimage,
         }
     }
     else
+    /* set single 4 colour cmyk image to gray output */
+    if (is_cmyk &&
+      num_inten == 4 &&
+      (visible[0] + visible[1] + visible[2]) + visible[3] == 1 )
+    { for(i = 0; i < num_inten; ++i)
+        {
+          vmask[i] = 1;
+          smask[i] = visible[0] ? 0 : (visible[1] ? 1 : (visible[2] ? 2 : 3));
+        }
+    }
+    else
+    /* simply show natural colour */
     { for(i = 0; i < num_inten; ++i)
           vmask[i] = visible[i];
     }
@@ -1268,9 +1249,153 @@ image_render_set_visible_channels(GImage *gimage,
 
 
 #if 1
-/* TODO make the function smaller and put the expose and
-        ICC code somewhere else
- */
+static guchar*
+render_image_tile_fault_expose (RenderInfo *info,
+                                void *in, void *out, int samples,
+                                float offset, float expose, float gamma,
+                                int has_alpha, Precision prec)
+{
+  int i;
+  float   *f, ff_;
+  guint16 *u16;
+  guint8  *u8;
+  float    sb, db;
+  ShortsFloat u;
+
+  f = (float*)tile_buf;
+  u16 = (guint16*)tile_buf;
+  u8 = (guint8*)tile_buf;
+  if(info->gdisp->expose != EXPOSE_DEFAULT ||
+     info->gdisp->offset != OFFSET_DEFAULT ||
+     info->gdisp->gamma  != GAMMA_DEFAULT)
+  {
+    switch (prec)
+    {
+      case PRECISION_FLOAT:
+           if(has_alpha)
+           {
+             for(i = 0; i < samples; ++i)
+             { if ((i+1)%info->src_num_channels)
+                 *f = pow((*f-offset) * expose, gamma);
+                 ++f;
+             }
+           } else
+         { int n = 12;
+           for(i = 0; i < samples/n; ++i)
+           {
+             f[0] -= offset;
+             f[1] -= offset;
+             f[2] -= offset;
+             f[3] -= offset;
+             f[4] -= offset;
+             f[5] -= offset;
+             f[6] -= offset;
+             f[7] -= offset;
+             f[8] -= offset;
+             f[9] -= offset;
+             f[10]-= offset;
+             f[11]-= offset;
+             f[0] *= expose;
+             f[1] *= expose;
+             f[2] *= expose;
+             f[3] *= expose;
+             f[4] *= expose;
+             f[5] *= expose;
+             f[6] *= expose;
+             f[7] *= expose;
+             f[8] *= expose;
+             f[9] *= expose;
+             f[10]*= expose;
+             f[11]*= expose;
+             f[0] = pow(  f[0], gamma);
+             f[1] = pow(  f[1], gamma);
+             f[2] = pow(  f[2], gamma);
+             f[3] = pow(  f[3], gamma);
+             f[4] = pow(  f[4], gamma);
+             f[5] = pow(  f[5], gamma);
+             f[6] = pow(  f[6], gamma);
+             f[7] = pow(  f[7], gamma);
+             f[8] = pow(  f[8], gamma);
+             f[9] = pow(  f[9], gamma);
+             f[10]= pow(  f[10],gamma);
+             f[11]= pow(  f[11],gamma);
+             f += n;
+           }
+           samples = samples % n;
+           for (i = 0; i < samples; ++i)
+           {
+             f[0] -= offset;
+             f[0] *= expose;
+             f[0] = pow(  f[0], gamma);
+             ++f;
+           }
+         }
+           break;
+      case PRECISION_FLOAT16:
+           for(i = 0; i < samples; ++i)
+           {
+             if ((has_alpha && (i+1)%info->src_num_channels) ||
+                 !has_alpha)
+             {
+               sb = FLT (*u16, u);
+               db = pow (sb*expose, gamma);
+               *u16++ = FLT16 (db, u);
+             } else
+               ++u16;
+           }
+           break;
+      case PRECISION_BFP:
+           for(i = 0; i < samples; ++i)
+           { if ((has_alpha && (i+1)%info->src_num_channels) ||
+                 !has_alpha)
+               *u16 = CLAMP(32768.f * pow(*u16/32768.f*expose, 
+                            gamma), 0, 65535);
+             ++u16;
+           }
+           break;
+      case PRECISION_U8:
+           for(i = 0; i < samples; ++i)
+           { if ((has_alpha && (i+1)%info->src_num_channels) ||
+                 !has_alpha)
+               *u8 =  CLAMP(255.f * pow(*u8/255.f * expose, gamma),
+                            0, 255);
+              ++u8;
+           }
+           break;
+      case PRECISION_U16:
+           if(has_alpha)
+           {
+             for(i = 0; i < samples; ++i)
+               { if ((i+1)%info->src_num_channels)
+                   *u16 = CLAMP(65535.f * pow(*u16/65535.f * expose,gamma),
+                                0, 65535);
+                   ++u16;
+               }
+           } else
+           for(i = 0; i < samples; ++i)
+           {
+             ff_ = (float)*u16 / 65535.f;
+             ff_ -= offset;
+             ff_ *= expose;
+             ff_ = pow(  ff_, gamma);
+             ff_ *= 65535.f;
+             ff_ = CLAMP(ff_, 0, 65535.f);
+             *u16++ = (guint16)ff_;
+           }
+           break;
+      case PRECISION_NONE:
+      default:
+           break;
+    }
+  }
+
+  if(info->transform_buffer)
+    cms_transform_buffer( info->transform_buffer, tile_buf, tile_buf, info->w,
+                          tag_precision(gimage_tag(info->gdisp->gimage)) );
+
+  return tile_buf;
+}
+
 static guchar*
 render_image_tile_fault (RenderInfo *info)
 {
@@ -1322,86 +1447,47 @@ render_image_tile_fault (RenderInfo *info)
   x = info->src_x;
   width = info->w;
   src_bpp = info->src_bpp;
+
   while (width--)
     {
-	 memcpy(dest,data,src_bpp);
-	 dest+=src_bpp;
-/*      for (b = 0; b < info->src_bpp; b++)
-	*dest++ = data[b];
-*/
+      /* RGB unscaled optimisation */
+      if(!(info->gdisp->expose != EXPOSE_DEFAULT ||
+           info->gdisp->offset != OFFSET_DEFAULT ||
+           info->gdisp->gamma != GAMMA_DEFAULT) &&
+       	   info->scalesrc == 1 && info->scaledest == 1)
+      {
+        memcpy(dest,data, src_bpp * portion_width);
+        dest += src_bpp * portion_width;
+        data += step * portion_width;
+        x += portion_width;
+        /*scale += portion_width;*/
+      } else
+        for (i = 0; i < info->src_bpp; i++)
+          *dest++ = data[i];
+
       if (*scale++ != 0)
 	{
-	  x += info->scalesrc;
-	  data += step;
+          /* RGB unscaled optimisation */
+          if((info->gdisp->expose != EXPOSE_DEFAULT ||
+              info->gdisp->offset != OFFSET_DEFAULT ||
+              info->gdisp->gamma != GAMMA_DEFAULT) ||
+             (info->scalesrc != 1 || info->scaledest != 1))
+          {
+            x += info->scalesrc;
+            data += step;
+          }
 
 	  if (x >= x_portion + portion_width)
 	    {
 	      canvas_portion_unref (info->src_canvas, x_portion, y_portion);
               if (x >= CAST(int) info->src_width)
-              { f = (float*)tile_buf;
-                u16 = (guint16*)tile_buf;
-                u8 = (guint8*)tile_buf;
-                if(info->gdisp->expose != EXPOSE_DEFAULT || info->gdisp->offset != OFFSET_DEFAULT || info->gdisp->gamma != GAMMA_DEFAULT)
-                {
-                  switch (tag_precision(tag))
-                  {
-                  case PRECISION_FLOAT:
-                    for(i = 0; i < dest_sample_width; ++i)
-                    { if ((has_alpha && (i+1)%info->src_num_channels) ||
-                          !has_alpha)
-                        *f = pow((*f-offset) * expose, gamma);
-                      ++f;
-                    }
-                    break;
-                  case PRECISION_FLOAT16:
-                    for(i = 0; i < dest_sample_width; ++i)
-                    { if ((has_alpha && (i+1)%info->src_num_channels) ||
-                          !has_alpha)
-                      {
-                        sb = FLT (*u16, u);
-                        db = pow (sb*expose, gamma);
-                        *u16 = FLT16 (db, u);
-                      }
-                      ++u16;
-                    }
-                    break;
-                  case PRECISION_BFP:
-                    for(i = 0; i < dest_sample_width; ++i)
-                    { if ((has_alpha && (i+1)%info->src_num_channels) ||
-                          !has_alpha)
-                        *u16 = CLAMP(32768.f * pow(*u16/32768.f*expose, 
-                                     gamma), 0, 65535);
-                      ++u16;
-                    }
-                    break;
-                  case PRECISION_U8:
-                    for(i = 0; i < dest_sample_width; ++i)
-                    { if ((has_alpha && (i+1)%info->src_num_channels) ||
-                          !has_alpha)
-                        *u8 =  CLAMP(255.f * pow(*u8/255.f * expose, gamma),
-                                     0, 255);
-                      ++u8;
-                    }
-                    break;
-                  case PRECISION_U16:
-                    for(i = 0; i < dest_sample_width; ++i)
-                    { if ((has_alpha && (i+1)%info->src_num_channels) ||
-                          !has_alpha)
-                        *u16 = CLAMP(65535.f * pow(*u16/65535.f * expose,gamma),
-                                     0, 65535);
-                      ++u16;
-                    }
-                    break;
-                  case PRECISION_NONE:
-                  default:
-                    break;
-                  }
-                }
+              {
+                f = (float*)tile_buf;
+                render_image_tile_fault_expose (info,
+                                tile_buf, f, dest_sample_width,
+                                offset, expose, gamma,
+                                has_alpha, tag_precision(tag));
                    
-                if(info->transform_buffer)
-                  cms_transform_buffer(info->transform_buffer,
-                                 tile_buf, tile_buf, info->w,
-                                 tag_precision(gimage_tag(info->gdisp->gimage)) );
                 return tile_buf;
               }
 	      x_portion += portion_width;
@@ -1419,70 +1505,11 @@ render_image_tile_fault (RenderInfo *info)
         }
     }
 
-  if(info->gdisp->gamma != 1.0 || info->gdisp->expose != 0.0)
-    {
-                f = (float*)tile_buf;
-                u16 = (guint16*)tile_buf;
-                u8 = (guint8*)tile_buf;
-
-                  switch (tag_precision(tag))
-                  {
-                  case PRECISION_FLOAT:
-                    for(i = 0; i < dest_sample_width; ++i)
-                    { if ((has_alpha && (i+1)%info->src_num_channels) ||
-                          !has_alpha)
-                        *f = pow((*f-offset) * expose, gamma);
-                      ++f;
-                    }
-                    break;
-                  case PRECISION_FLOAT16:
-                    for(i = 0; i < dest_sample_width; ++i)
-                    { if ((has_alpha && (i+1)%info->src_num_channels) ||
-                          !has_alpha)
-                      {
-                        sb = FLT (*u16, u);
-                        db = pow (sb*expose, gamma);
-                        *u16 = FLT16 (db, u);
-                      }
-                      ++u16;
-                    }
-                    break;
-                  case PRECISION_BFP:
-                    for(i = 0; i < dest_sample_width; ++i)
-                    { if ((has_alpha && (i+1)%info->src_num_channels) ||
-                          !has_alpha)
-                        *u16 = CLAMP(32768.f * pow(*u16/32768.f*expose, 
-                                     gamma), 0, 65535);
-                      ++u16;
-                    }
-                    break;
-                  case PRECISION_U8:
-                    for(i = 0; i < dest_sample_width; ++i)
-                    { if ((has_alpha && (i+1)%info->src_num_channels) ||
-                          !has_alpha)
-                        *u8 =  CLAMP(255.f * pow(*u8/255.f * expose, gamma),
-                                     0, 255);
-                      ++u8;
-                    }
-                    break;
-                  case PRECISION_U16:
-                    for(i = 0; i < dest_sample_width; ++i)
-                    { if ((has_alpha && (i+1)%info->src_num_channels) ||
-                          !has_alpha)
-                        *u16 = CLAMP(65535.f * pow(*u16/65535.f * expose,gamma),
-                                     0, 65535);
-                      ++u16;
-                    }
-                    break;
-                  case PRECISION_NONE:
-                  default:
-                    break;
-                  }
-    }
-
-  if(info->transform_buffer)
-     cms_transform_buffer(info->transform_buffer, tile_buf, tile_buf, info->w,
-                          tag_precision(gimage_tag(info->gdisp->gimage)) );
+  f = (float*)tile_buf;
+  render_image_tile_fault_expose (info,
+                                tile_buf, f, dest_sample_width,
+                                offset, expose, gamma,
+                                has_alpha, tag_precision(tag));
 
   canvas_portion_unref (info->src_canvas, x_portion, y_portion);
   return tile_buf;
