@@ -21,6 +21,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <sys/types.h>
+#include "libgimp/gimpintl.h"
 #include "../../lib/wire/dl_list.h"
 #include "../appenv.h"
 #include "../canvas.h"
@@ -200,7 +201,7 @@ layer_new  (
   SplineTool *st;
 
   if (width == 0 || height == 0) {
-    g_message ("Zero width or height layers not allowed.");
+    g_message (_("Zero width or height layers not allowed."));
     return NULL;
   }
 
@@ -298,7 +299,7 @@ layer_copy (layer, add_alpha)
   
   new_layer->gimage_id = layer->gimage_id;
   if (!new_layer) {
-    g_message ("layer_copy: could not allocate new layer");
+    g_message (_("layer_copy: could not allocate new layer"));
     goto cleanup;
   }
 
@@ -370,7 +371,7 @@ layer_from_tiles (void *gimage_ptr, CanvasDrawable *drawable, Canvas *tiles, cha
                          name, opacity, mode);
 
   if (!new_layer) {
-    g_message("layer_from_tiles: could not allocate new layer");
+    g_message(_("layer_from_tiles: could not allocate new layer"));
     return NULL;
   }
 
@@ -504,8 +505,7 @@ layer_create_mask (layer, add_mask_type)
 
 
 Layer *
-layer_get_ID (ID)
-     int ID;
+layer_get_ID (int ID)
 {
   CanvasDrawable *drawable;
   drawable = drawable_get_ID (ID);
@@ -682,6 +682,7 @@ layer_remove_alpha (layer)
   PixelArea srcPR, destPR;
   Canvas * c;
   Tag t;
+  GImage* gimage = NULL;
   if(!layer)
   {	return;
   }
@@ -727,6 +728,9 @@ layer_remove_alpha (layer)
    *  this layer being the only layer in the gimage
    */
   gdisplays_update_title (GIMP_DRAWABLE(layer)->gimage_ID);
+
+  if(gimage = gimage_get_ID(GIMP_DRAWABLE(layer)->gimage_ID))
+    lc_dialog_update (gimage);
 }
 
 
@@ -737,6 +741,7 @@ layer_add_alpha (layer)
   PixelArea srcPR, destPR;
   Canvas * c;
   Tag t;
+  GImage* gimage = NULL;
 
   t = drawable_tag (GIMP_DRAWABLE(layer));
 
@@ -780,6 +785,9 @@ layer_add_alpha (layer)
    *  this layer being the only layer in the gimage
    */
   gdisplays_update_title (GIMP_DRAWABLE(layer)->gimage_ID);
+
+  if(gimage = gimage_get_ID(GIMP_DRAWABLE(layer)->gimage_ID))
+    lc_dialog_update (gimage);
 }
 
 
