@@ -20,6 +20,7 @@
 #include <math.h>
 #include <stdio.h>
 
+#include "libgimp/gimpintl.h"
 #include "../appenv.h"
 #include "../brush.h"
 #include "../brushlist.h"
@@ -221,7 +222,7 @@ paint_core_16_init_linked  (
   /* get the brush mask */
   if (!(brush = get_active_brush ()))
     {
-      g_message ("No brushes available for use with this tool.");
+      g_message (_("No brushes available for use with this tool."));
       return FALSE;
     }
  
