@@ -22,6 +22,7 @@
 #include <gdk/gdkkeysyms.h>
 #include <gdk/gdkprivate.h>
 #include "../../lib/version.h"
+#include "libgimp/gimpintl.h"
 #include "../appenv.h"
 #include "../actionarea.h"
 #include "../buildmenu.h"
@@ -101,8 +102,8 @@ struct TextTool
   void *gdisp_ptr;
 };
 
-typedef struct FontInfo FontInfo;
-struct FontInfo
+typedef struct CPFontInfo CPFontInfo;
+struct CPFontInfo
 {
   char *family;         /* The font family this info struct describes. */
   int *foundries;       /* An array of valid foundries. */
@@ -146,7 +147,7 @@ static void       text_font_item_update   (GtkWidget *, gpointer);
 static void       text_validate_combo     (TextTool *, int);
 
 static void       text_get_fonts          (void);
-static void       text_insert_font        (FontInfo **, int *, char *);
+static void       text_insert_font        (CPFontInfo **, int *, char *);
 static GSList*    text_insert_field       (GSList *, char *, int);
 static char*      text_get_field          (char *, int);
 static int        text_field_to_index     (char **, int, char *);
@@ -183,7 +184,7 @@ static MenuItem size_metric_items[] =
 };
 
 static TextTool *the_text_tool = NULL;
-static FontInfo **font_info;
+static CPFontInfo **font_info;
 static int nfonts = -1;
 
 static GSList *foundries = NULL;
@@ -218,7 +219,7 @@ tools_new_text ()
    Tool * tool;
 
    if (! text_options)
-      text_options = tools_register_no_options (TEXT, "Text Tool Options");
+      text_options = tools_register_no_options (TEXT, _("Text Tool Options"));
 
    tool = g_malloc_zero (sizeof (Tool));
   if (!the_text_tool)
@@ -298,7 +299,7 @@ text_button_press (Tool           *tool,
       text_get_fonts ();
       if (nfonts == 0)
        {
-         g_message ("Note: No fonts found.  Text tool not available.");
+         g_message (_("Note: No fonts found.  Text tool not available."));
          nfonts = -1;
          return;
        }
@@ -428,7 +429,7 @@ text_create_dialog (TextTool *text_tool)
   /* Create the shell and vertical & horizontal boxes */
   text_tool->shell = gtk_dialog_new ();
   gtk_window_set_wmclass (GTK_WINDOW (text_tool->shell), "text_tool", PROGRAM_NAME);
-  gtk_window_set_title (GTK_WINDOW (text_tool->shell), "Text Tool");
+  gtk_window_set_title (GTK_WINDOW (text_tool->shell), _("Text Tool"));
   gtk_window_set_policy (GTK_WINDOW (text_tool->shell), FALSE, TRUE, TRUE);
   gtk_window_position (GTK_WINDOW (text_tool->shell), GTK_WIN_POS_MOUSE);
   gtk_widget_set (GTK_WIDGET (text_tool->shell),
@@ -485,6 +486,8 @@ text_create_dialog (TextTool *text_tool)
   gtk_box_pack_start (GTK_BOX (text_hbox), text_tool->size_text, TRUE, TRUE, 0);
 
   /* Create the size menu */
+  size_metric_items[0].label = _(size_metric_items[0].label);
+  size_metric_items[1].label = _(size_metric_items[0].label);
   size_metric_items[0].user_data = text_tool;
   size_metric_items[1].user_data = text_tool;
   text_tool->size_menu = build_menu (size_metric_items, NULL);
@@ -499,7 +502,7 @@ text_create_dialog (TextTool *text_tool)
   gtk_container_add (GTK_CONTAINER (text_tool->text_frame), text_tool->the_text);
 
   /* create the antialiasing toggle button  */
-  text_tool->antialias_toggle = gtk_check_button_new_with_label ("Antialiasing");
+  text_tool->antialias_toggle = gtk_check_button_new_with_label (_("Antialiasing"));
   gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (text_tool->antialias_toggle), text_tool->antialias);
   gtk_box_pack_start (GTK_BOX (right_vbox), text_tool->antialias_toggle, FALSE, FALSE, 0);
   gtk_signal_connect (GTK_OBJECT (text_tool->antialias_toggle), "toggled",
@@ -531,13 +534,13 @@ text_create_dialog (TextTool *text_tool)
   nmenu_items[5] = nregistries;
   nmenu_items[6] = nencodings;
 
-  menu_strs[0] = "Foundry";
-  menu_strs[1] = "Weight";
-  menu_strs[2] = "Slant";
-  menu_strs[3] = "Set width";
-  menu_strs[4] = "Spacing";
-  menu_strs[5] = "Registry";
-  menu_strs[6] = "Encoding";
+  menu_strs[0] = _("Foundry");
+  menu_strs[1] = _("Weight");
+  menu_strs[2] = _("Slant");
+  menu_strs[3] = _("Set width");
+  menu_strs[4] = _("Spacing");
+  menu_strs[5] = _("Registry");
+  menu_strs[6] = _("Encoding");
 
   menu_item_strs[0] = foundry_array;
   menu_item_strs[1] = weight_array;
@@ -618,6 +621,10 @@ text_create_dialog (TextTool *text_tool)
 #endif
 
   /* Create the action area */
+  { int i;
+    for(i = 0; i < 2; ++i)
+      action_items[i].label = _(action_items[i].label);
+  }
   action_items[0].user_data = text_tool;
   action_items[1].user_data = text_tool;
   build_action_area (GTK_DIALOG (text_tool->shell), action_items, 2, 0);
@@ -689,7 +696,7 @@ static void
 text_font_item_update (GtkWidget *w,
              gpointer   data)
 {
-  FontInfo *font;
+  CPFontInfo *font;
   int old_index;
   int i, index;
 
@@ -939,7 +946,7 @@ static void
 text_validate_combo (TextTool *text_tool,
            int       which)
 {
-  FontInfo *font;
+  CPFontInfo *font;
   int which_val;
   int new_combo[7];
   int best_combo[7];
@@ -1115,7 +1122,7 @@ text_get_fonts ()
   char *fontname;
   char *field;
   GSList *temp_list;
-  int num_fonts;
+  int num_fonts = 0;
   int index;
   int i, j;
 
@@ -1123,10 +1130,12 @@ text_get_fonts ()
 #ifdef WIN32
 	num_fonts=0;
 #else
+# ifndef __APPLE__
   fontnames = XListFonts (DISPLAY, "-*-*-*-*-*-*-0-0-75-75-*-0-*-*", 32767, &num_fonts);
+# endif
 #endif
   /* the maximum size of the table is the number of font names returned */
-  font_info = g_malloc (sizeof (FontInfo**) * num_fonts);
+  font_info = g_malloc (sizeof (CPFontInfo**) * num_fonts);
 
   /* insert the fontnames into a table */
   nfonts = 0;
@@ -1147,7 +1156,9 @@ text_get_fonts ()
 #ifdef WIN32
 
 #else
+# ifndef __APPLE__
   XFreeFontNames (fontnames);
+# endif
 #endif
 
   nfoundries = g_slist_length (foundries) + 1;
@@ -1322,11 +1333,11 @@ text_get_fonts ()
 }
 
 static void
-text_insert_font (FontInfo **table,
+text_insert_font (CPFontInfo **table,
         int       *ntable,
         char      *fontname)
 {
-  FontInfo *temp_info;
+  CPFontInfo *temp_info;
   char *family;
   int lower, upper;
   int middle, cmp;
@@ -1362,7 +1373,7 @@ text_insert_font (FontInfo **table,
     }
 
   /* Add another entry to the table for this new font family */
-  table[*ntable] = g_malloc (sizeof (FontInfo));
+  table[*ntable] = g_malloc (sizeof (CPFontInfo));
   table[*ntable]->family = family;
   table[*ntable]->foundries = NULL;
   table[*ntable]->weights = NULL;
@@ -1712,7 +1723,7 @@ text_gdk_image_to_region_u8 (GdkImage    *image,
 			  int          scale,
 			  PixelArea   *textPR)
 {
-   int black_pixel;
+   int black_pixel = 0;
    int pixel;
    int value;
    int scalex, scaley;
@@ -1728,7 +1739,9 @@ text_gdk_image_to_region_u8 (GdkImage    *image,
 #ifdef WIN32
 	black_pixel=0;
 #else
+# ifndef __APPLE__
    black_pixel = BlackPixel (DISPLAY, DefaultScreen (DISPLAY));
+# endif
 #endif
    data = pixelarea_data (textPR);
    outdata = (unsigned char *) g_malloc (width);
@@ -1764,7 +1777,7 @@ text_gdk_image_to_region_u16 (GdkImage    *image,
 			  int          scale,
 			  PixelArea   *textPR)
 {
-   int black_pixel;
+   int black_pixel = 0;
    int pixel;
    int value;
    int scalex, scaley;
@@ -1779,7 +1792,9 @@ text_gdk_image_to_region_u16 (GdkImage    *image,
 #ifdef WIN32
 	black_pixel=0;
 #else
+# ifndef __APPLE__
    black_pixel = BlackPixel (DISPLAY, DefaultScreen (DISPLAY));
+# endif
 #endif
    outdata = (guint16 *) g_malloc (width*sizeof(guint16));
 
@@ -1814,7 +1829,7 @@ text_gdk_image_to_region_float (GdkImage    *image,
 			  int          scale,
 			  PixelArea   *textPR)
 {
-   int black_pixel;
+   int black_pixel = 0;
    int pixel;
    int value;
    int scalex, scaley;
@@ -1829,7 +1844,9 @@ text_gdk_image_to_region_float (GdkImage    *image,
 #ifdef WIN32
 	black_pixel=0;
 #else
+# ifndef __APPLE__
    black_pixel = BlackPixel (DISPLAY, DefaultScreen (DISPLAY));
+# endif
 #endif
   outdata = (gfloat *) g_malloc (width*sizeof(gfloat));
 
@@ -1865,7 +1882,7 @@ text_gdk_image_to_region_float (GdkImage    *image,
  * Kevin M. Murray 11/5/02
  *********************************************************************************************/
 static void text_gdk_image_to_region_float16 (GdkImage* image, int scale, PixelArea* textPR) {
-   int black_pixel;
+   int black_pixel = 0;
    int pixel;
    int value;
    int scalex, scaley;
@@ -1882,7 +1899,9 @@ static void text_gdk_image_to_region_float16 (GdkImage* image, int scale, PixelA
 #ifdef WIN32
 	black_pixel=0;
 #else
+# ifndef __APPLE__
    black_pixel = BlackPixel (DISPLAY, DefaultScreen (DISPLAY));
+# endif
 #endif
    outdata     = (guint16*) g_malloc (width * sizeof(guint16));
 
@@ -1913,7 +1932,7 @@ text_gdk_image_to_region_bfp (GdkImage    *image,
 			  int          scale,
 			  PixelArea   *textPR)
 {
-   int black_pixel;
+   int black_pixel = 0;
    int pixel;
    int value;
    int scalex, scaley;
@@ -1928,7 +1947,9 @@ text_gdk_image_to_region_bfp (GdkImage    *image,
 #ifdef WIN32
 	black_pixel=0;
 #else
+# ifndef __APPLE__
    black_pixel = BlackPixel (DISPLAY, DefaultScreen (DISPLAY));
+# endif
 #endif
    outdata = (guint16 *) g_malloc (width*sizeof(guint16));
 
@@ -2061,12 +2082,16 @@ text_render (GImage *gimage,
    gdk_gc_set_font (gc, font);
 
    /*  get black and white pixels for this gdisplay  */
+    black.pixel=0;
+    white.pixel=1;
 #ifdef WIN32
 	black.pixel=0;
 	white.pixel=1;
 #else
+# ifndef __APPLE__
    black.pixel = BlackPixel (DISPLAY, DefaultScreen (DISPLAY));
    white.pixel = WhitePixel (DISPLAY, DefaultScreen (DISPLAY));
+# endif
 #endif
    /* Render the text into the pixmap.
     * Since the pixmap may not fully bound the text (because we limit its size)
@@ -2157,7 +2182,7 @@ text_render (GImage *gimage,
 #else
 						  STORAGE_TILED,
 #endif
-                          "Text Layer", 1.0, NORMAL_MODE)))
+                          _("Text Layer"), 1.0, NORMAL_MODE)))
     {
       COLOR16_NEW (color, drawable_tag (GIMP_DRAWABLE(layer)));
       COLOR16_INIT (color);
@@ -2214,7 +2239,7 @@ text_render (GImage *gimage,
     {
       if (newmask) 
 	{
-           g_message ("text_render: could not allocate image");
+           g_message (_("text_render: could not allocate image"));
          canvas_delete (newmask);
            }
       layer = NULL;
