@@ -15,40 +15,73 @@
 
 /* temporary logging facilities */
 
+/*
+  CHANGE-LOG (started 03/2006)
+  ============================
+  2006/03  hartmut.sbosny@gmx.de [hsbo]
+   - adjustable trace depth (`trace_depth_')
+   - safeguard against level under/overflow
+   - TRACE macros in .h for removable tracing and with line numbering
+*/
 
+
+/*  global variables  */
+int trace_depth_ = 24;          /*  maximum == max_level/2 == 24 */
+int trace_line_no_;             /*  set by TRACE macros */
+
+/*  local variables */
 static char indent[] = "                                                 ";
-static int level = 48;
+static int max_level = 48;
+static int level     = 48;
+static int skipped_levels = 0;
+static gboolean with_line_no = TRUE;    /* tracing with line numbers? */
 
 void 
-trace_enter  (
-              char * func
-              )
+trace_enter  (const char * func)
 {
-  printf ("%s%s () {\n", indent+level, func);
-  level -= 2;
+  if (max_level - level >= 2*trace_depth_) 
+    {
+      skipped_levels ++;
+      return;
+    }
+  if (with_line_no) 
+    printf("%4d:", trace_line_no_);
+  
+  printf ("%s%s() - Enter {\n", indent+level, func);
+  if (level > 1) level -= 2;
+}
+
+void 
+trace_exit  (void)
+{
+  if (skipped_levels > 0) 
+    {
+      skipped_levels --;
+      return;
+    }
+  if (with_line_no) 
+    printf("%4d:", trace_line_no_);
+  
+  if (level < max_level-1) level += 2;
+  printf ("%s} - Exit\n", indent+level);
 }
 
 
 void 
-trace_exit  (
-             void
-             )
-{
-  level += 2;
-  printf ("%s}\n", indent+level);
-}
-
-
-void 
-trace_begin  (
-              char * format,
-              ...
-              )
+trace_begin  (const char * format, ...)
 {
   va_list args;
   gchar *buf;
   extern char * g_vsprintf ();
     
+  if (max_level - level >= 2*trace_depth_) 
+    {
+      skipped_levels ++;
+      return;
+    }
+  if (with_line_no) 
+    printf("%4d:", trace_line_no_);
+  
   va_start (args, format);
   buf = g_strdup_vprintf (format, args);
   va_end (args);
@@ -57,30 +90,39 @@ trace_begin  (
   fputs (buf, stdout);
   fputs (": {\n", stdout);
 
-  level -= 2;
+  if (level > 1) level -= 2;
 }
 
 
 void 
-trace_end  (
-            void
-            )
+trace_end  (void)
 {
-  level += 2;
+  if (skipped_levels > 0) 
+    {
+      skipped_levels --;
+      return;
+    }
+  if (with_line_no) 
+    printf("%4d:", trace_line_no_);
+  
+  if (level < max_level-1) level += 2;
   printf ("%s}\n", indent+level);
 }
 
 
 void 
-trace_printf  (
-               char * format,
-               ...
-               )
+trace_printf  (const char * format, ...)
 {
   va_list args;
   char *buf;
   extern char * g_vsprintf ();
 
+  if (skipped_levels > 0) 
+    return;
+  
+  if (with_line_no) 
+    printf("%4d:", trace_line_no_);
+  
   va_start (args, format);
   buf = g_strdup_vprintf (format, args);
   va_end (args);
