@@ -29,8 +29,10 @@
 #include "interface.h"
 #include "rc.h"
 #include "palette.h"
+#include "pixelrow.h"
 #include "tools.h"
 #include "brushlist.h"
+#include "libgimp/gimpintl.h"
 
 typedef struct DeviceInfo DeviceInfo;
 
@@ -295,7 +297,7 @@ devices_rc_update (gchar *name, DeviceValues values,
 	}
       else
 	{
-	  g_warning ("devices_rc_update called multiple times for not present device\n");
+	  g_warning (_("devices_rc_update called multiple times for not present device\n"));
 	  return;
 	}
     }
@@ -352,11 +354,19 @@ select_device (guint32 new_device)
       if (device_info->brush)
 	select_brush (device_info->brush);
       gtk_widget_activate (tool_widgets[tool_info[(int) device_info->tool].toolbar_position]);
-#if 0
-      palette_set_foreground (device_info->foreground[0], 
-			      device_info->foreground[1], 
-			      device_info->foreground[2]);
-#endif
+
+        {
+          PixelRow col;
+          gfloat d[3];
+
+          d[0] = device_info->foreground[0] / 255.;
+          d[1] = device_info->foreground[1] / 255.;
+          d[2] = device_info->foreground[2] / 255.;
+          
+          pixelrow_init (&col, tag_new (PRECISION_FLOAT, FORMAT_RGB, ALPHA_NO), (guchar *) d, 1);
+
+          palette_set_foreground (&col);
+        }
     }
 
   suppress_update = FALSE;
@@ -419,11 +429,19 @@ devices_save_current_info (void)
     device_info->tool = active_tool_type;
   else
     device_info->tool = RECT_SELECT;
-#if 0
-  palette_get_foreground (&device_info->foreground[0], 
-			  &device_info->foreground[1], 
-			  &device_info->foreground[2]);
-#endif
+
+        {
+          PixelRow col;
+          gfloat d[3];
+
+          pixelrow_init (&col, tag_new (PRECISION_FLOAT, FORMAT_RGB, ALPHA_NO), (guchar *) d, 1);
+
+          palette_get_foreground (&col);
+
+          device_info->foreground[0] = d[0] * 255.;
+          device_info->foreground[1] = d[1] * 255.;
+          device_info->foreground[2] = d[2] * 255.;
+        }
 }
 
 static void
@@ -585,7 +603,7 @@ create_device_status (void)
       deviceD = g_new (DeviceInfoDialog, 1);
       deviceD->shell = gtk_dialog_new ();
 
-      gtk_window_set_title (GTK_WINDOW(deviceD->shell), "Device Status");
+      gtk_window_set_title (GTK_WINDOW(deviceD->shell), _("Device Status"));
       gtk_window_set_policy (GTK_WINDOW (deviceD->shell), FALSE, FALSE, TRUE);
 
       deviceD->num_devices = 0;
@@ -663,6 +681,8 @@ create_device_status (void)
 	  i++;
 	}
 
+      action_items[0].label = _(action_items[0].label);
+      action_items[1].label = _(action_items[1].label);
       action_items[0].user_data = deviceD->shell;
       build_action_area (GTK_DIALOG (deviceD->shell), action_items, 2, 0);
 
@@ -791,14 +811,12 @@ device_status_update (guint32 deviceid)
 			  NULL);
 	  gtk_widget_show (deviceD->tools[i]);
 	  
-#if 0
 	  for (j=0;j<20*3;j+=3)
 	    {
 	      buffer[j] = device_info->foreground[0];
 	      buffer[j+1] = device_info->foreground[1];
 	      buffer[j+2] = device_info->foreground[2];
 	    }
-#endif
 	  
 	  for (j=0;j<20;j++)
 	    gtk_preview_draw_row (GTK_PREVIEW(deviceD->colors[i]), buffer, 
