@@ -37,6 +37,8 @@
 #include "clone.h"
 #include "zoom.h"
 #include "info_window.h"
+#include "layers_dialog.h"      /* hsbo */
+#include "gtk_debug_helpers.h"  /* hsbo */
 
 
 #define HORIZONTAL  1
@@ -91,6 +93,10 @@ gdisplay_shell_events (GtkWidget *widget,
                        GdkEvent  *event,
                        GDisplay  *gdisp)
 {
+#if 0
+  printf("%s (\"%s\", displayID=%d)...\n",__func__,
+         gdk_event_type_name(event), gdisplay_to_ID(gdisp));
+#endif         
   switch (event->type)
     {
     case GDK_BUTTON_PRESS:
@@ -108,10 +114,9 @@ gdisplay_shell_events (GtkWidget *widget,
 }
 
 gboolean    
-gdisplay_menubar_down(
-  GtkWidget *widget,
-  GdkEventButton *event,
-  gpointer user_data)
+gdisplay_menubar_down (GtkWidget *widget,
+                       GdkEventButton *event,
+                       gpointer user_data)
 {
   GDisplay * disp;
   disp = (GDisplay *)user_data;   
@@ -149,9 +154,15 @@ gdisplay_check_device_cursor (GDisplay *gdisp)
     }
 }
 
+
+/**
+*   gdisplay_canvas_events()  -  handles the events concerning the 'canvas'
+*                                       widget of a GDisplay
+*   `gdisp != NULL' warranted?
+*/
 gint
 gdisplay_canvas_events (GtkWidget *canvas,
-    GdkEvent  *event)
+                        GdkEvent  *event)
 {
   GDisplay *gdisp;
   GdkEventExpose *eevent;
@@ -160,7 +171,8 @@ gdisplay_canvas_events (GtkWidget *canvas,
   GdkEventKey *kevent;
   gdouble          tx            = 0;
   gdouble          ty            = 0;
-  GdkModifierType tmask;
+  gint             tx_int, ty_int;
+  GdkModifierType  tmask;                   /* unused */
   guint            state         = 0;
   gint             return_val    = FALSE;
   static gboolean  scrolled      = FALSE;
@@ -168,6 +180,12 @@ gdisplay_canvas_events (GtkWidget *canvas,
 
   gdisp = (GDisplay *) gtk_object_get_user_data (GTK_OBJECT (canvas));
 
+#if DEBUG_DISPLAY
+  printf("%4d: %s( \"%s\", dispID=%d )... [have window=%d]\n", __LINE__,
+         __func__, gdk_event_type_name(event), gdisplay_to_ID(gdisp), 
+         canvas->window ? 1 : 0);
+#endif 
+
   if (!canvas->window)
     {
     return FALSE;
@@ -205,19 +223,22 @@ gdisplay_canvas_events (GtkWidget *canvas,
   /*  Find out what device the event occurred upon  */
   if (!gdisp_busy && devices_check_change (event))
       gdisplay_check_device_cursor (gdisp);
-#if 0
-  /*  get the pointer position  */
+#if 1
+  /*  get the pointer position  */      /* reanimated -hsbo */
   if (!current_device) {
-    gdk_window_get_pointer (canvas->window, &tx, &ty, &tmask);
+    gdk_window_get_pointer (canvas->window, &tx_int, &ty_int, &tmask);
   }
   else
   {
-    gdk_window_get_pointer (canvas->window, &tx, &ty, &tmask);
+    gdk_window_get_pointer (canvas->window, &tx_int, &ty_int, &tmask);
     gdk_input_window_get_pointer (canvas->window, current_device, 
         NULL, NULL, NULL, NULL, NULL, NULL);
   }
+  tx = tx_int;
+  ty = ty_int;
 #endif
 
+  /*print_gdk_event_type(event);*/
   switch (event->type)
   {
     case GDK_EXPOSE:
@@ -238,7 +259,7 @@ gdisplay_canvas_events (GtkWidget *canvas,
         resize_display (gdisp, 0, FALSE);
       
       }
-	return_val = TRUE;
+      return_val = TRUE;
       break;
 
     case GDK_LEAVE_NOTIFY:
@@ -264,6 +285,10 @@ gdisplay_canvas_events (GtkWidget *canvas,
 	clone_enter_notify ();
       break;
 
+    case GDK_FOCUS_CHANGE:              /* hsbo */
+      lc_dialog_update (gdisp->gimage); /* laid-back if gimage==dialog_img */
+      break;
+      
     case GDK_BUTTON_PRESS:
       bevent = (GdkEventButton *) event;
       state = bevent->state;
@@ -398,7 +423,7 @@ gdisplay_canvas_events (GtkWidget *canvas,
                 bevent->y = ty;
               }
 
-
+              
               /* hack hack hack */
               if (no_cursor_updating == 0)
               {
@@ -440,7 +465,6 @@ gdisplay_canvas_events (GtkWidget *canvas,
           gtk_grab_remove (canvas);
 	  break;
 
-
         case 3:
           break;
 
@@ -449,8 +473,8 @@ gdisplay_canvas_events (GtkWidget *canvas,
       }
       break;
 
-  case GDK_MOTION_NOTIFY:{
-    GdkModifierType state;
+    case GDK_MOTION_NOTIFY:{
+      GdkModifierType state;
 
       middle_mouse_button = 0;
 
@@ -501,7 +525,7 @@ gdisplay_canvas_events (GtkWidget *canvas,
           /*  if the first mouse button is down, check for automatic
            *  scrolling...
            */
-          if ((mevent->state & Button1Mask) && !active_tool->scroll_lock)
+          if ((mevent->state & GDK_BUTTON1_MASK) && !active_tool->scroll_lock)
           {
             if (mevent->x < 0 || mevent->y < 0 ||
                 mevent->x > gdisp->disp_width ||
@@ -539,33 +563,36 @@ gdisplay_canvas_events (GtkWidget *canvas,
       {
         case GDK_Left: case GDK_Right:
         case GDK_Up: case GDK_Down:
-                     if (active_tool && !gimage_is_empty (gdisp->gimage)
-#                        ifndef DISP_DEBUG
-                         && active_tool->gdisp_ptr == gdisp
-#                        endif
-                        )
-                       (* active_tool->arrow_keys_func) (active_tool, kevent, gdisp);
-                     return_val = TRUE;
-                     break;
+          if (active_tool && !gimage_is_empty (gdisp->gimage)
+#         ifndef DISP_DEBUG
+              && active_tool->gdisp_ptr == gdisp
+#         endif
+             )
+            (* active_tool->arrow_keys_func) (active_tool, kevent, gdisp);
+          return_val = TRUE;
+          break;
 
         case GDK_Tab:
-                     if (kevent->state & GDK_MOD1_MASK && !gimage_is_empty (gdisp->gimage))
-                       layer_select_init (gdisp->gimage, 1, kevent->time);
-                     if (kevent->state & GDK_CONTROL_MASK && !gimage_is_empty (gdisp->gimage))
-                       layer_select_init (gdisp->gimage, -1, kevent->time);
-                     return_val = TRUE;
-                     break;
+          if (kevent->state & GDK_MOD1_MASK && !gimage_is_empty (gdisp->gimage))
+            layer_select_init (gdisp->gimage, 1, kevent->time);
+          if (kevent->state & GDK_CONTROL_MASK && !gimage_is_empty (gdisp->gimage))
+            layer_select_init (gdisp->gimage, -1, kevent->time);
+          return_val = TRUE;
+          break;
 
-                     /*  Update the state based on modifiers being pressed  */
-        case GDK_Alt_L: case GDK_Alt_R:
-                        state |= GDK_MOD1_MASK;
-                        break;
-        case GDK_Shift_L: case GDK_Shift_R:
-                          state |= GDK_SHIFT_MASK;
-                          break;
-        case GDK_Control_L: case GDK_Control_R:
-                            state |= GDK_CONTROL_MASK;
-                            break;
+        /*  Update the state based on modifiers being pressed  */
+        case GDK_Alt_L: 
+        case GDK_Alt_R:
+          state |= GDK_MOD1_MASK;
+          break;
+        case GDK_Shift_L: 
+        case GDK_Shift_R:
+          state |= GDK_SHIFT_MASK;
+          break;
+        case GDK_Control_L: 
+        case GDK_Control_R:
+          state |= GDK_CONTROL_MASK;
+          break;
       }
 
       /*  We need this here in case of accelerators  */
@@ -578,15 +605,18 @@ gdisplay_canvas_events (GtkWidget *canvas,
 
       switch (kevent->keyval)
       {
-        case GDK_Alt_L: case GDK_Alt_R:
-                        state &= ~GDK_MOD1_MASK;
-                        break;
-        case GDK_Shift_L: case GDK_Shift_R:
-                          kevent->state &= ~GDK_SHIFT_MASK;
-                          break;
-        case GDK_Control_L: case GDK_Control_R:
-                            kevent->state &= ~GDK_CONTROL_MASK;
-                            break;
+        case GDK_Alt_L: 
+        case GDK_Alt_R:
+           state &= ~GDK_MOD1_MASK;
+           break;
+        case GDK_Shift_L: 
+        case GDK_Shift_R:
+           kevent->state &= ~GDK_SHIFT_MASK;
+           break;
+        case GDK_Control_L: 
+        case GDK_Control_R:
+           kevent->state &= ~GDK_CONTROL_MASK;
+           break;
       }
 
       return_val = TRUE;
@@ -594,7 +624,7 @@ gdisplay_canvas_events (GtkWidget *canvas,
 
     default:
       break;
-  }
+  }          /*  switch(event->type)  */
 
   if (no_cursor_updating == 0)
   {
@@ -630,8 +660,8 @@ gdisplay_canvas_events (GtkWidget *canvas,
 
 gint
 gdisplay_hruler_button_press (GtkWidget      *widget,
-    GdkEventButton *event,
-    gpointer        data)
+                              GdkEventButton *event,
+                              gpointer        data)
 {
   GDisplay *gdisp;
 
