@@ -19,6 +19,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <math.h>
+#include "libgimp/gimpintl.h"
 #include "appenv.h"
 #include "channel.h"
 #include "drawable.h"
@@ -618,7 +619,7 @@ gimp_drawable_configure  (
   g_return_if_fail (drawable != NULL);
 
   if (!name)
-    name = "unnamed";
+    name = _("unnamed");
   
   if (drawable->name) 
     g_free (drawable->name);
