@@ -19,6 +19,7 @@
 #include <string.h>
 #include <math.h>
 #include "../lib/version.h"
+#include "libgimp/gimpintl.h"
 #include "appenv.h"
 #include "actionarea.h"
 #include "expose_image.h"
@@ -250,6 +251,8 @@ expose_view_new_dialog (GDisplay* gdisp)
   GtkWidget *slider;
   GtkObject *data;
 
+  action_items[0].label = _("Ok");
+  action_items[1].label = _("Reset (LDR)");
   bcd = g_malloc_zero (sizeof (ExposeImageDialog));
   bcd->preview = TRUE;
   bcd->forceexpose = TRUE;
@@ -258,7 +261,7 @@ expose_view_new_dialog (GDisplay* gdisp)
   /*  The shell and main vbox  */
   bcd->shell = gtk_dialog_new ();
   gtk_window_set_wmclass (GTK_WINDOW (bcd->shell), "expose_view", PROGRAM_NAME);
-  gtk_window_set_title (GTK_WINDOW (bcd->shell), "expose-view");
+  gtk_window_set_title (GTK_WINDOW (bcd->shell), _("Expose View"));
   
   /* handle wm close signal */
   gtk_signal_connect (GTK_OBJECT (bcd->shell), "delete_event",
@@ -280,7 +283,7 @@ expose_view_new_dialog (GDisplay* gdisp)
   gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, FALSE, 0);
 
   /*  Create the expose scale widget  */
-  label = gtk_label_new ("expose");
+  label = gtk_label_new (_("expose"));
   gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 2, 2);
@@ -316,7 +319,7 @@ expose_view_new_dialog (GDisplay* gdisp)
 
   /*  Create the offset scale widget  */
 # if USE_OFFSET
-  label = gtk_label_new ("offset");
+  label = gtk_label_new (_("offset"));
   gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 2, 2);
@@ -351,7 +354,7 @@ expose_view_new_dialog (GDisplay* gdisp)
 #endif
 
   /*  Create the gamma scale widget  */
-  label = gtk_label_new ("gamma");
+  label = gtk_label_new (_("gamma"));
   gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1,
 # if USE_OFFSET
