@@ -34,6 +34,7 @@
 #include <errno.h>
 #include <stdlib.h>
 #include "../lib/version.h"
+#include "libgimp/gimpintl.h"
 #include "appenv.h"
 #include "actionarea.h"
 #include "cms.h"
@@ -234,10 +235,10 @@ static ProcArg register_magic_load_handler_args[] =
     "the name of the procedure to be used for loading" },
   { PDB_STRING,
     "extensions",
-    "comma separated list of extensions this handler can load (ie. \"jpeg,jpg\")" },
+    "comma separated list of extensions this handler can load (ie. \")jpeg,jpg\"" },
   { PDB_STRING,
     "prefixes",
-    "comma separated list of prefixes this handler can load (ie. \"http:,ftp:\")" },
+    "comma separated list of prefixes this handler can load (ie. \")http:,ftp:\"" },
   { PDB_STRING,
     "magics",
     "comma separated list of magic file information this handler can load (ie. \"0,string,GIF\")" },
@@ -424,7 +425,7 @@ register_magic_load_handler_invoker (Argument *args)
 	       (proc->args[2].arg_type != PDB_STRING) ||
 	       (proc->values[0].arg_type != PDB_IMAGE)))
     {
-      g_message ("load handler \"%s\" does not take the standard load handler args",
+      g_message (_("load handler \"%s\" does not take the standard load handler args"),
 		 (char*) args[0].value.pdb_pointer);
       goto done;
     }
@@ -436,7 +437,7 @@ register_magic_load_handler_invoker (Argument *args)
 
   if (!file_proc)
     {
-      g_message ("attempt to register non-existant load handler \"%s\"",
+      g_message (_("attempt to register non-existant load handler \"%s\""),
 		 (char*) args[0].value.pdb_pointer);
       goto done;
     }
@@ -470,7 +471,7 @@ register_save_handler_invoker (Argument *args)
 	       (proc->args[3].arg_type != PDB_STRING) ||
 	       (proc->args[4].arg_type != PDB_STRING)))
     {
-      g_message ("save handler \"%s\" does not take the standard save handler args",
+      g_message (_("save handler \"%s\" does not take the standard save handler args"),
 		 (char*) args[0].value.pdb_pointer);
       goto done;
     }
@@ -482,11 +483,11 @@ register_save_handler_invoker (Argument *args)
 
   if (!file_proc)
     {
-      g_message ("attempt to register non-existant save handler \"%s\"",
+      g_message (_("attempt to register non-existant save handler \"%s\""),
 		 (char*) args[0].value.pdb_pointer);
       goto done;
     }
-	d_printf("save_handler: %s\n",file_proc->extensions);
+	d_printf(_("save_handler: %s\n"),file_proc->extensions);
   save_procs = g_slist_prepend (save_procs, file_proc);
 
   success = TRUE;
@@ -520,7 +521,7 @@ file_reload_callback (GDisplay *gdisplay)
   warning_dialog = gtk_dialog_new ();
   gtk_window_set_wmclass (GTK_WINDOW (warning_dialog), "really_reload", PROGRAM_NAME);
   gtk_window_set_policy (GTK_WINDOW (warning_dialog), FALSE, FALSE, FALSE);
-  gtk_window_set_title (GTK_WINDOW (warning_dialog), "Warning");
+  gtk_window_set_title (GTK_WINDOW (warning_dialog), _("Warning"));
   gtk_object_set_user_data (GTK_OBJECT (warning_dialog), cur_gdisplay);
   gtk_widget_set_uposition(warning_dialog, generic_window_x, generic_window_y);
   layout_connect_window_position(warning_dialog, &generic_window_x, &generic_window_y, FALSE);
@@ -532,10 +533,14 @@ file_reload_callback (GDisplay *gdisplay)
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (warning_dialog)->vbox), vbox, TRUE, TRUE, 0);
   gtk_widget_show (vbox);
 
-  label = gtk_label_new ("Do you really want to revert to saved?");
+  label = gtk_label_new (_("Do you really want to revert to saved?"));
   gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, FALSE, 0);
   gtk_widget_show (label);
 
+  { int i;
+    for(i = 0; i < 2; ++i)
+      action_items[i].label = _(action_items[i].label);
+  }
   action_items[0].user_data = warning_dialog;
   action_items[1].user_data = warning_dialog;
   build_action_area (GTK_DIALOG (warning_dialog), action_items, 2, 0);
@@ -556,7 +561,7 @@ file_open_callback (GtkWidget *w,
     {/* char path[MAX_PATH];
 	 strcpy(path,GetDirHome());
 	 strcat(path,"/x.png");*/
-      fileload = gtk_file_selection_new ("Load Image");
+      fileload = gtk_file_selection_new (_("Load Image"));
 /*	 gtk_file_selection_set_filename(GTK_FILE_SELECTION(fileload),path);
     gtk_clist_set_text(GTK_CLIST(GTK_FILE_SELECTION(fileload)->dir_list),0,0,path);
 
@@ -592,14 +597,14 @@ file_open_callback (GtkWidget *w,
 	return;
 
       gtk_file_selection_set_filename (GTK_FILE_SELECTION(fileload), "./");
-      gtk_window_set_title (GTK_WINDOW (fileload), "Load Image");
+      gtk_window_set_title (GTK_WINDOW (fileload), _("Load Image"));
     }
 
   gdisplay = gdisplay_active ();
 
   if (!open_options)
     {
-      open_options = gtk_frame_new ("Open Options");
+      open_options = gtk_frame_new (_("Open Options"));
       gtk_frame_set_shadow_type (GTK_FRAME (open_options), GTK_SHADOW_ETCHED_IN);
 
       hbox = gtk_hbox_new (FALSE, 1);
@@ -607,7 +612,7 @@ file_open_callback (GtkWidget *w,
       gtk_container_add (GTK_CONTAINER (open_options), hbox);
       gtk_widget_show (hbox);
 
-      label = gtk_label_new ("Determine file type:");
+      label = gtk_label_new (_("Determine file type:"));
       gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, TRUE, 0);
       gtk_widget_show (label);
 
@@ -678,7 +683,7 @@ file_save_as_callback (GtkWidget *w,
 
   if (!filesave)
     {
-      filesave = gtk_file_selection_new ("Save Image");
+      filesave = gtk_file_selection_new (_("Save Image"));
       gtk_window_set_wmclass (GTK_WINDOW (filesave), "save_image", PROGRAM_NAME);
       gtk_window_position (GTK_WINDOW (filesave), GTK_WIN_POS_MOUSE);
       gtk_signal_connect_object (GTK_OBJECT (GTK_FILE_SELECTION (filesave)->cancel_button),
@@ -700,13 +705,17 @@ file_save_as_callback (GtkWidget *w,
 	return;
 
       gtk_file_selection_set_filename (GTK_FILE_SELECTION(filesave), "./");
-      gtk_window_set_title (GTK_WINDOW (filesave), "Save Image");
+      gtk_window_set_title (GTK_WINDOW (filesave), _("Save Image"));
     }
 
   if (!save_layer)
   {
+    const char *file_name = NULL;
     gdisplay = gdisplay_active ();
     image_ID = gdisplay->gimage->ID;
+    file_name = gimage_filename(gdisplay->gimage);
+    if(file_name)
+      gtk_file_selection_set_filename (GTK_FILE_SELECTION(filesave), file_name);
   }
   else
   {
@@ -715,7 +724,7 @@ file_save_as_callback (GtkWidget *w,
   }
   if (!save_options)
     {
-      save_options = gtk_frame_new ("Save Options");
+      save_options = gtk_frame_new (_("Save Options"));
       gtk_frame_set_shadow_type (GTK_FRAME (save_options), GTK_SHADOW_ETCHED_IN);
 
       hbox = gtk_hbox_new (FALSE, 1);
@@ -723,7 +732,7 @@ file_save_as_callback (GtkWidget *w,
       gtk_container_add (GTK_CONTAINER (save_options), hbox);
       gtk_widget_show (hbox);
 
-      label = gtk_label_new ("Determine file type:");
+      label = gtk_label_new (_("Determine file type:"));
       gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, TRUE, 0);
       gtk_widget_show (label);
 
@@ -769,7 +778,7 @@ file_save_copy_as_callback (GtkWidget *w,
 
   if (!filesave)
     {
-      filesave = gtk_file_selection_new ("Save Image");
+      filesave = gtk_file_selection_new (_("Save Image"));
       gtk_window_set_wmclass (GTK_WINDOW (filesave), "save_image", PROGRAM_NAME);
       gtk_window_position (GTK_WINDOW (filesave), GTK_WIN_POS_MOUSE);
       gtk_signal_connect_object (GTK_OBJECT (GTK_FILE_SELECTION (filesave)->cancel_button),
@@ -791,7 +800,7 @@ file_save_copy_as_callback (GtkWidget *w,
 	return;
 
       gtk_file_selection_set_filename (GTK_FILE_SELECTION(filesave), "./");
-      gtk_window_set_title (GTK_WINDOW (filesave), "Save Image");
+      gtk_window_set_title (GTK_WINDOW (filesave), _("Save Image"));
     }
 
   gdisplay = gdisplay_active ();
@@ -799,7 +808,7 @@ file_save_copy_as_callback (GtkWidget *w,
 
   if (!save_options)
     {
-      save_options = gtk_frame_new ("Save Options");
+      save_options = gtk_frame_new (_("Save Options"));
       gtk_frame_set_shadow_type (GTK_FRAME (save_options), GTK_SHADOW_ETCHED_IN);
 
       hbox = gtk_hbox_new (FALSE, 1);
@@ -807,7 +816,7 @@ file_save_copy_as_callback (GtkWidget *w,
       gtk_container_add (GTK_CONTAINER (save_options), hbox);
       gtk_widget_show (hbox);
 
-      label = gtk_label_new ("Determine file type:");
+      label = gtk_label_new (_("Determine file type:"));
       gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, TRUE, 0);
       gtk_widget_show (label);
 
@@ -969,29 +978,6 @@ file_load (char *filename, char* raw_filename, GDisplay *gdisplay)
       /*  set the image to clean  */
       gimage_clean_all (gimage);
 
-      /* assign profile according to cms_open_action */
-      if (!gimage_get_cms_profile(gimage) &&
-	   (cms_open_action == CMS_ASSIGN_DEFAULT) &&
-	   (cms_default_image_profile_name != NULL)) 
-      {   gimage_set_cms_profile(gimage, cms_get_profile_from_file(cms_default_image_profile_name));
-      }
-      /* assign proof profile allways */
-      if (!gimage_get_cms_proof_profile(gimage) &&
-           (cms_default_proof_profile_name != NULL)) 
-      {   gimage_set_cms_proof_profile(gimage, cms_get_profile_from_file(cms_default_proof_profile_name));
-      }
- 		          
-      /* if a workspace profile is given and it's not equal the 
-	 image profile, check whether to convert */
-      if ((cms_workspace_profile_name != NULL) && (gimage_get_cms_profile(gimage) != NULL))
-      {   CMSProfile *workspace_profile = cms_get_profile_from_file(cms_workspace_profile_name);
-          if ((gimage_get_cms_profile(gimage) != workspace_profile) &&
-	      ((cms_mismatch_action == CMS_MISMATCH_AUTO_CONVERT)  || 
-	       ((cms_mismatch_action == CMS_MISMATCH_PROMPT) && (cms_convert_on_open_prompt(gimage)==TRUE))))
-          {   convert_image_colorspace(gimage, workspace_profile, cms_default_intent);
-          }
-      } 
-
       /*  display the image */
       gdisplay->gimage = gimage;
       gimage_set_filename (gimage, filename);
@@ -1054,13 +1040,14 @@ file_load_without_display (char *filename, char* raw_filename, GDisplay *gdispla
       /*  set the image to clean  */
       gimage_clean_all (gimage);
       /* assign profile according to cms_open_action */
-      if (!gimage_get_cms_profile(gimage) &&
-           (cms_open_action == CMS_ASSIGN_DEFAULT) &&
-	   (cms_default_image_profile_name != NULL)) 
-      {   gimage_set_cms_profile(gimage, cms_get_profile_from_file(cms_default_image_profile_name));
-      }
-      else if (cms_open_action == CMS_ASSIGN_PROMPT)
-      {   cms_open_assign_dialog(gimage);
+      if (!gimage_get_cms_profile(gimage))
+      { if ((cms_open_action == CMS_ASSIGN_DEFAULT) &&
+	        (cms_default_image_profile_name != NULL)) 
+        { gimage_set_cms_profile(gimage, cms_get_profile_from_file(cms_default_image_profile_name));
+        }
+        else if (cms_open_action == CMS_ASSIGN_PROMPT)
+        { cms_open_assign_dialog(gimage);
+        }
       }
 
       /* assign proof profile allways */
@@ -1076,7 +1063,9 @@ file_load_without_display (char *filename, char* raw_filename, GDisplay *gdispla
           if ((gimage_get_cms_profile(gimage) != workspace_profile) &&
 	      ((cms_mismatch_action == CMS_MISMATCH_AUTO_CONVERT)  || 
 	       ((cms_mismatch_action == CMS_MISMATCH_PROMPT) && (cms_convert_on_open_prompt(gimage)==TRUE))))
-	  {   convert_image_colorspace(gimage, workspace_profile, cms_default_intent);
+	  {  convert_image_colorspace(gimage, workspace_profile, cms_default_intent,
+                       cms_default_flags & cmsFLAGS_WHITEBLACKCOMPENSATION ?
+                       cmsFLAGS_WHITEBLACKCOMPENSATION : 0 );
 	  }
       } 
    }
@@ -1140,13 +1129,15 @@ file_open (char *filename, char* raw_filename)
       gimage_clean_all (gimage);
 
       /* assign profile according to cms_open_action */
-      if (!gimage_get_cms_profile(gimage) &&
-           (cms_open_action == CMS_ASSIGN_DEFAULT) &&
-           (cms_default_image_profile_name != NULL)) 
-      {   gimage_set_cms_profile(gimage, cms_get_profile_from_file(cms_default_image_profile_name));
-      }
-      else if (cms_open_action == CMS_ASSIGN_PROMPT)
-      {   cms_open_assign_dialog(gimage);
+      if (!gimage_get_cms_profile(gimage))
+      { 
+        if ((cms_open_action == CMS_ASSIGN_DEFAULT) &&
+            (cms_default_image_profile_name != NULL))
+        { gimage_set_cms_profile(gimage, cms_get_profile_from_file(cms_default_image_profile_name));
+        }
+        else if (cms_open_action == CMS_ASSIGN_PROMPT)
+        { cms_open_assign_dialog(gimage);
+        }
       }
       /* assign proof profile allways */
       if (!gimage_get_cms_proof_profile(gimage) &&
@@ -1161,7 +1152,10 @@ file_open (char *filename, char* raw_filename)
           if ((gimage_get_cms_profile(gimage) != workspace_profile) &&
                ((cms_mismatch_action == CMS_MISMATCH_AUTO_CONVERT)  || 
                ((cms_mismatch_action == CMS_MISMATCH_PROMPT) && (cms_convert_on_open_prompt(gimage)==TRUE))))
-          {   convert_image_colorspace(gimage, workspace_profile, cms_default_intent);
+          {   convert_image_colorspace(gimage, workspace_profile,
+                       cms_default_intent,
+                       cms_default_flags & cmsFLAGS_WHITEBLACKCOMPENSATION ?
+                       cmsFLAGS_WHITEBLACKCOMPENSATION : 0 );
           }
       } 
 
@@ -1386,7 +1380,7 @@ file_open_ok_callback (GtkWidget *w,
       return;
     }
 
-  s = g_string_new ("Open failed: ");
+  s = g_string_new (_("Open failed: "));
 
   g_string_append (s, raw_filename);
 
@@ -1486,7 +1480,7 @@ file_save_ok_callback (GtkWidget *w,
   
   if (!filename && !raw_filename)
   {
-    s = g_string_new ("Save failed: ");
+    s = g_string_new (_("Save failed: "));
     g_string_append (s, orig_raw_filename);
     message_box (s->str, file_message_box_close_callback, (void *) fs);
     if (filename) g_free( filename);
@@ -1518,7 +1512,7 @@ file_save_ok_callback (GtkWidget *w,
       else
 	{
 	  s = g_string_new (NULL);
-	  g_string_sprintf (s, "%s is an irregular file (%s)", raw_filename, g_strerror(errno));
+	  g_string_sprintf (s, _("%s is an irregular file (%s)"), raw_filename, g_strerror(errno));
 	}
     } 
     else 
@@ -1535,7 +1529,7 @@ file_save_ok_callback (GtkWidget *w,
 	}
       else
 	{
-	  s = g_string_new ("Save failed22: ");
+	  s = g_string_new (_("Save failed22: "));
 	  g_string_append (s, raw_filename);
 	}
     }
@@ -1581,6 +1575,10 @@ file_overwrite (char *filename, char* raw_filename)
     { "Yes", file_overwrite_yes_callback, NULL, NULL },
     { "No", file_overwrite_no_callback, NULL, NULL }
   };
+  { int i;
+    for(i = 0; i < 2; ++i)
+      obox_action_items[i].label = _(obox_action_items[i].label);
+  }
 
   OverwriteBox *overwrite_box;
   GtkWidget *vbox;
@@ -1588,14 +1586,14 @@ file_overwrite (char *filename, char* raw_filename)
   char *overwrite_text;
 
   overwrite_box = (OverwriteBox *) g_malloc_zero (sizeof (OverwriteBox));
-  overwrite_text = (char *) g_malloc (strlen (" exists, overwrite?") + strlen (filename) + 1);
-  sprintf (overwrite_text, "%s exists, overwrite?", filename);
+  overwrite_text = (char *) g_malloc (strlen (_(" exists, overwrite?")) + strlen (filename) + 1);
+  sprintf (overwrite_text, _("%s exists, overwrite?"), filename);
 
   overwrite_box->full_filename = filename;
   overwrite_box->raw_filename = raw_filename;
   overwrite_box->obox = gtk_dialog_new ();
   gtk_window_set_wmclass (GTK_WINDOW (overwrite_box->obox), "file_exists", PROGRAM_NAME);
-  gtk_window_set_title (GTK_WINDOW (overwrite_box->obox), "File Exists!");
+  gtk_window_set_title (GTK_WINDOW (overwrite_box->obox), _("File Exists!"));
   gtk_widget_set_uposition(overwrite_box->obox, generic_window_x, generic_window_y);
   layout_connect_window_position(overwrite_box->obox, &generic_window_x, &generic_window_y, FALSE);
   minimize_register(overwrite_box->obox);
@@ -1644,7 +1642,7 @@ file_overwrite_yes_callback (GtkWidget *w,
     {
       GString* s;
 
-      s = g_string_new ("Save failed3: ");
+      s = g_string_new (_("Save failed3: "));
 
       g_string_append (s, overwrite_box->raw_filename);
 
@@ -2072,7 +2070,8 @@ file_temp_clear()
 
 	sprintf (full_file_path, "%s/%s", temp_path, file_name);
 	remove(full_file_path);
-    }   
+    }
+    if(dir) closedir(dir);
 }
 
 static Argument*
