@@ -17,6 +17,7 @@
  */
 #include <stdio.h>
 #include <stdlib.h>
+#include "libgimp/gimpintl.h"
 #include "appenv.h"
 #include "buildmenu.h"
 #include "channels_dialog.h"
@@ -143,6 +144,8 @@ gdisplay_new (GImage       *gimage,
   gdisp->cms_intent = cms_default_intent;
   gdisp->cms_flags = cms_default_flags;
   gdisp->look_profile_pipe = NULL;
+  gdisp->cms_expensive_transf = calloc( sizeof(CMSTransform*), 1);
+  *gdisp->cms_expensive_transf = NULL;
 
   /*  add the new display to the list so that it isn't lost  */
   display_list = g_slist_append (display_list, (void *) gdisp);
@@ -167,15 +170,18 @@ gdisplay_new (GImage       *gimage,
   while (cur_slist != NULL) {
     fac_item = (GtkItemFactoryItem *) cur_slist->data; 
     cur_wid_list = fac_item->widgets;
+    //printf("%s:%d %s() Adding factory component: %s %s |\n", __FILE__,__LINE__,__func__,
+     //     fac_item->path);
 
     while (cur_wid_list != NULL) { 
 
       if( strcmp("GtkTearoffMenuItem",
           gtk_type_query(GTK_OBJECT_TYPE(cur_wid_list->data))->type_name) != 0)
       {
-#       ifdef DEBUG
-        printf("%s:%d %s() Adding factory component: %s\n", __FILE__,__LINE__,__func__,
-          gtk_type_query(GTK_OBJECT_TYPE(cur_wid_list->data))->type_name);
+#       ifdef DEBUG_
+        printf("%s:%d %s() Adding factory component: %s %s |\n", __FILE__,__LINE__,__func__,
+          gtk_type_query(GTK_OBJECT_TYPE(cur_wid_list->data))->type_name,
+          ((GtkItemFactoryItem *) cur_wid_list->data)->path);
 #       endif
         g_hash_table_insert(display_ht, cur_wid_list->data, gdisp); 
       }
@@ -189,9 +195,14 @@ gdisplay_new (GImage       *gimage,
 
   gdisplays_update_title (gimage->ID); 
 
+  if(cms_bpc_by_default)
+    gdisp->cms_flags = gdisp->cms_flags | cmsFLAGS_WHITEBLACKCOMPENSATION;
+  if(cms_manage_by_default)
+    gdisplay_set_bpc(gdisp, cms_bpc_by_default);
+  gdisp->cms_proof_flags = cms_default_proof_intent;
 
   if (gdisplay_set_colormanaged(gdisp, cms_manage_by_default) == FALSE)	 
-  {   g_message("Cannot colormanage this display.\nEither image or display profile are undefined.\n. To avoid this message switch off automatic colormanagement in File/Preferences/Color Management");
+  {   g_message(_(_("Cannot colormanage this display.\nEither image or display profile are undefined.\n. To avoid this message switch off automatic colormanagement in File/Preferences/Color Management")));
   }
 
   return gdisp;
@@ -208,7 +219,7 @@ gdisplay_fm (GImage *gimage,
 
  return display;
 }
-        
+
 
 static void
 gdisplay_format_title (GImage *gimage,
@@ -220,32 +231,38 @@ gdisplay_format_title (GImage *gimage,
   const char *colour = 0;
   char *alpha_msg = ""; /*"no alpha";*/
   const char *profile;
+  char *proof = NULL;
 
   if (layer_has_alpha(gimage->active_layer)){
-    alpha_msg = "A"; /*"alpha";*/
+    alpha_msg = _("A"); /*"alpha";*/
   }
 
   if (gimage_get_cms_profile(gimage) != NULL)
   {   profile = cms_get_profile_info(gimage_get_cms_profile(gimage))->description;
+      if (gdisplay_is_proofed (gdisp))
+        proof = g_strdup(cms_get_profile_info(gimage_get_cms_proof_profile(gimage))->description);
       colour = cms_get_profile_info(gimage->cms_profile)->color_space_name;
       if(strstr(colour,"Cmyk"))
           alpha_msg = "";
   }
   else 
-  {   profile = "[no icc profile assigned]";
+  {   profile = _("[no icc profile assigned]");
   }
 
 
 
-  sprintf (title, "%s-%d.%d (%s - %s%s - %s)%s %d%%",
+  sprintf (title, "%s-%d.%d (%s - %s%s - %s%s%s)%s %d%%",
 	   prune_filename (gimage_filename (gimage)),
 	   gimage->ID, gimage->instance_count,
 	   tag_string_precision (tag_precision (t)),
 	   colour ? colour : tag_string_format (tag_format (t)),
 	   alpha_msg,
 	   profile,
-           empty ? " (empty)" : "",
+           proof ? _(" | proof: ") : "",
+           proof ? proof : "",
+           empty ? _(" (empty)") : "",
 	   100 * SCALEDEST (gdisp) / SCALESRC (gdisp));
+  if (proof) g_free (proof);
 
   if (gdisp->current_cursor != -1 )
   change_win_cursor (gdisp->canvas->window, gdisp->current_cursor); 
@@ -323,6 +340,11 @@ gdisplay_delete (GDisplay *gdisp)
   /* free the profile pipe */
   g_slist_free(gdisp->look_profile_pipe); 
 
+  /* free the stored transform */
+  if(*gdisp->cms_expensive_transf)
+    cms_return_transform ( *gdisp->cms_expensive_transf );
+  free (gdisp->cms_expensive_transf);
+
   if (gdisp->scroll_gc)
     gdk_gc_destroy (gdisp->scroll_gc);
 
@@ -1405,12 +1427,21 @@ gdisplay_set_menu_sensitivity (GDisplay *gdisp)
       menus_set_state (buff, TRUE);
       menus_set_state ("<Image>/View/Rendering Intent/Absolute Colorimetric", TRUE);
   }
-  g_snprintf(buff, 1024, "<Image%d>/View/Colormanage Display", gdisp->unique_id);
+  g_snprintf(buff, 1024, "<Image%d>/View/Rendering Intent/Black Point Compensation", gdisp->unique_id);
+  menus_set_state (buff,  (gdisp->cms_flags & cmsFLAGS_WHITEBLACKCOMPENSATION) != 0);
+  menus_set_state ("<Image>/View/Rendering Intent/Black Point Compensation", (gdisp->cms_flags & cmsFLAGS_WHITEBLACKCOMPENSATION) != 0);
+ g_snprintf(buff, 1024, "<Image%d>/View/Colormanage Display", gdisp->unique_id);
   menus_set_state (buff, gdisp->colormanaged && format == FORMAT_RGB);
   menus_set_state ("<Image>/View/Colormanage Display", gdisp->colormanaged && format == FORMAT_RGB);
   g_snprintf(buff, 1024, "<Image%d>/View/Proof Display", gdisp->unique_id);
   menus_set_state (buff,  (gdisp->cms_flags & cmsFLAGS_SOFTPROOFING) != 0);
   menus_set_state ("<Image>/View/Proof Display", (gdisp->cms_flags & cmsFLAGS_SOFTPROOFING) != 0);
+  g_snprintf(buff, 1024, "<Image%d>/View/Simulatate Paper", gdisp->unique_id);
+  menus_set_state (buff, gdisp->cms_proof_flags == INTENT_ABSOLUTE_COLORIMETRIC);
+  menus_set_state ("<Image>/View/Simulatate Paper", gdisp->cms_proof_flags == INTENT_ABSOLUTE_COLORIMETRIC);
+  #ifdef DEBUG
+    printf("%s:%d Simulate Paper?: %d\n",__FILE__,__LINE__, gdisp->cms_proof_flags == INTENT_ABSOLUTE_COLORIMETRIC);
+  #endif
   g_snprintf(buff, 1024, "<Image%d>/View/Gamut Check Display", gdisp->unique_id);
   menus_set_state (buff, (gdisp->cms_flags & cmsFLAGS_GAMUTCHECK) != 0);
   menus_set_state ("<Image>/View/Gamut Check Display", (gdisp->cms_flags & cmsFLAGS_GAMUTCHECK) != 0);
@@ -1466,6 +1497,7 @@ gdisplay_expose_full (GDisplay *gdisp)
 void
 gdisplay_update_full (GDisplay *gdisp)
 {
+  gdisplays_update_title (gdisp-> ID);
   gdisplay_add_update_area (gdisp, 0, 0,
 			     gdisp->gimage->width,
 			     gdisp->gimage->height);
@@ -1483,6 +1515,7 @@ gdisplay_active ()
   GtkWidget *cur_widget;
   GdkEvent *event;
   GDisplay *gdisp = NULL;
+  static GDisplay *old_gdisp = NULL;
 
   /*  If the popup shell is valid, then get the gdisplay associated with that shell  */
   event = gtk_get_current_event ();
@@ -1490,7 +1523,9 @@ gdisplay_active ()
   if (event) gdk_event_free (event);
 
   if (event_widget == NULL)
-    return NULL;
+  {
+    return (gdisplay_to_ID( old_gdisp ) >= 0) ? old_gdisp : NULL;
+  }
 
   cur_widget = event_widget;
 
@@ -1499,9 +1534,10 @@ gdisplay_active ()
       gdisp = g_hash_table_lookup (display_ht, cur_widget);
 
       if (gdisp) {
-#       ifdef DEBUG
+#       ifdef DEBUG_
         printf("%s:%d %s() %s -> %d  0x%x\n",__FILE__,__LINE__,__func__, gtk_type_query(GTK_OBJECT_TYPE(cur_widget))->type_name, gdisp?gdisp->ID:-1, (int)gdisp);
 #       endif
+        old_gdisp = gdisp;
         return gdisp;
       }
 
@@ -1512,6 +1548,7 @@ gdisplay_active ()
   if (popup_shell)
     {
       gdisp = gtk_object_get_user_data (GTK_OBJECT (popup_shell));
+      old_gdisp = gdisp;
       return gdisp;
     }
 
@@ -1870,6 +1907,7 @@ gdisplays_flush ()
 {
   static int flushing = FALSE;
   GSList *list = display_list;
+  int lc_can_flush = 0;
 
   /*  no flushing necessary without an interface  */
   if (no_interface)
@@ -1885,13 +1923,18 @@ gdisplays_flush ()
   while (list)
     {
       gdisplay_flush ((GDisplay *) list->data);
+      if(!sfm_plays((GDisplay *) list->data))
+        lc_can_flush = 1;
       list = g_slist_next (list);
     }
 
-  /*  for convenience, we call the layers dialog flush here  */
-  layers_dialog_flush ();
-  /*  for convenience, we call the channels dialog flush here  */
-  channels_dialog_flush ();
+  if (lc_can_flush)
+  {
+    /*  for convenience, we call the layers dialog flush here  */
+    layers_dialog_flush ();
+    /*  for convenience, we call the channels dialog flush here  */
+    channels_dialog_flush ();
+  }
 
   flushing = FALSE;
 }
@@ -1942,11 +1985,11 @@ gboolean
 gdisplay_set_colormanaged(GDisplay *display, gboolean colormanaged)
 {   if (colormanaged != display->colormanaged)
     {   if ((colormanaged == TRUE) && (gimage_get_cms_profile(display->gimage) == NULL))
-        {   g_warning("gdisplay_set_colormanaged: cannot colormanage. no display profile defined");  
+        {   g_warning("gdisplay_set_colormanaged: cannot colormanage. no image profile defined");  
    	    return FALSE;
 	}
         if ((colormanaged == TRUE) && (cms_display_profile_name == NULL))
-	{   g_warning("gdisplay_set_colormanaged: cannot colormanage. no image profile defined");
+	{   g_warning("gdisplay_set_colormanaged: cannot colormanage. no display profile defined");
             return FALSE;
 	}
 
@@ -1957,6 +2000,51 @@ gdisplay_set_colormanaged(GDisplay *display, gboolean colormanaged)
 	gdisplay_flush (display);
     }
 
+    lc_dialog_update( display->gimage );
+
+    return TRUE;
+}
+
+gboolean
+gdisplay_set_bpc(GDisplay *display, gboolean set)
+{   if (set != (display->cms_flags & cmsFLAGS_WHITEBLACKCOMPENSATION))
+    {   if(set == TRUE)
+          if(gdisplay_set_colormanaged(display, set) == FALSE)
+            return FALSE;
+        if ((set == TRUE) && (cms_display_profile_name == NULL))
+        {   g_warning("gdisplay_set_bpc: cannot colormanage. no display profile defined");  
+            return FALSE;
+        }
+
+        display->cms_flags = set ? display->cms_flags | cmsFLAGS_WHITEBLACKCOMPENSATION :
+                                 display->cms_flags & (~cmsFLAGS_WHITEBLACKCOMPENSATION) ;
+
+        /* and update */
+        gdisplay_update_full (display);
+        gdisplay_flush (display);
+    }
+
+    return TRUE;
+}
+
+gboolean
+gdisplay_set_paper_simulation(GDisplay *display, gboolean set)
+{   if (set != gdisplay_has_paper_simulation(display) )
+    {   if(set == TRUE)
+          if(gdisplay_set_proofed(display, set) == FALSE)
+            return FALSE;
+        if ((set == TRUE) && (cms_display_profile_name == NULL))
+        {   g_warning("gdisplay_set_paper_simulation: cannot colormanage. no display profile defined");  
+            return FALSE;
+        }
+
+        display->cms_proof_flags = set ? INTENT_ABSOLUTE_COLORIMETRIC : INTENT_RELATIVE_COLORIMETRIC;
+
+        /* and update */
+        gdisplay_update_full (display);
+        gdisplay_flush (display);
+    }
+
     return TRUE;
 }
 
