@@ -207,13 +207,18 @@ gdisplay_active_invoker (Argument *args)
 
   success = ((gdisp = gdisplay_active ()) != NULL);
 
+# ifdef DEBUG
+  printf("%s:%d %s() disp %d success %d\n", __FILE__,__LINE__,__func__,(intptr_t)gdisp, success);
+  if(gdisp)
+    printf("%s:%d %s() disp->ID %d\n", __FILE__,__LINE__,__func__,gdisp->ID);
+# endif
   
   /*  create the new image  */
-  return_args = procedural_db_return_args (&gdisplay_new_proc, success);
+  return_args = procedural_db_return_args (&gdisplay_active_proc, success);
 
 
   if (success)
-    return_args[0].value.pdb_int = gdisp->ID;
+    return_args[1].value.pdb_int = gdisp->ID;
 
   return return_args;
 }
@@ -381,6 +386,8 @@ ProcRecord gdisplays_flush_proc =
 
 
 
+/*****************************/
+
 /*****************************/
 /*  GDISPLAY_GET_CMS_INTENT  */
 
@@ -388,23 +395,34 @@ static Argument *
 gdisplay_get_cms_intent_invoker (Argument *args)
 {
   GDisplay *gdisp;
+  gint type = 0;
 
   gdisp = NULL;
 
   success = TRUE;
   if (success)
     {
-      int_value = args[0].value.pdb_int;
+      int_value  = args[0].value.pdb_int;
       if ((gdisp = gdisplay_get_ID (int_value)) == NULL)
 	success = FALSE;
 
+      type       = args[1].value.pdb_int;
     }
 
   return_args = procedural_db_return_args (&gdisplay_get_cms_intent_proc, success);
 
 
   if (success)
-    return_args[1].value.pdb_int = gdisp->cms_intent;
+    switch(type)
+      {
+      case 0: /* Image Profile */
+            return_args[1].value.pdb_int = gdisp->cms_intent;
+            break;
+      case 1: /* Proof Profile */
+            return_args[1].value.pdb_int = gdisplay_has_paper_simulation(gdisp)?
+                INTENT_ABSOLUTE_COLORIMETRIC : INTENT_RELATIVE_COLORIMETRIC;
+            break;
+      }
 
   return return_args;
 }
@@ -412,10 +430,14 @@ gdisplay_get_cms_intent_invoker (Argument *args)
 /*  The procedure definition  */
 ProcArg gdisplay_get_cms_intent_args[] =
 {
-    { PDB_DISPLAY,
-      "display",
-      "the display"
-    }
+  { PDB_DISPLAY,
+    "display",
+    "the display"
+  },
+  { PDB_INT32,
+    "type",
+    "The type of the Profile. 0 = Image Profile / 1 = Proof Profile"
+  }
 };
 
 ProcArg gdisplay_get_cms_intent_out_args[] =
@@ -437,7 +459,7 @@ ProcRecord gdisplay_get_cms_intent_proc =
   PDB_INTERNAL,
 
   /*  Input arguments  */
-  1,
+  2,
   gdisplay_get_cms_intent_args,
 
   /*  Output arguments  */
@@ -458,20 +480,32 @@ gdisplay_set_cms_intent_invoker (Argument *args)
 {
   GDisplay *gdisp;
   int old_intent;
+  gint type = 0;
 
   gdisp = NULL;
 
   success = TRUE;
   if (success)
     {
-      int_value = args[0].value.pdb_int;
+      int_value  = args[0].value.pdb_int;
       if ((gdisp = gdisplay_get_ID (int_value)) == NULL)
 	success = FALSE;
       old_intent = gdisp->cms_intent;
+      type       = args[2].value.pdb_int;
     }
 
   if (success)
-    gdisplay_set_cms_intent (gdisp, args[1].value.pdb_int);
+    switch(type)
+      {
+      case 0: /* Image Profile */
+            gdisplay_set_cms_intent (gdisp, args[1].value.pdb_int);
+            break;
+      case 1: /* Proof Profile */
+            gdisplay_set_paper_simulation (gdisp,
+            (args[1].value.pdb_int & INTENT_ABSOLUTE_COLORIMETRIC) ?
+             TRUE : FALSE);
+            break;
+      }
 
   return_args = procedural_db_return_args (&gdisplay_set_cms_intent_proc, success);
 
@@ -488,21 +522,26 @@ ProcArg gdisplay_set_cms_intent_args[] =
     { PDB_INT32,
       "intent",
       "the new rendering intent"
-    }
+    },
+  { PDB_INT32,
+    "type",
+    "The type of the Profile. 0 = Image Profile / 1 = Proof Profile"
+  }
+
 };
 
 ProcRecord gdisplay_set_cms_intent_proc =
 {
   "gimp_display_set_cms_intent",
-  "Sets the rendering intent for the specified display.",
-  "Sets the rendering intent for the specified display.",
-  "Stefan Klein",
-  "Stefan Klein",
-  "2004",
+  "Sets the rendering intent for the specified display and profile.",
+  "Sets the rendering intent for the specified display and profile.",
+  "Stefan Klein, Kai-Uwe Behrmann",
+  "Stefan Klein, Kai-Uwe Behrmann",
+  "2004-2006",
   PDB_INTERNAL,
 
   /*  Input arguments  */
-  2,
+  3,
   gdisplay_set_cms_intent_args,
 
   /*  Output arguments  */
@@ -655,6 +694,7 @@ static Argument *
 gdisplay_is_colormanaged_invoker (Argument *args)
 {
   GDisplay *gdisp;
+  gint type = 0;
 
   gdisp = NULL;
 
@@ -664,13 +704,22 @@ gdisplay_is_colormanaged_invoker (Argument *args)
       int_value = args[0].value.pdb_int;
       if ((gdisp = gdisplay_get_ID (int_value)) == NULL)
 	success = FALSE;
+      type       = args[1].value.pdb_int;
     }
 
   return_args = procedural_db_return_args (&gdisplay_is_colormanaged_proc, success);
 
 
   if (success)
-    return_args[1].value.pdb_int = gdisp->colormanaged;
+    switch(type)
+      {
+      case 0: /* Image Profile */
+            return_args[1].value.pdb_int = gdisp->colormanaged;
+            break;
+      case 1: /* Proof Profile */
+            return_args[1].value.pdb_int = gdisplay_is_proofed (gdisp);
+            break;
+      }
 
   return return_args;
 }
@@ -681,7 +730,12 @@ ProcArg gdisplay_is_colormanaged_args[] =
     { PDB_DISPLAY,
       "display",
       "the display"
-    }
+    },
+  { PDB_INT32,
+    "type",
+    "The type of the Profile. 0 = Image Profile / 1 = Proof Profile"
+  }
+
 };
 
 ProcArg gdisplay_is_colormanaged_out_args[] =
@@ -698,13 +752,13 @@ ProcRecord gdisplay_is_colormanaged_proc =
   "gimp_display_is_colormanaged",
   "Returns true if the specified display is colormanaged.",
   "Returns true if the specified display is colormanaged.",
-  "Stefan Klein",
-  "Stefan Klein",
-  "2004",
+  "Stefan Klein, Kai-Uwe Behrmann",
+  "Stefan Klein, Kai-Uwe Behrmann",
+  "2004-2006",
   PDB_INTERNAL,
 
   /*  Input arguments  */
-  1,
+  2,
   gdisplay_is_colormanaged_args,
 
   /*  Output arguments  */
