@@ -19,6 +19,7 @@
 #include <stdio.h>
 #include <string.h>
 #include "../lib/version.h"
+#include "libgimp/gimpintl.h"
 #include "appenv.h"
 #include "actionarea.h"
 #include "colormaps.h"
@@ -318,8 +319,12 @@ gdisplay_close_warning_dialog (char     *image_name,
   GtkWidget *mbox;
   GtkWidget *vbox;
   GtkWidget *label;
-  char *warning_buf;
+  char *warning_buf, *tmp;
 
+  { int i;
+    for(i = 0; i < 2; ++i)
+      mbox_action_items[i].label = _(mbox_action_items[i].label);
+  }
   /* FIXUP this will raise any prexsisting close dialogs, which can be a
      a bit confusing if you tried to close a new window because you had
      forgotten the old dialog was still around */
@@ -354,8 +359,9 @@ gdisplay_close_warning_dialog (char     *image_name,
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (mbox)->vbox), vbox, TRUE, TRUE, 0);
   gtk_widget_show (vbox);
 
-  warning_buf = (char *) g_malloc (strlen (image_name) + 50);
-  sprintf (warning_buf, "Changes made to %s.  Close anyway?", image_name);
+  tmp = _("Changes made to %s.  Close anyway?");
+  warning_buf = (char *) g_malloc (strlen (image_name) + strlen (tmp) + 1);
+  sprintf (warning_buf, tmp, image_name);
   label = gtk_label_new (warning_buf);
   gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, FALSE, 0);
   gtk_widget_show (label);
