@@ -24,6 +24,7 @@
 #include <stdlib.h>
 #include <sys/stat.h>
 #include <unistd.h>
+#include "libgimp/gimpintl.h"
 #include "../lib/version.h"
 #include "appenv.h"
 #include "actionarea.h"
@@ -90,12 +91,6 @@ install_verify (InstallCallback install_callback)
 static void
 install_help (InstallCallback callback)
 {
-  static ActionAreaItem action_items[] =
-  {
-    { "Install", help_install_callback, NULL, NULL },
-    { "Ignore", help_ignore_callback, NULL, NULL },
-    { "Quit", help_quit_callback, NULL, NULL }
-  };
   GtkWidget *text;
   GtkWidget *table;
   GtkWidget *vsb;
@@ -103,6 +98,16 @@ install_help (InstallCallback callback)
   GdkFont   *font_strong;
   GdkFont   *font_emphasis;
   GdkFont   *font;
+  static ActionAreaItem action_items[] =
+  {
+    { "Install", help_install_callback, NULL, NULL },
+    { "Ignore", help_ignore_callback, NULL, NULL },
+    { "Quit", help_quit_callback, NULL, NULL }
+  };
+
+  action_items[0].label = _("Install");
+  action_items[1].label = _("Ignore");
+  action_items[2].label = _("Quit");
 
   help_widget = gtk_dialog_new ();
   gtk_signal_connect (GTK_OBJECT (help_widget), "delete_event",
@@ -381,11 +386,6 @@ help_quit_callback (GtkWidget *w,
 static void
 install_run (InstallCallback callback)
 {
-  static ActionAreaItem action_items[] =
-  {
-    { "Continue", install_continue_callback, NULL, NULL },
-    { "Quit", install_quit_callback, NULL, NULL }
-  };
   GtkWidget *text;
   GtkWidget *table;
   GtkWidget *vsb;
@@ -397,13 +397,21 @@ install_run (InstallCallback callback)
   struct stat stat_buf;
   int err;
   int executable = TRUE;
+  static ActionAreaItem action_items[] =
+  {
+    { "Continue", install_continue_callback, NULL, NULL },
+    { "Quit", install_quit_callback, NULL, NULL }
+  };
+
+  action_items[0].label = _("Continue");
+  action_items[1].label = _(action_items[1].label);
 
   install_widget = gtk_dialog_new ();
   gtk_signal_connect (GTK_OBJECT (install_widget), "delete_event",
 		      GTK_SIGNAL_FUNC (gtk_true),
 		      NULL);
   gtk_window_set_wmclass (GTK_WINDOW (install_widget), "installation_log", PROGRAM_NAME);
-  gtk_window_set_title (GTK_WINDOW (install_widget), "Installation Log");
+  gtk_window_set_title (GTK_WINDOW (install_widget), _("Installation Log"));
   gtk_window_position (GTK_WINDOW (install_widget), GTK_WIN_POS_CENTER);
   vadj = GTK_ADJUSTMENT (gtk_adjustment_new (0.0, 0.0, 0.0, 0.0, 0.0, 0.0));
   vsb  = gtk_vscrollbar_new (vadj);
@@ -434,16 +442,16 @@ install_run (InstallCallback callback)
   /*  Realize the text widget before inserting text strings  */
   gtk_widget_realize (text);
 
-  gtk_text_insert (GTK_TEXT (text), font_strong, NULL, NULL, "User Installation Log\n\n", -1);
+  gtk_text_insert (GTK_TEXT (text), font_strong, NULL, NULL, _("User Installation Log\n\n"), -1);
 
 #ifdef WIN32
 	{	const char* msg = UserInstall(gimp_directory());
 		if(msg)
 		{	gtk_text_insert (GTK_TEXT (text), font, NULL, NULL,msg, -1);
-			msg="\nInstallation failed!\n";
+			msg=_("\nInstallation failed!\n");
 		}
 		else
-		{	msg="\nInstallation successful!\n";
+		{	msg=_("\nInstallation successful!\n");
 		}
 		gtk_text_insert (GTK_TEXT (text), font, NULL, NULL,msg, -1);
 	}
@@ -454,14 +462,14 @@ install_run (InstallCallback callback)
     {
       gtk_text_insert (GTK_TEXT (text), font, NULL, NULL, buffer, -1);
       gtk_text_insert (GTK_TEXT (text), font, NULL, NULL,
-		       " does not exist.  Cannot install.\n", -1);
+		       _(" does not exist.  Cannot install.\n"), -1);
       executable = FALSE;
     }
   else if (! (S_IXUSR & stat_buf.st_mode) || ! (S_IRUSR & stat_buf.st_mode))
     {
       gtk_text_insert (GTK_TEXT (text), font, NULL, NULL, buffer, -1);
       gtk_text_insert (GTK_TEXT (text), font, NULL, NULL,
-		       " has invalid permissions.\nCannot install.", -1);
+		       _(" has invalid permissions.\nCannot install."), -1);
       executable = FALSE;
     }
 
@@ -476,14 +484,14 @@ install_run (InstallCallback callback)
 	  pclose (pfp);
 
 	  gtk_text_insert (GTK_TEXT (text), font, NULL, NULL,
-			   "\nInstallation successful!\n", -1);
+			   _("\nInstallation successful!\n"), -1);
 	}
       else
 	executable = FALSE;
     }
   if (executable == FALSE)
     gtk_text_insert (GTK_TEXT (text), font, NULL, NULL,
-		     "\nInstallation failed.  Contact system administrator.\n", -1);
+		     _("\nInstallation failed.  Contact system administrator.\n"), -1);
 #endif
   gtk_widget_show (vsb);
   gtk_widget_show (text);
