@@ -17,6 +17,7 @@
  */
 #include <stdlib.h>
 #include "../lib/version.h"
+#include "libgimp/gimpintl.h"
 #include "appenv.h"
 #include "actionarea.h"
 #include "app_procs.h"
@@ -160,7 +161,7 @@ static ToolButton tool_data[] =
     (gpointer) CROP },
 
   { (char **) scale_bits,
-    "Transform the layer or selection",
+    "Transform the layer or selection (rotate, scale, share, perspective)",
     (gpointer) ROTATE },
   { (char **) horizflip_bits,
     "Flip the layer or selection",
@@ -443,9 +444,9 @@ create_color_area (GtkWidget *parent)
 
   col_area = color_area_create (54, 42, default_pixmap, swap_pixmap);
   gtk_container_add (GTK_CONTAINER (alignment), col_area);
-  gtk_tooltips_set_tip (tool_tips, col_area, "Foreground & background colors.  The small black "
+  gtk_tooltips_set_tip (tool_tips, col_area, _("Foreground & background colors.  The small black "
 			"and white squares reset colors.  The small arrows swap colors.  Double "
-			"click to change colors.",
+			"click to change colors."),
 			NULL);
   gtk_widget_show (col_area);
   gtk_widget_show (alignment);
@@ -656,6 +657,41 @@ create_toolbox ()
   GtkWidget *menubar;
   GList     *device_list;
   GtkAccelGroup *table;
+  int i = 0;
+
+  tool_data[i].tool_desc = _("Select rectangular regions"); ++i;
+  tool_data[i].tool_desc = _("Select elliptical regions"); ++i;
+  tool_data[i].tool_desc = _("Select hand-drawn regions"); ++i;
+
+  tool_data[i].tool_desc = _("Select contiguous regions"); ++i;
+  tool_data[i].tool_desc = _("Select regions using Bezier curves"); ++i;
+  tool_data[i].tool_desc = _("Select shapes from image"); ++i;
+
+  tool_data[i].tool_desc = _("Move layers & selections"); ++i;
+  tool_data[i].tool_desc = _("Zoom in & out"); ++i;
+  tool_data[i].tool_desc = _("Crop the image"); ++i;
+
+  tool_data[i].tool_desc = _("Transform the layer or selection (rotate, scale, share, perspective)"); ++i;
+  tool_data[i].tool_desc = _("Flip the layer or selection"); ++i;
+  tool_data[i].tool_desc = _("Add text to the image"); ++i;
+  tool_data[i].tool_desc = _("Spline"); ++i;
+
+  tool_data[i].tool_desc = _("Pick colors from the image"); ++i;
+  tool_data[i].tool_desc = _("Fill with a color or pattern"); ++i;
+  tool_data[i].tool_desc = _("Fill with a color gradient"); ++i;
+
+  tool_data[i].tool_desc = _("Draw sharp pencil strokes"); ++i;
+  tool_data[i].tool_desc = _("Paint fuzzy brush strokes"); ++i;
+  tool_data[i].tool_desc = _("Erase to background or transparency"); ++i;
+
+  tool_data[i].tool_desc = _("Airbrush with variable pressure"); ++i;
+  tool_data[i].tool_desc = _("Clone image regions"); ++i;
+  tool_data[i].tool_desc = _("Blur or sharpen"); ++i;
+
+  tool_data[i].tool_desc = _("Dodge or burn"); ++i;
+  tool_data[i].tool_desc = _("Smudge"); ++i;
+  tool_data[i].tool_desc = _("Measure"); ++i;
+  tool_data[i].tool_desc = _("Spline Edit"); ++i;
   
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_wmclass (GTK_WINDOW (window), "toolbox", PROGRAM_NAME);
@@ -1216,7 +1252,7 @@ query_string_box (char        *title,
 
   gtk_container_border_width (GTK_CONTAINER (GTK_DIALOG (qbox)->action_area), 2);
 
-  button = gtk_button_new_with_label ("OK");
+  button = gtk_button_new_with_label (_("OK"));
   GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
                       (GtkSignalFunc) query_box_ok_callback,
@@ -1225,7 +1261,7 @@ query_string_box (char        *title,
   gtk_widget_grab_default (button);
   gtk_widget_show (button);
 
-  button = gtk_button_new_with_label ("Cancel");
+  button = gtk_button_new_with_label (_("Cancel"));
   GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
                       (GtkSignalFunc) query_box_cancel_callback,
@@ -1359,7 +1395,7 @@ message_box (const char        *orig,
 		      GTK_SIGNAL_FUNC (message_box_delete_callback),
 		      msg_box);
 
-  button = gtk_button_new_with_label ("OK");
+  button = gtk_button_new_with_label (_("OK"));
   GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
                       (GtkSignalFunc) message_box_close_callback,
