@@ -18,6 +18,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
+#include "libgimp/gimpintl.h"
 #include "appenv.h"
 #include "app_procs.h"
 #include "airbrush.h"
@@ -83,7 +84,7 @@ internal_procs_init ()
   gfloat pcount = 0;
   /* grep -c procedural_db_register internal_procs.c */
   gfloat total_pcount = 209;
-  app_init_update_status("Internal Procedures", "Tool procedures",
+  app_init_update_status(_("Internal Procedures"), _("Tool procedures"),
 			 pcount/total_pcount);
 
   /*  Tool procedures  */
@@ -110,7 +111,7 @@ internal_procs_init ()
   procedural_db_register (&scale_proc); pcount++;
   procedural_db_register (&shear_proc); pcount++;
 
-  app_init_update_status(NULL, "GDisplay procedures",
+  app_init_update_status(NULL, _("GDisplay procedures"),
 			 pcount/total_pcount);
 
   /*  GDisplay procedures  */
@@ -123,7 +124,7 @@ internal_procs_init ()
   procedural_db_register (&gdisplays_delete_image_proc); pcount++;
   procedural_db_register (&gdisplays_flush_proc); pcount++;
 
-  app_init_update_status(NULL, "Edit procedures",
+  app_init_update_status(NULL, _("Edit procedures"),
 			 pcount/total_pcount);
 
   /*  Edit procedures  */
@@ -134,7 +135,7 @@ internal_procs_init ()
   procedural_db_register (&edit_fill_proc); pcount++;
   procedural_db_register (&edit_stroke_proc); pcount++;
 
-  app_init_update_status(NULL, "GImage procedures",
+  app_init_update_status(NULL, _("GImage procedures"),
 			 pcount/total_pcount);
 
   /*  GImage procedures  */
@@ -205,7 +206,7 @@ internal_procs_init ()
   procedural_db_register (&gdisplay_all_set_colormanaged_proc); pcount++;
   procedural_db_register (&gdisplay_image_set_colormanaged_proc); pcount++;
 
-  app_init_update_status(NULL, "GImage mask procedures",
+  app_init_update_status(NULL, _("GImage mask procedures"),
 			 pcount/total_pcount);
 
   /*  GImage mask procedures  */
@@ -227,7 +228,7 @@ internal_procs_init ()
   procedural_db_register (&gimage_mask_load_proc); pcount++;
   procedural_db_register (&gimage_mask_save_proc); pcount++;
 
-  app_init_update_status(NULL, "Layer procedures",
+  app_init_update_status(NULL, _("Layer procedures"),
 			 pcount/total_pcount);
 
   /*  Layer procedures  */
@@ -259,7 +260,7 @@ internal_procs_init ()
   procedural_db_register (&layer_mask_proc); pcount++;
   procedural_db_register (&layer_is_floating_sel_proc); pcount++;
 
-  app_init_update_status(NULL, "Channel procedures",
+  app_init_update_status(NULL, _("Channel procedures"),
 			 pcount/total_pcount);
 
   /*  Channel procedures  */
@@ -277,7 +278,7 @@ internal_procs_init ()
   procedural_db_register (&channel_get_color_proc); pcount++;
   procedural_db_register (&channel_set_color_proc); pcount++;
 
-  app_init_update_status(NULL, "Drawable procedures",
+  app_init_update_status(NULL, _("Drawable procedures"),
 			 pcount/total_pcount);
 
   /*  Drawable procedures  */
@@ -304,7 +305,7 @@ internal_procs_init ()
   procedural_db_register (&drawable_set_pixel_proc); pcount++;
   procedural_db_register (&drawable_get_pixel_proc); pcount++;
 
-  app_init_update_status(NULL, "Floating selections",
+  app_init_update_status(NULL, _("Floating selections"),
 			 pcount/total_pcount);
 
   /*  Floating Selections  */
@@ -312,14 +313,14 @@ internal_procs_init ()
   procedural_db_register (&floating_sel_anchor_proc); pcount++;
   procedural_db_register (&floating_sel_to_layer_proc); pcount++;
 
-  app_init_update_status(NULL, "Undo",
+  app_init_update_status(NULL, _("Undo"),
 			 pcount/total_pcount);
 
   /*  Undo  */
   procedural_db_register (&undo_push_group_start_proc); pcount++;
   procedural_db_register (&undo_push_group_end_proc); pcount++;
 
-  app_init_update_status(NULL, "Palette",
+  app_init_update_status(NULL, _("Palette"),
 			 pcount/total_pcount);
 
   /*  Palette  */
@@ -331,7 +332,7 @@ internal_procs_init ()
   procedural_db_register (&palette_swap_colors_proc); pcount++; 
   procedural_db_register (&palette_refresh_proc); pcount++;
 
-  app_init_update_status(NULL, "Interface procedures",
+  app_init_update_status(NULL, _("Interface procedures"),
 			 pcount/total_pcount);
 
   /*  Interface procs  */
@@ -355,7 +356,7 @@ internal_procs_init ()
   procedural_db_register (&gradients_sample_uniform_proc); pcount++;
   procedural_db_register (&gradients_sample_custom_proc); pcount++;
 
-  app_init_update_status(NULL, "Image procedures",
+  app_init_update_status(NULL, _("Image procedures"),
 			 pcount/total_pcount);
 
   /*  Image procedures  */
@@ -380,7 +381,7 @@ internal_procs_init ()
   procedural_db_register (&convert_indexed_proc); pcount++;
   procedural_db_register (&convert_indexed_palette_proc); pcount++;
 
-  app_init_update_status(NULL, "Channel ops",
+  app_init_update_status(NULL, _("Channel ops"),
 			 pcount/total_pcount);
 
   /*  Channel Ops procedures  */
@@ -390,7 +391,7 @@ internal_procs_init ()
   /*  Gimprc procedures  */
   procedural_db_register (&gimprc_query_proc); pcount++;
 
-  app_init_update_status(NULL, "Procedural database",
+  app_init_update_status(NULL, _("Procedural database"),
 			 pcount/total_pcount);
 
   /*  Procedural Database  */
@@ -403,7 +404,7 @@ internal_procs_init ()
   procedural_db_register (&procedural_db_set_data_proc); pcount++;
 
   
-  app_init_update_status(NULL, "Shared Memory Images",
+  app_init_update_status(NULL, _("Shared Memory Images"),
 			 pcount/total_pcount);
 
 #ifdef BUILD_SHM
