@@ -72,9 +72,9 @@ struct Kink
   double          kinkiness;    /*  kinkiness measure  */
 };
 
-typedef struct Point Point;
+typedef struct CPPoint CPPoint;
 
-struct Point
+struct CPPoint
 {
   int             x, y;         /*  coordinates  */
   int             dir;          /*  direction  */
@@ -152,7 +152,7 @@ static Tool* last_tool;
 /*  The global array of XSegments for drawing the polygon...  */
 static GdkSegment *segs = NULL;
 static int         max_segs = 0;
-static Point *     pts = NULL;
+static CPPoint *     pts = NULL;
 static int         max_pts = 0;
 
 /*  boundary resolution variables  */
@@ -202,7 +202,7 @@ static void   iscissors_control         (Tool *, int, gpointer);
 static void   iscissors_reset           (Iscissors *);
 static void   iscissors_draw            (Tool *);
 static void   iscissors_draw_CR         (GDisplay *, Iscissors *,
-					 Point *, int *, int);
+					 CPPoint *, int *, int);
 static void   CR_compose                (CRMatrix, CRMatrix, CRMatrix);
 static int    add_segment               (int *, int, int);
 static int    add_point                 (int *, int, int, int, double *);
@@ -733,7 +733,7 @@ iscissors_draw (Tool *tool)
 static void
 iscissors_draw_CR (GDisplay  *gdisp,
 		   Iscissors *iscissors,
-		   Point     *pts,
+		   CPPoint     *pts,
 		   int       *indices,
 		   int        draw_type)
 {
@@ -994,7 +994,7 @@ add_point (int    *num_pts,
     {
       max_pts += DEFAULT_MAX_INC;
 
-      pts = (Point *) g_realloc ((void *) pts, sizeof (Point) * max_pts);
+      pts = (CPPoint *) g_realloc ((void *) pts, sizeof (CPPoint) * max_pts);
 
       if (!pts)
 	fatal_error ("Unable to reallocate points array in iscissors.");
