@@ -295,7 +295,7 @@ look_profile_create(GImage *image, gint sample_depth)
     transform = cms_get_transform(profiles, TYPE_Lab_16,
 						lcms_format_out,
 						INTENT_PERCEPTUAL,
-                                                cms_default_flags);
+                                                cms_default_flags, 0, NULL);
     g_slist_free(profiles);
 
     /* iterate over Lab space, converting to rgb, filling into picture */
@@ -448,6 +448,14 @@ look_profile_save (LookProfile *profile,
     GSList *profiles = NULL;
     PixelRow row_buffer;
 
+    FILE *fp = fopen(file_name, "w");
+    if (fp)
+        fclose (fp);
+    else
+      { g_message ("Could not open file: %s", file_name);
+        return;
+      }
+
     sample_info->profile = profile;
 
     cmsSetColorSpace(saved_profile, icSigLabData);
@@ -471,7 +479,7 @@ look_profile_save (LookProfile *profile,
     profiles = g_slist_append(profiles, lab_profile);
     sample_info->transform = cms_get_transform(profiles,
                                        cms_get_lcms_format(t, input_profile),
-				       TYPE_Lab_16, intent, flags);
+                                       TYPE_Lab_16, intent, flags, 0, NULL);
 
     pixelarea_init(&sample_info->sample_area,
 		   profile->canvas,
@@ -713,15 +721,22 @@ _look_profile_gui_free_row_data(gpointer user_data)
 static void 
 _look_profile_gui_update_list(_LookProfileGui *data)
 {
-    GSList *profile_file_names = cms_read_icc_profile_dir(look_profile_path, icSigAbstractClass);
-    gint path_length = strlen(look_profile_path); 
+    GSList *profile_file_names;
+    gint path_length = 0;
     gchar *file_path;
     /* row_data[0] contains the path of the profile,
        row_data[1] is NULL if off, profile handle if on */
     _LookProfileGuiRowData *row_data = NULL;
-	gchar *row_text[2] = {NULL, NULL};
+    gchar *row_text[2] = {NULL, NULL};
+    GSList *iterator = 0;
 
-    GSList *iterator = profile_file_names; 
+    profile_file_names = cms_read_icc_profile_dir(look_profile_path, icSigAbstractClass);
+    iterator =  profile_file_names; 
+
+    if(!look_profile_path || !g_slist_length(profile_file_names))
+    { return;
+    }
+    path_length = strlen(look_profile_path); 
 
     data->row_count=0;
     gtk_clist_clear(GTK_CLIST(data->profile_list));
@@ -732,6 +747,9 @@ _look_profile_gui_update_list(_LookProfileGui *data)
 
     while (iterator != NULL)      
     {   file_path = (gchar *)iterator->data;
+        if(!file_path)
+        { return;
+        }
         row_data = g_new(_LookProfileGuiRowData, 1);
         row_data->file_name = file_path;
 	row_data->handle = NULL;
@@ -859,9 +877,11 @@ _look_profile_gui_apply(_LookProfileGui *data)
     lcms_format = cms_get_lcms_format(gimage_tag(data->display->gimage),
                                             image_profile);
     transform = cms_get_transform(profiles,
-                                        lcms_format, lcms_format,
-                                        gdisplay_get_cms_intent(data->display),
-                                        gdisplay_get_cms_flags(data->display));
+                                   lcms_format, lcms_format,
+                                   gdisplay_get_cms_intent(data->display),
+                                   gdisplay_get_cms_flags(data->display),
+                                   gdisplay_get_cms_proof_intent(data->display),
+                                   NULL);
     g_slist_free(profiles);
     gimage_transform_colors(data->display->gimage, transform, TRUE);
     cms_return_transform(transform);
@@ -901,9 +921,11 @@ _look_profile_gui_apply_flipbook (_LookProfileGui *data)
     profiles = g_slist_append(profiles, (gpointer)image_profile);
     lcms_format = cms_get_lcms_format(gimage_tag(data->display->gimage), image_profile);
     transform = cms_get_transform(profiles,
-                                        lcms_format, lcms_format,
-                                        gdisplay_get_cms_intent(data->display),
-                                        gdisplay_get_cms_flags(data->display));
+                                   lcms_format, lcms_format,
+                                   gdisplay_get_cms_intent(data->display),
+                                   gdisplay_get_cms_flags(data->display),
+                                   gdisplay_get_cms_proof_intent(data->display),
+                                   NULL);
     g_slist_free(profiles);
 
     /* create progress dialog */
@@ -932,7 +954,7 @@ _look_profile_gui_apply_flipbook (_LookProfileGui *data)
 	gimage_transform_colors(store->gimage, transform, FALSE);
         iterator = g_slist_next(iterator);
 	/* set modified indicator of store */
-	gtk_clist_set_text (GTK_CLIST (data->display->bfm->sfm->store_list), count, 4, "*");
+    sfm_dirty (data->display, count);
 	count ++;
 	gtk_progress_set_percentage(GTK_PROGRESS(progress_bar), count/(gfloat)num_images);
  	gtk_widget_draw(progress_bar, NULL);
