@@ -20,9 +20,11 @@
 #include <string.h>
 #include <ctype.h>
 #include <unistd.h>
+#include "libgimp/gimpintl.h"
 #include "appenv.h"
 #include "colormaps.h"
 #include "commands.h"
+#include "config.h"
 #include "fileops.h"
 #include "rc.h"
 #include "interface.h"
@@ -36,6 +38,8 @@
 #include "spline.h"
 #include "store_frame_manager.h"
 
+
+
 /* rsr: ld error hack, this is a bug: */
 /*#define sfm_slide_show 0*/
 
@@ -56,10 +60,11 @@ typedef struct {
 } PluginMenuEntry;
 
 
-static void menus_init (void);
+static void  menus_init (void);
 static void
 menus_strip_extra_entries(const char *tmp_filename, const char *filename);
 
+
 static GtkItemFactoryEntry toolbox_entries[] =
 {
 #ifdef TEAR_OFF
@@ -114,14 +119,14 @@ static GtkItemFactoryEntry image_entries[] =
 #ifdef TEAR_OFF
   { "/File/Flipbook/tearoff1", NULL, NULL, 0, "<Tearoff>" },
 #endif
-  { "/File/Flipbook/create", "<control>F", dialogs_store_frame_manager_cmd_callback, 0 },
-  { "/File/Flipbook/flip forward", "W", dialogs_store_frame_manager_flip_forward_cmd_callback, 0 },
-  { "/File/Flipbook/flip backward", "Q", dialogs_store_frame_manager_flip_backwards_cmd_callback, 0 },
-  { "/File/Flipbook/frame forward", "S", dialogs_store_frame_manager_adv_forward_cmd_callback, 0 },
-  { "/File/Flipbook/frame backward", "A", dialogs_store_frame_manager_adv_backwards_cmd_callback, 0 },
-  { "/File/Flipbook/play forward", "Q", dialogs_store_frame_manager_play_forward_cmd_callback, 0 },
-  { "/File/Flipbook/play backward", "Q", dialogs_store_frame_manager_play_backwards_cmd_callback, 0 },
-  { "/File/Flipbook/stop", "Q", dialogs_store_frame_manager_stop_cmd_callback, 0 },
+  { "/File/Flipbook/Create", "<control>F", dialogs_store_frame_manager_cmd_callback, 0 },
+  { "/File/Flipbook/Flip Forward", "E", dialogs_store_frame_manager_flip_forward_cmd_callback, 0 },
+  { "/File/Flipbook/Flip Backward", "W", dialogs_store_frame_manager_flip_backwards_cmd_callback, 0 },
+  { "/File/Flipbook/Frame Forward", "D", dialogs_store_frame_manager_adv_forward_cmd_callback, 0 },
+  { "/File/Flipbook/Frame Backward", "A", dialogs_store_frame_manager_adv_backwards_cmd_callback, 0 },
+  { "/File/Flipbook/Play Forward", "Y", dialogs_store_frame_manager_play_forward_cmd_callback, 0 },
+  { "/File/Flipbook/Play Backward", NULL, dialogs_store_frame_manager_play_backwards_cmd_callback, 0 },
+  { "/File/Flipbook/Stop", "X", dialogs_store_frame_manager_stop_cmd_callback, 0 },
 #endif
   { "/File/Save", "<alt>S", file_save_cmd_callback, 0 },
   { "/File/Save as...", "<alt><shift>s", file_save_as_cmd_callback, 0 },
@@ -177,11 +182,13 @@ static GtkItemFactoryEntry image_entries[] =
 #endif
   { "/View/Colormanage Display", NULL, view_colormanage_display_cmd_callback, 0, "<ToggleItem>" },
   { "/View/Proof Display", NULL, view_proof_display_cmd_callback, 0, "<ToggleItem>" },
+  { "/View/Simulatate Paper", NULL, view_paper_simulation_display_cmd_callback, 0, "<ToggleItem>" },
   { "/View/Gamut Check Display", NULL, view_gamutcheck_display_cmd_callback, 0, "<ToggleItem>" },
   { "/View/Rendering Intent/Perceptual", NULL, view_rendering_intent_cmd_callback, INTENT_PERCEPTUAL, "<RadioItem>"},
   { "/View/Rendering Intent/Relative Colorimetric", NULL, view_rendering_intent_cmd_callback, INTENT_RELATIVE_COLORIMETRIC, "/View/Rendering Intent/Perceptual" },
   { "/View/Rendering Intent/Saturation", NULL, view_rendering_intent_cmd_callback, INTENT_SATURATION, "/View/Rendering Intent/Relative Colorimetric"},
   { "/View/Rendering Intent/Absolute Colorimetric", NULL, view_rendering_intent_cmd_callback, INTENT_ABSOLUTE_COLORIMETRIC, "/View/Rendering Intent/Saturation"},
+  { "/View/Rendering Intent/Black Point Compensation", NULL, view_bpc_display_cmd_callback, 0, "<ToggleItem>" },
   { "/View/Look Profiles...", NULL, view_look_profiles_cmd_callback, 0 },
   { "/View/Expose", NULL, view_expose_hdr_cmd_callback, 0 },
   { "/View/---", NULL, NULL, 0, "<Separator>" },
@@ -216,7 +223,7 @@ static GtkItemFactoryEntry image_entries[] =
   { "/View/Toggle Guides", "<control><shift>T", view_toggle_guides_cmd_callback, 0, "<ToggleItem>" },
   { "/View/Snap To Guides", NULL, view_snap_to_guides_cmd_callback, 0, "<ToggleItem>" },
   { "/View/---", NULL, NULL, 0, "<Separator>" },
-  { "/View/Slide Show", NULL, sfm_slide_show, 0, NULL },
+  { "/View/Slide Show", NULL, sfm_slide_show_callback, 0, NULL },
   { "/View/---", NULL, NULL, 0, "<Separator>" },
   { "/View/New View", NULL, view_new_view_cmd_callback, 0 }, 
   { "/View/Shrink Wrap", "<control>E", view_shrink_wrap_cmd_callback, 0 },
@@ -246,7 +253,6 @@ static GtkItemFactoryEntry image_entries[] =
   { "/Image/Channel Ops/Offset", "<control><shift>O", channel_ops_offset_cmd_callback, 0 },
 #if 1
   { "/Image/Alpha/Add Alpha Channel", NULL, layers_add_alpha_channel_cmd_callback, 0 },
-  { "/Layers/Stroke Splines", NULL, spline_stroke_cmd_callback, 0 },
 #endif
   { "/Image/---", NULL, NULL, 0, "<Separator>" },
   { "/Image/RGB", NULL, image_convert_rgb_cmd_callback, 0 },
@@ -271,6 +277,7 @@ static GtkItemFactoryEntry image_entries[] =
 #ifdef TEAR_OFF
   { "/Layers/tearoff1", NULL, NULL, 0, "<Tearoff>" },
 #endif
+  { "/Layers/Stroke Splines", NULL, spline_stroke_cmd_callback, 0 },
   { "/Layers/Layers & Channels...", "<control>L", dialogs_lc_cmd_callback, 0 },
   { "/Layers/Raise Layer", "<shift>F", layers_raise_cmd_callback, 0 },
   { "/Layers/Lower Layer", "<shift>B", layers_lower_cmd_callback, 0 },
@@ -308,7 +315,7 @@ static GtkItemFactoryEntry image_entries[] =
   { "/Tools/Transform Tools/Flip", NULL, tools_select_cmd_callback, FLIP_HORZ },
   { "/Tools/Text", "T", tools_select_cmd_callback, TEXT },
   { "/Tools/Color Picker", NULL, tools_select_cmd_callback, COLOR_PICKER },
-  { "/Tools/Splines", "S", tools_select_cmd_callback, SPLINE },
+  { "/Tools/Splines", "", tools_select_cmd_callback, SPLINE },
 #if 0
   { "/Tools/Color Picker Down", "I", select_color_picker, NULL },
 #endif
@@ -321,7 +328,7 @@ static GtkItemFactoryEntry image_entries[] =
   { "/Tools/Paint Tools/Pencil", NULL, tools_select_cmd_callback, PENCIL },
   { "/Tools/Paint Tools/Eraser", NULL, tools_select_cmd_callback, ERASER },
   { "/Tools/Paint Tools/Airbrush", NULL, tools_select_cmd_callback, AIRBRUSH },
-  { "/Tools/Paint Tools/Clone", NULL, tools_select_cmd_callback, CLONE },
+  { "/Tools/Paint Tools/Clone", "C", tools_select_cmd_callback, CLONE },
   { "/Tools/Paint Tools/Convolve", NULL, tools_select_cmd_callback, CONVOLVE },
   { "/Tools/Paint Tools/Dodge or Burn", NULL, tools_select_cmd_callback, DODGEBURN },
   { "/Tools/Paint Tools/Smudge", NULL, tools_select_cmd_callback, SMUDGE },
@@ -335,10 +342,11 @@ static GtkItemFactoryEntry image_entries[] =
 #endif
   { "/Short cuts/Increase Brush Radius (+1)", ".", brush_increase_radius, 0 },
   { "/Short cuts/Decrease Brush Radius (-1)", ",", brush_decrease_radius, 0 },
-  { "/Short cuts/Increase clone x offset ", ",", clone_x_offset_increase, 0 },
-  { "/Short cuts/Decrease clone x offset ", ",", clone_x_offset_decrease, 0 },
-  { "/Short cuts/Increase clone y offset ", ",", clone_y_offset_increase, 0 },
-  { "/Short cuts/Decrease clone y offset ", ",", clone_y_offset_decrease, 0 },
+  { "/Short cuts/Increase clone x offset ", NULL, clone_x_offset_increase, 0 },
+  { "/Short cuts/Decrease clone x offset ", NULL, clone_x_offset_decrease, 0 },
+  { "/Short cuts/Increase clone y offset ", NULL, clone_y_offset_increase, 0 },
+  { "/Short cuts/Decrease clone y offset ", NULL, clone_y_offset_decrease, 0 },
+  { "/Short cuts/Toogle Onionskin ", "O", sfm_onionskin_toogle_callback, 0, "<ToggleItem>" },
   { "/Short cuts/Reset clone offset ", ",", clone_reset_offset, 0 },
 #ifdef TEAR_OFF
   { "/Filters/tearoff1", NULL, NULL, 0, "<Tearoff>" },
@@ -399,20 +407,24 @@ static GtkItemFactory *save_factory = NULL;
 
 static GtkItemFactoryEntry sfm_store_entries[] =
 {
-    {"/Store/Add", NULL, sfm_store_add, 0, NULL},
-    {"/Store/Delete", NULL, sfm_store_delete, 0, NULL},
-    {"/Store/Raise", NULL, sfm_store_raise, 0, NULL},
-    {"/Store/Lower", NULL, sfm_store_lower, 0, NULL},
-    {"/Store/Save", NULL, sfm_store_save, 0, NULL},
-    {"/Store/Save All", NULL, sfm_store_save_all, 0, NULL},
-    {"/Store/Revert", NULL, sfm_store_revert, 0, NULL},
-    {"/Store/Change Frame", NULL, sfm_store_change_frame, 0, NULL},
-    {"/View/Slide Show", NULL, sfm_slide_show, 0, NULL},
-    {"/Dir/Recent Src", NULL, sfm_store_recent_src, 0, NULL},
-    {"/Dir/Recent Dest", NULL, sfm_store_recent_dest, 0, NULL},
-    {"/Dir/Load Smart", NULL, sfm_store_load_smart, 0, "<ToggleItem>"}
-/*    {"/Commands/Filters/Apply Last", NULL, sfm_filter_apply, 0, NULL}
-*/};
+    {"/Store/Add", NULL, sfm_store_add_callback, 0, NULL},
+    {"/Store/Delete", NULL, sfm_store_delete_callback, 0, NULL},
+    {"/Store/Raise", NULL, sfm_store_raise_callback, 0, NULL},
+    {"/Store/Lower", NULL, sfm_store_lower_callback, 0, NULL},
+    {"/Store/Save", NULL, sfm_store_save_callback, 0, NULL},
+    {"/Store/Save All", NULL, sfm_store_save_all_callback, 0, NULL},
+    {"/Store/Revert", NULL, sfm_store_revert_callback, 0, NULL},
+    {"/Store/Change Frame", NULL, sfm_store_change_frame_callback, 0, NULL},
+    {"/View/Slide Show", NULL, sfm_slide_show_callback, 0, NULL},
+    {"/Dir/Recent Src", NULL, sfm_store_recent_src_callback, 0, NULL},
+    {"/Dir/Recent Dest", NULL, sfm_store_recent_dest_callback, 0, NULL},
+    {"/Dir/Load Smart", NULL, sfm_store_load_smart_callback, 0, "<ToggleItem>"},
+    {"/Effects/Apply Last Filter", NULL, sfm_filter_apply_last_callback, 0, NULL},
+    {"/Effects/New Layer", NULL, sfm_layer_new_callback, 0, NULL},
+    {"/Effects/Copy Layer", NULL, sfm_layer_copy_callback, 0, NULL},
+    {"/Effects/Layer Mode", NULL, sfm_layer_mode_callback, 0, NULL},
+    {"/Effects/Merge Visible", NULL, sfm_layer_merge_visible_callback, 0, NULL},
+};
 
 static guint n_sfm_store_entries = sizeof (sfm_store_entries) / sizeof (sfm_store_entries[0]);
 static GtkItemFactory *sfm_store_factory = NULL;
@@ -420,6 +432,199 @@ static int sfm_store_factory_init = TRUE;
 
 static int initialize = TRUE;
 
+static void
+menus_dummy_translate()
+{
+  _("Help");
+  _("File");
+  _("New...");
+  _("New From");
+  _("Open...");
+  _("Acquire");
+  _("Preferences...");
+  _("Dialogs");
+  _("Palette...");
+  _("Gradient Editor...");
+  _("Tool Options...");
+  _("Device Status...");
+  _("Device Dialog");
+  _("Quit");
+  _("Flipbook");
+  _("Create");
+  _("Flip Forward");
+  _("Flip Backward");
+  _("Frame Forward");
+  _("Frame Backward");
+  _("Play Forward");
+  _("Play Backward");
+  _("Stop");
+  _("Save");
+  _("Save as...");
+  _("SaveFile copy as...");
+  _("Close");
+  _("Redo");
+  _("Cut");
+  _("Copy");
+  _("Paste");
+  _("Paste Into");
+  _("Clear");
+  _("Fill");
+  _("Stroke");
+  _("Paste Named");
+  _("Select");
+  _("Toggle");
+  _("Invert");
+  _("Float");
+  _("Grow");
+  _("Shrink");
+  _("Save To Channel");
+  _("By Color...");
+  _("View");
+  _("Colormanage Display");
+  _("Proof Display");
+  _("Simulatate Paper");
+  _("Gamut Check Display");
+  _("Rendering Intent");
+  _("Perceptual");
+  _("Relative Colorimetric");
+  _("Saturation");
+  _("Absolute Colorimetric");
+  _("Black Point Compensation");
+  _("Look Profiles...");
+  _("Expose");
+  _("Pan Zoom Window");
+  _("Zoom Bookmarks");
+  _("Load");
+  _("Save");
+  _("Zoom In");
+  _("Zoom Out");
+  _("Zoom");
+  _("Window Info...");
+  _("Toggle Rulers");
+  _("Toggle Guides");
+  _("Snap To Guides");
+  _("Slide Show");
+  _("New View");
+  _("Shrink Wrap");
+  _("Image");
+  _("Colors");
+  _("Equalize");
+  _("Invert");
+  _("Posterize");
+  _("Threshold");
+  _("Color Balance");
+  _("Color Correction");
+  _("Brightness-Contrast");
+  _("Hue-Saturation");
+  _("Gamma-Expose");
+  _("Curves");
+  _("Levels");
+  _("Desaturate");
+  _("Channel Ops");
+  _("Duplicate");
+  _("Offset");
+  _("Alpha");
+  _("Add Alpha Channel");
+  _("Image");
+  _(PRECISION_U8_STRING);
+  _(PRECISION_U16_STRING);
+  _(PRECISION_FLOAT16_STRING);
+  _(PRECISION_BFP_STRING);
+  _(PRECISION_FLOAT_STRING);
+  _("Convert using ICC Profile...");
+  _("Assign ICC Profile...");
+  _("Assign ICC Proof Profile...");
+  _("Layers");
+  _("Stroke Splines");
+  _("Layers & Channels...");
+  _("Raise Layer");
+  _("Lower Layer");
+  _("Anchor Layer");
+  _("Merge Visible Layers");
+  _("Flatten Image");
+  _("Alpha To Selection");
+  _("Mask To Selection");
+  _("Add Alpha Channel");
+  _("Make Layer");
+  _("Rotate");
+  _("270 degrees");
+  _("180 degrees");
+  _("90 degrees");
+  _("Tools");
+  _("Select Tools");
+  _("Rect Select");
+  _("Ellipse Select");
+  _("Free Select");
+  _("Fuzzy Select");
+  _("Bezier Select");
+  _("Intelligent Scissors");
+  _("Transform Tools");
+  _("Move");
+  _("Magnify");
+  _("Crop");
+  _("Transform");
+  _("Flip");
+  _("Text");
+  _("Color Picker");
+  _("Splines");
+  _("Paint Tools");
+  _("Bucket Fill");
+  _("Blend");
+  _("Paintbrush");
+  _("Pencil");
+  _("Eraser");
+  _("Airbrush");
+  _("Clone");
+  _("Convolve");
+  _("Dodge or Burn");
+  _("Smudge");
+  _("Default Colors");
+  _("Swap Colors");
+  _("Increase Brush Radius (+1)");
+  _("Decrease Brush Radius (-1)");
+  _("Increase clone x offset ");
+  _("Decrease clone x offset");
+  _("Increase clone y offset ");
+  _("Decrease clone y offset ");
+  _("Toogle Onionskin ");
+  _("Filters");
+  _("Re-show last");
+  _("Repeat last");
+  _("Dialogs");
+  _("Brushes...");
+  _("Palette...");
+  _("Gradient Editor...");
+  _("Layers & Channels...");
+  _("Tool Options...");
+  _("Automatic");
+  _("By extension");
+  _("Store");
+  _("Add");
+  _("Delete");
+  _("Raise");
+  _("Lower");
+  _("Save");
+  _("Save All");
+  _("Revert");
+  _("Revert to Saved");
+  _("Change Frame");
+  _("Dir");
+  _("Recent Src");
+  _("Recent Dest");
+  _("Load Smart");
+  _("Effects");
+  _("Apply Last Filter");
+  _("New Layer");
+  _("Copy Layer");
+  _("Layer Mode");
+  _("Merge Visible");
+  _("none");
+  _("All");
+  _("Short cuts");
+  _("Toolbox");
+  _("Transforms");
+}
+
 static void
 menu_remove_default_accel(const gchar *name)
 {
@@ -679,7 +884,6 @@ sfm_menu_rem_accel_cb(
   this_gdisp = (GDisplay *)user_data;
   item = (GtkMenuItem *)widget;
   wid_path = strstr(gtk_widget_get_name(widget), ">/");
-//  d_printf("   %s\n", wid_path);
 
   // go to all other pulldown menus and the popup menu
   // propoate changes to them as well.
@@ -748,7 +952,6 @@ pull_down_menu_rem_accel_cb(
   this_gdisp = (GDisplay *)user_data;
   item = (GtkMenuItem *)widget;
   wid_path = strstr(gtk_widget_get_name(widget), ">/");
-//  d_printf("   %s\n", wid_path);
 
   // go to all other pulldown menus and the popup menu
   // propoate changes to them as well.
@@ -856,11 +1059,14 @@ menus_get_image_menubar(GDisplay *gdisp)
   g_snprintf(buff, 256, "<Image%d>", gdisp->unique_id);
   gdisp->menubar_fac = gtk_item_factory_new (GTK_TYPE_MENU_BAR, buff, NULL);
 
-# ifdef DEBUG_
   { int i;
     for(i = 0 ; i < n_image_entries; ++i)
-      printf("%s:%d %s() %s\n",__FILE__,__LINE__,__func__,image_entries[i]); }
-#endif
+    {
+# ifdef DEBUG_
+      printf("%s:%d %s() %s\n",__FILE__,__LINE__,__func__,image_entries[i].path);
+# endif
+    }
+  }
   gtk_item_factory_create_items_ac (gdisp->menubar_fac , n_image_entries, image_entries, NULL, 2);
   plug_in_make_image_menu(gdisp->menubar_fac, buff);
 
@@ -997,7 +1203,8 @@ menus_propagate_plugins(
 
   for (node = g_plugin_menu_items; node != NULL; node = node->next) {
     entry = (PluginMenuEntry *)node->data;
-    g_snprintf(buff, 1024, "<Image%d>%s", gdisp->unique_id, entry->path);
+    g_snprintf(buff, 1024, "<Image%d>%s", gdisp->unique_id,
+               menu_entry_translate(entry->path));
     menuEntry.path = buff;
     if (strcmp(entry->accelerator, "NULL") == 0)
       menuEntry.accelerator = NULL;
@@ -1011,9 +1218,10 @@ menus_propagate_plugins(
     // check if it doesn't already exist
     ifactory = gtk_item_factory_from_path (menuEntry.path);
 
-    if (ifactory) {
+    if (ifactory)
+    {
       widget = gtk_item_factory_get_widget (ifactory, menuEntry.path);
-    
+
       if (!widget)
         gtk_item_factory_create_menu_entries (1, &menuEntry);
     }
@@ -1029,10 +1237,16 @@ menus_create (GtkMenuEntry *entries,
   if (initialize)
     menus_init ();
  
-  for (i=0; i < nmenu_entries; i++) {
-    if (strncmp(entries[i].path, "<Image>", 7) == 0) {
+  for (i=0; i < nmenu_entries; i++)
+  {
+    entries[i].path = menu_entry_translate( entries[i].path );
+    if (strncmp(entries[i].path, "<Image>", 7) == 0)
+    {
       item = g_malloc_zero(sizeof(PluginMenuEntry));
-      strcpy(item->path,entries[i].path + 7);
+      strcpy(item->path, menu_entry_translate( entries[i].path + 7 ));
+#     ifdef DEBUG_
+      printf("%s:%d %s %s\n",__FILE__,__LINE__,item->path, entries[i].path);
+#     endif
       if (entries[i].accelerator)
       	strcpy(item->accelerator, entries[i].accelerator);
       else
@@ -1052,22 +1266,26 @@ menus_set_sensitive (char *path,
 {
   GtkItemFactory *ifactory;
   GtkWidget *widget = NULL;
+  char *tpath = menu_entry_translate(path);
 
   if (initialize)
     {
     menus_init ();
     }
-  ifactory = gtk_item_factory_from_path (path);
+  
+  ifactory = gtk_item_factory_from_path (tpath);
 
   if (ifactory)
     {
-      widget = gtk_item_factory_get_widget (ifactory, path);
+      widget = gtk_item_factory_get_widget (ifactory, tpath);
     
       if (widget)
 	gtk_widget_set_sensitive (widget, sensitive);
     }
   if (!ifactory || !widget)
-    e_printf ("Unable to set sensitivity for menu which doesn't exist:\n%s", path);
+    e_printf ("Unable to set sensitivity for menu which doesn't exist:\n%s", tpath);
+
+  if(tpath) free(tpath);
 }
 
 void
@@ -1076,15 +1294,16 @@ menus_set_state (char *path,
 {
   GtkItemFactory *ifactory;
   GtkWidget *widget = NULL;
+  char *tpath = menu_entry_translate(path);
 
   if (initialize)
     menus_init ();
 
-  ifactory = gtk_item_factory_from_path (path);
+  ifactory = gtk_item_factory_from_path (tpath);
 
   if (ifactory)
     {
-      widget = gtk_item_factory_get_widget (ifactory, path);
+      widget = gtk_item_factory_get_widget (ifactory, tpath);
 
       if (widget && GTK_IS_CHECK_MENU_ITEM (widget))
 	gtk_check_menu_item_set_state (GTK_CHECK_MENU_ITEM (widget), state);
@@ -1092,7 +1311,9 @@ menus_set_state (char *path,
 	widget = NULL;
     }
   if (!ifactory || !widget)
-    e_printf ("Unable to set state for menu which doesn't exist:\n%s", path);
+    e_printf ("Unable to set state for menu which doesn't exist:\n%s", tpath);
+
+  if(tpath) free(tpath);
 }
 
 void
@@ -1226,10 +1447,31 @@ menus_init ()
   if (initialize)
     {
       gchar *filename;
+      int i;
 
       initialize = FALSE;      
 
       toolbox_factory = gtk_item_factory_new (GTK_TYPE_MENU_BAR, "<Toolbox>", NULL);
+
+# define gtk_menu_translate(entries, n_entries) { \
+      for(i = 0; i < n_entries; ++i) { \
+        if(entries[i].path) \
+          entries[i].path = menu_entry_translate( entries[i].path ); \
+      } }
+
+      gtk_menu_translate (toolbox_entries, n_toolbox_entries)
+      for(i = 0; i < n_image_entries; ++i) {
+        if(image_entries[i].item_type)
+        if(strstr(image_entries[i].item_type,"/View/Rendering Intent/Relative Colorimetric") ||
+           strstr(image_entries[i].item_type,"/View/Rendering Intent/Saturation") ||
+           strstr(image_entries[i].item_type,"/View/Rendering Intent/Perceptual"))
+          image_entries[i].item_type = menu_entry_translate( image_entries[i].item_type );
+      }
+      gtk_menu_translate (image_entries, n_image_entries)
+      gtk_menu_translate (load_entries, n_load_entries)
+      gtk_menu_translate (save_entries, n_save_entries)
+      gtk_menu_translate (sfm_store_entries, n_sfm_store_entries)
+
       gtk_item_factory_create_items_ac (toolbox_factory,
 					n_toolbox_entries,
 					toolbox_entries,
@@ -1266,3 +1508,80 @@ menus_init ()
     }
 }
 
+#define DIR_SEPARATOR '/'
+
+char*
+menu_plugins_translate (const char* entry)
+{
+  char* new_name;
+  textdomain( PACKAGE "-std-plugins" );
+  new_name = menu_entry_translate (entry);
+# ifdef DEBUG_
+  printf( "%s:%d: %s %s | %s\n", __FILE__,__LINE__, new_name, _(entry), entry );
+# endif
+
+  textdomain( PACKAGE );
+  return new_name;
+}
+
+char*
+menu_entry_translate (const char* entry)
+{
+  char *text = (char*) calloc (1024, sizeof(char)),
+       *word = 0;
+  const char *tmp = 0;
+
+# ifdef DEBUG_
+  printf( "%s:%d: %s | %s\n", __FILE__,__LINE__, _(entry), entry );
+# endif
+
+  if(strchr(entry, '<'))
+    tmp = entry;
+
+  tmp = entry;
+
+  // segmentate the path
+  while (strchr( tmp, DIR_SEPARATOR ))
+  {
+    char *sep = 0;
+    int add_separator = 0;
+
+    // prepend <xxx> part of pathname
+    if( tmp[0] == DIR_SEPARATOR )
+    {
+      ++tmp;
+      add_separator = 1;
+    }
+
+    // erase the separator
+    word = strdup( tmp );
+    sep = strchr( word, DIR_SEPARATOR );
+    if( sep )
+      *sep = 0;
+
+    // translate and append
+    snprintf( &text [strlen( text )], 1024, "%s%s",
+              add_separator ? "/" : "",
+              strlen(word) ? _(word) : "" );
+#   ifdef DEBUG_
+    printf( "%s:%d: %s | %s\n", __FILE__,__LINE__, _(word), text );
+#   endif
+
+    // proceede
+    tmp = tmp + strlen(word);
+
+    if(word)
+      free(word);
+  }
+
+  // resize memory
+  if(strlen(text))
+  {
+    word = (char*) calloc( strlen(text) + 1, sizeof(char) );
+    memcpy( word, text, strlen( text ) + 1 );
+    free (text);
+    return word;
+  }
+  else
+    return (char*) calloc(1,sizeof(char));
+}
