@@ -27,7 +27,6 @@
 #include "gimage.h"
 #include "paint_core_16.h"
 #include "paint_funcs_area.h"
-#include "paint_options.h"
 #include "paintbrush.h"
 #include "palette.h"
 #include "pixelarea.h"
@@ -98,7 +97,8 @@ static void paintbrush_motion (PaintCore *, CanvasDrawable *,
 			       PaintPressureOptions *,
 			       double,
 			       gboolean);
-static void         paintbrush_painthit_setup (PaintCore *,Canvas *);
+static void* paintbrush_paint_func(PaintCore *paint_core, CanvasDrawable *drawable, int state);
+
 static double non_gui_fade_out, non_gui_incremental;
 
 
@@ -324,7 +324,7 @@ paintbrush_options_new (void)
   return options;
 }
 
-static void *
+static void*
 paintbrush_paint_func (PaintCore *paint_core,
 		       CanvasDrawable *drawable,
 		       int        state)
@@ -443,8 +443,7 @@ paintbrush_motion (PaintCore *paint_core,
     }
 }
 
-
-static void
+void
 paintbrush_painthit_setup (PaintCore * paint_core,Canvas * painthit)
 {
     PixelArea a;
@@ -476,18 +475,36 @@ paintbrush_painthit_setup (PaintCore * paint_core,Canvas * painthit)
     }
 }
 
-static void *
-paintbrush_non_gui_paint_func (PaintCore *paint_core,
-			       CanvasDrawable *drawable,
-			       int        state)
-{	
-  paintbrush_motion (paint_core, drawable,
+void*
+paintbrush_non_gui_paint_func(PaintCore *paint_core, CanvasDrawable *drawable, int state)
+{
+  paintbrush_motion(paint_core, drawable,
 		     paintbrush_options->paint_options.pressure_options,
 		     non_gui_fade_out, non_gui_incremental);
-
   return NULL;
 }
 
+void*
+paintbrush_spline_non_gui_paint_func(PaintCore *paint_core, CanvasDrawable *drawable, int state)
+{	
+  double paint_left, scale=1.0;
+
+  /* model the paint left on the brush as a gaussian curve */
+  paint_left = 1;
+
+  /* apply the next bit of remaining paint */
+  if (paint_left > 0.001)
+    {
+      /* Set up the painthit canvas */
+      paint_core_16_area_setup (paint_core, drawable);
+      
+      /* apply it to the image */
+      paint_core_16_area_paste (paint_core, drawable, (float)paint_left,
+				(float)gimp_brush_get_opacity(), SOFT,
+				scale, CONSTANT, gimp_brush_get_paint_mode ());
+    }
+  return NULL;
+}
 
 /*  The paintbrush procedure definition  */
 ProcArg paintbrush_args[] =
