@@ -29,6 +29,7 @@
 #endif
 
 #include "../lib/version.h"
+#include "libgimp/gimpintl.h"
 #include "appenv.h"
 #include "actionarea.h"
 #include "buildmenu.h"
@@ -61,9 +62,9 @@
 
 #define PALETTE_EVENT_MASK GDK_EXPOSURE_MASK | GDK_BUTTON_PRESS_MASK | GDK_ENTER_NOTIFY_MASK
 
-typedef struct Palette Palette, *PaletteP;
+typedef struct CPPalette CPPalette, *PaletteP;
 
-struct Palette {
+struct CPPalette {
   GtkWidget *shell;
   GtkWidget *vbox;
   GtkWidget *frame;
@@ -218,8 +219,19 @@ palette_create ()
   int i;
 
   if (!palette)
-    {
-      palette = g_malloc (sizeof (Palette));
+    { i = 0;
+      action_items[i].label = _("New"); ++i;
+      action_items[i].label = _("Edit"); ++i;
+      action_items[i].label = _("Delete"); ++i;
+      action_items[i].label = _("Close"); ++i;
+
+      i = 0;
+      palette_ops[i].label = _("New Palette"); ++i;
+      palette_ops[i].label = _("Delete Palette"); ++i;
+      palette_ops[i].label = _("Refresh Palettes"); ++i;
+      palette_ops[i].label = _("Close"); ++i;
+
+      palette = g_malloc (sizeof (CPPalette));
 
       palette->entries = default_palette_entries;
       palette->color = NULL;
@@ -233,7 +245,7 @@ palette_create ()
       palette->shell = gtk_dialog_new ();
       gtk_window_set_wmclass (GTK_WINDOW (palette->shell), "color_palette", PROGRAM_NAME);
       gtk_window_set_policy (GTK_WINDOW (palette->shell), FALSE, FALSE, FALSE);
-      gtk_window_set_title (GTK_WINDOW (palette->shell), "Color Palette");
+      gtk_window_set_title (GTK_WINDOW (palette->shell), _("Color Palette"));
       gtk_widget_set_uposition(palette->shell, palette_x, palette_y);
       layout_connect_window_position(palette->shell, &palette_x, &palette_y, TRUE);
       layout_connect_window_visible(palette->shell, &palette_visible);
@@ -266,7 +278,7 @@ palette_create ()
       gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_bar_item), palette->palette_ops);
       arrow_hbox = gtk_hbox_new (FALSE, 1);
       gtk_container_add (GTK_CONTAINER (menu_bar_item), arrow_hbox);
-      label = gtk_label_new ("Ops");
+      label = gtk_label_new (_("Ops"));
       arrow = gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_OUT);
       gtk_box_pack_start (GTK_BOX (arrow_hbox), arrow, FALSE, FALSE, 0);
       gtk_box_pack_start (GTK_BOX (arrow_hbox), label, FALSE, FALSE, 4);
@@ -287,7 +299,7 @@ palette_create ()
 
       /*  The active color name  */
       palette->color_name = gtk_entry_new ();
-      gtk_entry_set_text (GTK_ENTRY (palette->color_name), "Active Color Name");
+      gtk_entry_set_text (GTK_ENTRY (palette->color_name), _("Active Color Name"));
       gtk_box_pack_start (GTK_BOX (vbox), palette->color_name, FALSE, FALSE, 0);
 
       gtk_widget_show (palette->color_name);
@@ -805,7 +817,7 @@ palette_change_color (PixelRow * col,
       switch (state)
 	{
 	case COLOR_NEW:
-	  palette->color = palette_add_entry (palette->entries, "Untitled", d[0], d[1], d[2]);
+	  palette->color = palette_add_entry (palette->entries, _("Untitled"), d[0], d[1], d[2]);
 
 	  palette_calc_scrollbar (palette);
 	  palette_draw_entries (palette);
@@ -936,11 +948,11 @@ palette_new_callback (GtkWidget *w,
     {
       if (active_color == FOREGROUND)
 	palette->color =
-	  palette_add_entry (palette->entries, "Untitled",
+	  palette_add_entry (palette->entries, _("Untitled"),
 			     foreground_data[0], foreground_data[1], foreground_data[2]);
       else if (active_color == BACKGROUND)
 	palette->color =
-	  palette_add_entry (palette->entries, "Untitled",
+	  palette_add_entry (palette->entries, _("Untitled"),
 			     background_data[0], background_data[1], background_data[2]);
 
       palette_calc_scrollbar (palette);
@@ -1056,7 +1068,7 @@ static void
 palette_new_entries_callback (GtkWidget *w,
 			      gpointer   client_data)
 {
-  query_string_box ("New Palette", "Enter a name for new palette", NULL,
+  query_string_box (_("New Palette"), _("Enter a name for new palette"), NULL,
 		    palette_add_entries_callback, NULL);
 }
 
@@ -1450,7 +1462,7 @@ palette_add_entry (PaletteEntriesP  entries,
       if (name)
 	entry->name = g_strdup (name);
       else
-	entry->name = g_strdup ("Untitled");
+	entry->name = g_strdup (_("Untitled"));
       entry->position = entries->n_colors;
 
       entries->colors = g_slist_append (entries->colors, entry);
@@ -1502,7 +1514,7 @@ palette_delete_entry (PaletteP palette)
 	}
 
       if (palette->entries->n_colors == 0)
-	palette->color = palette_add_entry (palette->entries, "Black", 0, 0, 0);
+	palette->color = palette_add_entry (palette->entries, _("Black"), 0, 0, 0);
 
       palette_calc_scrollbar (palette);
       palette_draw_entries (palette);
