@@ -19,6 +19,7 @@
 #include <stdio.h>
 #include <string.h>
 #include "../lib/version.h"
+#include "libgimp/gimpintl.h"
 #include "appenv.h"
 #include "actionarea.h"
 #include "canvas.h"
@@ -113,7 +114,7 @@ pattern_select_new ()
   /*  The shell and main vbox  */
   psp->shell = gtk_dialog_new ();
   gtk_window_set_wmclass (GTK_WINDOW (psp->shell), "patternselection", PROGRAM_NAME);
-  gtk_window_set_title (GTK_WINDOW (psp->shell), "Pattern Selection");
+  gtk_window_set_title (GTK_WINDOW (psp->shell), _("Pattern Selection"));
   vbox = gtk_vbox_new (FALSE, 1);
   gtk_container_border_width (GTK_CONTAINER (vbox), 1);
   gtk_window_set_policy(GTK_WINDOW(psp->shell), FALSE, TRUE, FALSE);
@@ -132,7 +133,7 @@ pattern_select_new ()
   label_box = gtk_hbox_new (FALSE, 1);
   gtk_container_border_width (GTK_CONTAINER (label_box), 2);
   gtk_box_pack_start (GTK_BOX (psp->options_box), label_box, FALSE, FALSE, 0);
-  psp->pattern_name = gtk_label_new ("Active");
+  psp->pattern_name = gtk_label_new (_("Active"));
   gtk_box_pack_start (GTK_BOX (label_box), psp->pattern_name, FALSE, FALSE, 2);
   psp->pattern_size = gtk_label_new ("(0x0)");
   gtk_box_pack_start (GTK_BOX (label_box), psp->pattern_size, FALSE, FALSE, 5);
@@ -183,6 +184,11 @@ pattern_select_new ()
   gtk_widget_show (psp->frame);
 
   /*  The action area  */
+  /*  The action area  */
+  { int i;
+    for(i = 0; i < 2; ++i)
+      action_items[i].label = _(action_items[i].label);
+  }
   action_items[0].user_data = psp;
   action_items[1].user_data = psp;
   build_action_area (GTK_DIALOG (psp->shell), action_items, 2, 0);
