@@ -20,6 +20,7 @@
 #include <stdarg.h>
 #include <string.h>
 #include <sys/types.h>
+#include "libgimp/gimpintl.h"
 #include "appenv.h"
 #include "app_procs.h"
 #include "general.h"
@@ -664,7 +665,7 @@ procedural_db_run_proc (gchar *name,
     {
       if (proc->args[i].arg_type != (params[i].arg_type = va_arg (args, PDBArgType)))
 	{
-	  g_message ("Incorrect arguments passed to procedural_db_run_proc");
+	  g_message (_("Incorrect arguments passed to procedural_db_run_proc"));
 	  g_free (params);
 	  return NULL;
 	}
