@@ -24,6 +24,7 @@
 #include <glib.h>
 #include <string.h>
 
+#include "libgimp/gimpintl.h"
 #include "app_procs.h"
 #include "appenv.h"
 #include "devices.h"
@@ -169,10 +170,17 @@ char *    cms_default_proof_profile_name = NULL;
 char *    cms_workspace_profile_name = NULL;
 char *    cms_display_profile_name = NULL;
 int       cms_default_intent = INTENT_PERCEPTUAL;
+int       cms_bpc_by_default = TRUE;
+int       cms_default_proof_intent = INTENT_RELATIVE_COLORIMETRIC;
 int       cms_default_flags = 0;
 int       cms_open_action = 0;
 int       cms_mismatch_action = 0;
 int       cms_manage_by_default = TRUE;
+#ifdef HAVE_OY
+int       cms_oyranos = FALSE;
+#else
+int       cms_oyranos = FALSE;
+#endif
 int       enable_rulers_on_start = FALSE;
 
 static int get_next_token (void);
@@ -249,7 +257,11 @@ static ParseFunc funcs[] =
   { "cms-default-flags",     TT_INT,        &cms_default_flags, NULL },
   { "cms-open-action",       TT_INT,        &cms_open_action, NULL },
   { "cms-mismatch-action",   TT_INT,        &cms_mismatch_action, NULL },
+  { "cms-bpc-by-default",    TT_BOOLEAN,    &cms_bpc_by_default, NULL },
   { "cms-manage-by-default", TT_BOOLEAN,    &cms_manage_by_default, NULL },
+#ifdef HAVE_OY
+  { "cms-oyranos",           TT_INT,        &cms_oyranos, NULL },
+#endif
   { "look-profile-path",     TT_STRING,     &look_profile_path, NULL },
   { "default-pattern",       TT_STRING,     &default_pattern, NULL },
   { "default-palette",       TT_STRING,     &default_palette, NULL },
@@ -365,7 +377,7 @@ gimp_directory ()
 	      gimp_dir[len_env_home_dir] = '/';
 	    }
 	  else
-	    g_message ("warning: no home directory.");
+	    g_message (_("warning: no home directory."));
 
 	  strncpy (&gimp_dir[len_env_home_dir+1],
 		   env_gimp_dir,
@@ -380,7 +392,7 @@ gimp_directory ()
 	  gimp_dir[len_env_home_dir] = '/';
 	}
       else
-	g_message ("warning: no home directory.");
+	g_message (_("warning: no home directory."));
 
       strncpy (&gimp_dir[len_env_home_dir+1],
 	       GetDirDot(),
@@ -434,10 +446,26 @@ parse_gimprc_file (char *filename)
       filename = rfilename;
     }
 #endif
-	d_printf("parse_gimprc_file: %s\n",filename);
+  d_printf("parse_gimprc_file: %s\n",filename);
   parse_info.fp = fopen (filename, "rt");
+  
   if (!parse_info.fp)
-    return;
+  {
+    char *fn = malloc(2048);
+    char *ptr = NULL;
+
+    ptr = strrchr(filename, '/');
+    ++ptr;
+    if(ptr)
+    {
+      snprintf( fn, 2046, "%s%s%s%s%s", GetDirPrefix(),
+                GetDirSeparator(), GetDirDataSuffix(), GetDirSeparator(),
+                ptr );
+      parse_info.fp = fopen (fn, "rt");
+    }
+    if (!parse_info.fp)
+      return;
+  }
 
   if ((be_verbose == TRUE) || (no_splash == TRUE))
     g_print ("parsing \"%s\"\n", filename);
