@@ -21,6 +21,7 @@
 #include <glib.h>
 #include "appenv.h"
 
+#include "libgimp/gimpintl.h"
 #include "rc.h"
 #include "paint_funcs.h"
 #include "paint_options.h"
@@ -124,7 +125,7 @@ tool_options_new (gchar *title)
   options = g_new (ToolOptions, 1);
   tool_options_init (options, title, NULL);
 
-  label = gtk_label_new ("This tool has no options.");
+  label = gtk_label_new (_("This tool has no options."));
   gtk_box_pack_start (GTK_BOX (options->main_vbox), label, FALSE, FALSE, 6);
   gtk_widget_show (label);
 
@@ -148,20 +149,20 @@ selection_options_init (SelectionOptions     *options,
   /*  initialize the tool options structure  */
   tool_options_init ((ToolOptions *) options,
 		     ((tool_type == RECT_SELECT) ?
-		      "Rectangular Selection" :
+		      _("Rectangular Selection") :
 		      ((tool_type == ELLIPSE_SELECT) ?
-		       "Elliptical Selection" :
+		       _("Elliptical Selection") :
 		       ((tool_type == FREE_SELECT) ?
-			"Free-Hand Selection" :
+			_("Free-Hand Selection") :
 			((tool_type == FUZZY_SELECT) ?
-			 "Fuzzy Selection" :
+			 _("Fuzzy Selection") :
 			 ((tool_type == BEZIER_SELECT) ?
-			  "Bezier Selection" :
+			  _("Bezier Selection") :
 			  ((tool_type == ISCISSORS) ?
-			   "Intelligent Scissors" :
+			   _("Intelligent Scissors") :
 			   ((tool_type == BY_COLOR_SELECT) ?
-			    "By-Color Selection" :
-			    "ERROR: Unknown Select Tool Type"))))))),
+			    _("By-Color Selection") :
+			    _("ERROR: Unknown Select Tool Type")))))))),
 		     reset_func);
 
   /*  the main vbox  */
@@ -193,7 +194,7 @@ selection_options_init (SelectionOptions     *options,
   gtk_table_set_col_spacing (GTK_TABLE (table), 0, 4);
   gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, FALSE, 0);
 
-  options->feather_w = gtk_check_button_new_with_label ("Feather");
+  options->feather_w = gtk_check_button_new_with_label (_("Feather"));
   gtk_table_attach (GTK_TABLE (table), options->feather_w, 0, 1, 0, 1,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK, 0, 0);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (options->feather_w),
@@ -204,7 +205,7 @@ selection_options_init (SelectionOptions     *options,
   gtk_widget_show (options->feather_w);
 
   /*  the feather radius scale  */
-  label = gtk_label_new ("Radius:");
+  label = gtk_label_new (_("Radius:"));
   gtk_misc_set_alignment (GTK_MISC (label), 1.0, 1.0);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
@@ -237,7 +238,7 @@ selection_options_init (SelectionOptions     *options,
   /*  the antialias toggle button  */
   if (tool_type != RECT_SELECT)
     {
-      options->antialias_w = gtk_check_button_new_with_label ("Antialiasing");
+      options->antialias_w = gtk_check_button_new_with_label (_("Antialiasing"));
       gtk_box_pack_start (GTK_BOX (vbox), options->antialias_w, FALSE, FALSE, 0);
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (options->antialias_w),
 				    options->antialias_d);
@@ -273,7 +274,7 @@ selection_options_init (SelectionOptions     *options,
 
       /*  the sample merged toggle  */
       options->sample_merged_w =
-	gtk_check_button_new_with_label ("Sample Merged");
+	gtk_check_button_new_with_label (_("Sample Merged"));
       gtk_box_pack_start (GTK_BOX (vbox), options->sample_merged_w,
 			  FALSE, FALSE, 0);
       gtk_signal_connect (GTK_OBJECT (options->sample_merged_w), "toggled",
@@ -288,7 +289,7 @@ selection_options_init (SelectionOptions     *options,
       gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
       gtk_widget_show (hbox);
   
-      label = gtk_label_new ("Threshold:");
+      label = gtk_label_new (_("Threshold:"));
       gtk_misc_set_alignment (GTK_MISC (label), 1.0, 1.0);
       gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 1);
       gtk_widget_show (label);
@@ -314,7 +315,7 @@ selection_options_init (SelectionOptions     *options,
       GtkWidget *height_spinbutton;
 
       options->fixed_size_w =
-	gtk_check_button_new_with_label ("Fixed Size / Aspect Ratio");
+	gtk_check_button_new_with_label (_("Fixed Size / Aspect Ratio"));
       gtk_box_pack_start (GTK_BOX (vbox), options->fixed_size_w,
 			  FALSE, FALSE, 0);
       gtk_signal_connect (GTK_OBJECT (options->fixed_size_w), "toggled",
@@ -351,7 +352,7 @@ selection_options_init (SelectionOptions     *options,
                           GTK_SIGNAL_FUNC (gimp_double_adjustment_update),
                           &options->fixed_width);
       gimp_table_attach_aligned (GTK_TABLE (table), 0, 0,
-				 "Width:", 1.0, 0.5,
+				 _("Width:"), 1.0, 0.5,
 				 width_spinbutton, 1, FALSE);
 
       options->fixed_height_w =
@@ -367,7 +368,7 @@ selection_options_init (SelectionOptions     *options,
                           GTK_SIGNAL_FUNC (gimp_double_adjustment_update),
                           &options->fixed_height);
       gimp_table_attach_aligned (GTK_TABLE (table), 0, 1,
-				 "Height:", 1.0, 0.5,
+				 _("Height:"), 1.0, 0.5,
 				 height_spinbutton, 1, FALSE);
 
       options->fixed_unit_w =
@@ -380,7 +381,7 @@ selection_options_init (SelectionOptions     *options,
       gtk_object_set_data (GTK_OBJECT (width_spinbutton), "set_digits",
 			   height_spinbutton);
       gimp_table_attach_aligned (GTK_TABLE (table), 0, 2,
-				 "Unit:", 1.0, 0.5,
+				 _("Unit:"), 1.0, 0.5,
 				 options->fixed_unit_w, 1, FALSE);
 
       gtk_widget_show (table);
@@ -473,37 +474,37 @@ paint_options_init (PaintOptions         *options,
   /*  initialize the tool options structure  */
   tool_options_init ((ToolOptions *) options,
 		     ((tool_type == BUCKET_FILL) ?
-		      "Bucket Fill" :
+		      _("Bucket Fill") :
 		      ((tool_type == BLEND) ?
-		       "Blend Tool" :
+		       _("Blend Tool") :
 		       ((tool_type == PENCIL) ?
-			"Pencil" :
+			_("Pencil") :
 			((tool_type == PAINTBRUSH) ?
-			 "Paintbrush" :
+			 _("Paintbrush") :
 			 ((tool_type == ERASER) ?
-			  "Eraser" :
+			  _("Eraser") :
 			  ((tool_type == AIRBRUSH) ?
-			   "Airbrush" :
+			   _("Airbrush") :
 			   ((tool_type == CLONE) ?
-			    "Clone Tool" :
+			    _("Clone Tool") :
 			    ((tool_type == CONVOLVE) ?
-			     "Convolver" :
+			     _("Convolver") :
 #if 0
 			     ((tool_type == INK) ?
-			      "Ink Tool" :
+			      _("Ink Tool") :
 #endif
 			      ((tool_type == DODGEBURN) ?
-			       "Dodge or Burn" :
+			       _("Dodge or Burn") :
 			       ((tool_type == SMUDGE) ?
-				"Smudge Tool" :
+				_("Smudge Tool") :
 			       ((tool_type == MEASURE) ?
-				"Measure Tool" :
+				_("Measure Tool") :
 /*  				((tool_type == XINPUT_AIRBRUSH) ? */
-/*  				 "Xinput Airbrush" : */
+/*  				 _("Xinput Airbrush") : */
 #if 0
-				 "ERROR: Unknown Paint Tool Type"))))))))))),
+				 _("ERROR: Unknown Paint Tool Type")))))))))))),
 #else
-				 "ERROR: Unknown Paint Tool Type"))))))))))),
+				 _("ERROR: Unknown Paint Tool Type")))))))))))),
 #endif
 		     reset_func);
 
@@ -541,7 +542,7 @@ paint_options_init (PaintOptions         *options,
 		      GTK_SIGNAL_FUNC (tool_options_opacity_adjustment_update),
 		      tool_context);
   gimp_table_attach_aligned (GTK_TABLE (table), 0, 0,
-			     "Opacity:", 1.0, 1.0,
+			     _("Opacity:"), 1.0, 1.0,
 			     scale, 1, FALSE);
 
   gtk_signal_connect (GTK_OBJECT (tool_context), "opacity_changed",
@@ -628,7 +629,7 @@ paint_options_init (PaintOptions         *options,
     case PAINTBRUSH:
     case PENCIL:
       options->incremental_w =
-	gtk_check_button_new_with_label ("Incremental");
+	gtk_check_button_new_with_label (_("Incremental"));
       gtk_box_pack_start (GTK_BOX (options->tool_options.main_vbox),
 			  options->incremental_w, FALSE, FALSE, 0);
       gtk_signal_connect (GTK_OBJECT (options->incremental_w), "toggled",
@@ -738,7 +739,7 @@ paint_pressure_options_new (ToolType tool_type)
     case PAINTBRUSH:
     case PENCIL:
     case SMUDGE:
-      frame = gtk_frame_new ("Pressure Sensitivity");
+      frame = gtk_frame_new (_("Pressure Sensitivity"));
       wbox = gtk_hwrap_box_new (FALSE);
       gtk_wrap_box_set_aspect_ratio (GTK_WRAP_BOX (wbox), 6);
       gtk_container_add (GTK_CONTAINER (frame), wbox);
@@ -757,7 +758,7 @@ paint_pressure_options_new (ToolType tool_type)
     case PAINTBRUSH:
     case PENCIL:
       pressure->opacity_w =
-	gtk_check_button_new_with_label ("Opacity");
+	gtk_check_button_new_with_label (_("Opacity"));
       gtk_container_add (GTK_CONTAINER (wbox), pressure->opacity_w);
       gtk_signal_connect (GTK_OBJECT (pressure->opacity_w), "toggled",
 			  GTK_SIGNAL_FUNC (gimp_toggle_button_update),
@@ -780,7 +781,7 @@ paint_pressure_options_new (ToolType tool_type)
     case ERASER:
     case PAINTBRUSH:
     case SMUDGE:
-      pressure->pressure_w = gtk_check_button_new_with_label ("Hardness");
+      pressure->pressure_w = gtk_check_button_new_with_label (_("Hardness"));
       gtk_container_add (GTK_CONTAINER (wbox), pressure->pressure_w);
       gtk_signal_connect (GTK_OBJECT (pressure->pressure_w), "toggled",
 			  GTK_SIGNAL_FUNC (gimp_toggle_button_update),
@@ -800,7 +801,7 @@ paint_pressure_options_new (ToolType tool_type)
     case CONVOLVE:
     case SMUDGE:
       pressure->rate_w =
-	gtk_check_button_new_with_label ("Rate");
+	gtk_check_button_new_with_label (_("Rate"));
       gtk_container_add (GTK_CONTAINER (wbox), pressure->rate_w);
       gtk_signal_connect (GTK_OBJECT (pressure->rate_w), "toggled",
 			  GTK_SIGNAL_FUNC (gimp_toggle_button_update),
@@ -824,7 +825,7 @@ paint_pressure_options_new (ToolType tool_type)
     case PAINTBRUSH:
     case PENCIL:
       pressure->size_w =
-	gtk_check_button_new_with_label ("Size");
+	gtk_check_button_new_with_label (_("Size"));
       gtk_container_add (GTK_CONTAINER (wbox), pressure->size_w);
       gtk_signal_connect (GTK_OBJECT (pressure->size_w), "toggled",
 			  GTK_SIGNAL_FUNC (gimp_toggle_button_update),
@@ -845,7 +846,7 @@ paint_pressure_options_new (ToolType tool_type)
     case PAINTBRUSH:
     case PENCIL:
       pressure->color_w =
-	gtk_check_button_new_with_label ("Color");
+	gtk_check_button_new_with_label (_("Color"));
       gtk_container_add (GTK_CONTAINER (wbox), pressure->color_w);
       gtk_signal_connect (GTK_OBJECT (pressure->color_w), "toggled",
 			  GTK_SIGNAL_FUNC (gimp_toggle_button_update),
@@ -950,24 +951,24 @@ paint_mode_menu_new (GtkSignalFunc    callback,
   menu = gimp_option_menu_new2
     (FALSE, callback, data, (gpointer) initial,
 
-     "Normal",          (gpointer) NORMAL_MODE, NULL,
-     "Dissolve",        (gpointer) DISSOLVE_MODE, NULL,
-     "Behind",          (gpointer) BEHIND_MODE, NULL,
-     "Multiply (Burn)", (gpointer) MULTIPLY_MODE, NULL,
+     _("Normal"),          (gpointer) NORMAL_MODE, NULL,
+     _("Dissolve"),        (gpointer) DISSOLVE_MODE, NULL,
+     _("Behind"),          (gpointer) BEHIND_MODE, NULL,
+     _("Multiply (Burn)"), (gpointer) MULTIPLY_MODE, NULL,
 #if 0
-     "Divide (Dodge)",  (gpointer) DIVIDE_MODE, NULL,
+     _("Divide (Dodge)"),  (gpointer) DIVIDE_MODE, NULL,
 #endif
-     "Screen",          (gpointer) SCREEN_MODE, NULL,
-     "Overlay",         (gpointer) OVERLAY_MODE, NULL,
-     "Difference",      (gpointer) DIFFERENCE_MODE, NULL,
-     "Addition",        (gpointer) ADDITION_MODE, NULL,
-     "Subtract",        (gpointer) SUBTRACT_MODE, NULL,
-     "Darken Only",     (gpointer) DARKEN_ONLY_MODE, NULL,
-     "Lighten Only",    (gpointer) LIGHTEN_ONLY_MODE, NULL,
-     "Hue",             (gpointer) HUE_MODE, NULL,
-     "Saturation",      (gpointer) SATURATION_MODE, NULL,
-     "Color",           (gpointer) COLOR_MODE, NULL,
-     "Value",           (gpointer) VALUE_MODE, NULL,
+     _("Screen"),          (gpointer) SCREEN_MODE, NULL,
+     _("Overlay"),         (gpointer) OVERLAY_MODE, NULL,
+     _("Difference"),      (gpointer) DIFFERENCE_MODE, NULL,
+     _("Addition"),        (gpointer) ADDITION_MODE, NULL,
+     _("Subtract"),        (gpointer) SUBTRACT_MODE, NULL,
+     _("Darken Only"),     (gpointer) DARKEN_ONLY_MODE, NULL,
+     _("Lighten Only"),    (gpointer) LIGHTEN_ONLY_MODE, NULL,
+     _("Hue"),             (gpointer) HUE_MODE, NULL,
+     _("Saturation"),      (gpointer) SATURATION_MODE, NULL,
+     _("Color"),           (gpointer) COLOR_MODE, NULL,
+     _("Value"),           (gpointer) VALUE_MODE, NULL,
 
      NULL);
 
