@@ -17,6 +17,7 @@
  */
 #include <stdlib.h>
 #include "../lib/version.h"
+#include "libgimp/gimpintl.h"
 #include "appenv.h"
 #include "actionarea.h"
 #include "airbrush.h"
@@ -63,14 +64,38 @@
 #include "transform_tool.h"
 #include "layout.h"
 #include "minimize.h"
+/*  DEBUG and DEBUG_TOOLS stuff added by hsbo */
+#include "gtk_debug_helpers.h"
 
-/* Global Data */
+
+/*  Define DEBUG_TOOLS for debug output. Since the used debug functions from
+     tools.c are available only for DEBUG, we tie DEBUG_TOOLS to DEBUG. */
+#if DEBUG
+#  define DEBUG_TOOLS           /* undefine it if unwanted */
+#  undef DEBUG_TOOLS
+#else
+#  undef  DEBUG_TOOLS
+#endif
+
+/*  If `DEBUG_TOOLS' is defined we define an active PRINTF() macro */
+#ifdef DEBUG_TOOLS
+#  define PRINTF(args)       {printf("%4d: ",__LINE__); printf args;}
+#else
+#  define PRINTF(args)
+#endif
+
+
+/*  Global Data */
 
 Tool * active_tool = NULL;
 Layer * active_tool_layer = NULL;
 ToolType active_tool_type = -1;
 
-/* Local Data */
+/*  Only for debugging of active_tool->private->core */
+DrawCore* active_draw_core;
+
+
+/*  Local Data */
 
 static GtkWidget *options_shell = NULL;
 static GtkWidget *options_vbox = NULL;
@@ -179,13 +204,15 @@ static void tools_options_dialog_callback (GtkWidget *, gpointer);
 static gint tools_options_delete_callback (GtkWidget *, GdkEvent *, gpointer);
 
 
-/* Function definitions */
+/*  Function definitions */
 
 static void
 active_tool_free (void)
 {
   /* gtk_container_disable_resize (GTK_CONTAINER (options_shell)); */
 
+  PRINTF(("%s( %s )...\n",__func__, tool_type_name(active_tool) ));
+  
   if (!active_tool)
     return;
 
@@ -300,7 +327,6 @@ active_tool_free (void)
       tools_free_curves (active_tool);
       break;
 #endif
-
     case LEVELS:
       tools_free_levels (active_tool);
       break;
@@ -331,6 +357,9 @@ active_tool_free (void)
 void
 tools_select (ToolType type)
 {
+  PRINTF(("%s( tool=%s )... [active_tool=%s]\n",__func__,
+      TOOL_TYPE_NAMES[type], tool_type_name(active_tool) )); 
+  
   if (active_tool)
     active_tool_free ();
 
@@ -419,8 +448,8 @@ tools_select (ToolType type)
     case SMUDGE:
       active_tool = tools_new_smudge ();
       break;
-	case MEASURE:
-	 active_tool = tools_new_measure_tool();
+    case MEASURE:
+      active_tool = tools_new_measure_tool();
       break;
     case BY_COLOR_SELECT:
       active_tool = tools_new_by_color_select ();
@@ -464,7 +493,7 @@ tools_select (ToolType type)
       active_tool=tools_new_spline_edit();
       break;
     default:
-	active_tool = tools_new_measure_tool();
+      active_tool = tools_new_measure_tool();
       return;
     }
 
@@ -492,6 +521,9 @@ void
 tools_initialize (ToolType type, GDisplay *gdisp_ptr)
 {
   GDisplay *gdisp;
+  
+  PRINTF(("%s( type=%s, display=%p ID=%d )...\n",__func__, TOOL_TYPE_NAMES[type],
+      (void*)gdisp_ptr, gdisplay_to_ID(gdisp_ptr) ));
 
   /* If you're wondering... only these dialog type tools have init functions */
   gdisp = gdisp_ptr;
@@ -591,6 +623,7 @@ tools_initialize (ToolType type, GDisplay *gdisp_ptr)
       active_tool=tools_new_spline_edit();
       break;
 
+    /*  The tools, which fall back to rect_select, if no display:  */
     case BY_COLOR_SELECT:
       if (gdisp) {
 	active_tool = tools_new_by_color_select ();
@@ -640,7 +673,6 @@ tools_initialize (ToolType type, GDisplay *gdisp_ptr)
       }
       break;
 #if 1
-
     case CURVES:
       if (gdisp) {
 	active_tool = tools_new_curves ();
@@ -712,10 +744,12 @@ tools_options_dialog_new ()
     { "Close", tools_options_dialog_callback, NULL, NULL }
   };
 
+  action_items[0].label = _("Close");
+
   /*  The shell and main vbox  */
   options_shell = gtk_dialog_new ();
   gtk_window_set_wmclass (GTK_WINDOW (options_shell), "tool_options", PROGRAM_NAME);
-  gtk_window_set_title (GTK_WINDOW (options_shell), "Tool Options");
+  gtk_window_set_title (GTK_WINDOW (options_shell), _("Tool Options"));
   gtk_window_set_policy (GTK_WINDOW (options_shell), FALSE, TRUE, TRUE);
   gtk_widget_set_uposition (options_shell, tool_options_x, tool_options_y);
   layout_connect_window_position(options_shell, &tool_options_x, &tool_options_y, TRUE);
@@ -767,6 +801,8 @@ void
 tools_register_options (ToolType   type,
 			GtkWidget *options)
 {
+  PRINTF(("%s( type=%s )...\n",__func__, TOOL_TYPE_NAMES[type] ));
+  
   /*  need to check whether the widget is visible...this can happen
    *  because some tools share options such as the transformation tools
    */
@@ -785,6 +821,8 @@ tools_register_no_options (ToolType  tool_type,
   GtkWidget *vbox;
   GtkWidget *label;
 
+  PRINTF(("%s(type=%s, title=%s)...\n",__func__, TOOL_TYPE_NAMES[tool_type], tool_title));
+  
   /*  the main vbox  */
   vbox = gtk_vbox_new (FALSE, 1);
 
@@ -794,7 +832,7 @@ tools_register_no_options (ToolType  tool_type,
   gtk_widget_show (label);
 
   /*  this tool has no special options  */
-  label = gtk_label_new ("This tool has no options.");
+  label = gtk_label_new (_("This tool has no options."));
   gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
 
@@ -808,6 +846,10 @@ void
 active_tool_control (int   action,
 		     void *gdisp_ptr)
 {
+  PRINTF(("%s[atool=%s]( action=%s, display=%p ID=%d )...\n",__func__,
+      tool_type_name(active_tool), tool_action_name(action), 
+      (void*)gdisp_ptr, gdisplay_to_ID(gdisp_ptr) ));
+  
   if (active_tool)
     {
       if (active_tool->gdisp_ptr == gdisp_ptr)
@@ -832,9 +874,8 @@ active_tool_control (int   action,
 		    }
 		}
 	      active_tool->paused_count++;
-
 	      break;
-	    case RESUME :
+            case RESUME :
 	      active_tool->paused_count--;
 	      if (active_tool->state == PAUSED)
 		{
@@ -874,6 +915,12 @@ standard_arrow_keys_func (Tool        *tool,
 			  GdkEventKey *kevent,
 			  gpointer     gdisp_ptr)
 {
+# ifdef DEBUG_TOOLS
+  PRINTF(("%s( tool=%s, display=%p ID=%d )...\n", __func__, 
+      tool_type_name(tool), (void*)gdisp_ptr, gdisplay_to_ID(gdisp_ptr) ));
+  report_GdkEventKey (kevent);
+  printf("\t\t"); print_GdkEventKeyArrow(kevent);  
+# endif
 }
 
 static gint
@@ -895,3 +942,112 @@ tools_options_dialog_callback (GtkWidget *w,
   shell = (GtkWidget *) client_data;
   gtk_widget_hide (shell);
 }
+
+
+
+/*  Debug helpers  -  included for DEBUG, not only for DEBUG_TOOLS, so other
+                        debug clients can refer to it too */
+#ifdef DEBUG
+
+/*  Names of the four tool states. Debug helper */
+const char* const TOOL_STATE_NAMES[] = 
+{
+  "INACTIVE",           /*  = 0  */
+  "ACTIVE",             /*  = 1  */
+  "PAUSED",             /*  = 2  */
+  "INACT_PAUSED"        /*  = 3  */
+};
+
+const char* tool_state_name (int state) 
+{
+  if (0 <= state && state < 4)
+    return TOOL_STATE_NAMES[state];
+  
+  return "(unknown state)";
+}  
+
+
+/*  Names of the six "tool control actions". Debug helper */
+const char* const TOOL_ACTION_NAMES[] = 
+{
+  "PAUSE",              /*  = 0  */
+  "RESUME",
+  "HALT",
+  "CURSOR_UPDATE",
+  "DESTROY",
+  "RECREATE"            /*  = 5  */
+};
+
+const char* tool_action_name (int action) 
+{
+  if (0 <= action && action < 6)
+    return TOOL_ACTION_NAMES[action];
+  
+  return "(unknown action)";
+}  
+
+/*  Names of the `ToolType' enums. Debug helper */
+const char* const TOOL_TYPE_NAMES[] =
+{
+  "RECT_SELECT",
+  "ELLIPSE_SELECT",
+  "FREE_SELECT",
+  "FUZZY_SELECT",
+  "BEZIER_SELECT",
+  "ISCISSORS",
+  "MOVE",
+  "MAGNIFY",
+  "CROP",
+  "ROTATE",
+  "SCALE",
+  "SHEAR",
+  "PERSPECTIVE",
+  "FLIP_HORZ",
+  "FLIP_VERT",
+  "TEXT",
+  "SPLINE",
+  "COLOR_PICKER",
+  "BUCKET_FILL",
+  "BLEND",
+  "PENCIL",
+  "PAINTBRUSH",
+  "ERASER",
+  "AIRBRUSH",
+  "CLONE",
+  "CONVOLVE",
+  "DODGEBURN",
+  "SMUDGE",
+  "MEASURE",
+  "SPLINE_EDIT",
+  /*  Non-toolbox tools  */
+  "BY_COLOR_SELECT (~)",
+  "COLOR_BALANCE (~)",
+  "BRIGHTNESS_CONTRAST (~)",
+  "HUE_SATURATION (~)",
+  "POSTERIZE (~)",
+  "THRESHOLD (~)",
+  "CURVES (~)",
+  "LEVELS (~)",
+  "HISTOGRAM (~)", 
+  "GAMMA_EXPOSE (~)",
+  "EXPOSE_IMAGE (~)"
+};
+
+static const int n_tool_type_names = 
+  sizeof(TOOL_TYPE_NAMES) / sizeof(TOOL_TYPE_NAMES[0]);
+
+const char* tool_type_name (Tool* tool)
+{
+  if (!tool) 
+    return "(null)";
+  
+  if (0 <= tool->type && tool->type < n_tool_type_names)
+    return TOOL_TYPE_NAMES [tool->type];
+  
+  return "(unknown type)";
+}
+
+#endif  /* DEBUG */
+
+/* END OF FILE */
+
