@@ -13,17 +13,28 @@
 
 #include <unistd.h>
 
+
+/*  Macros for removable tracing and with line numbering  -hsbo */
+#define TRACE_ENTER(args)       {trace_line_no_=__LINE__; trace_enter args ;}
+#define TRACE_EXIT              {trace_line_no_=__LINE__; trace_exit();}
+#define TRACE_BEGIN(args)       {trace_line_no_=__LINE__; trace_begin args ;}
+#define TRACE_END               {trace_line_no_=__LINE__; trace_end();}
+#define TRACE_PRINTF(args)      {trace_line_no_=__LINE__; trace_printf args ;}
+
 typedef struct
 {
   struct timeval a;
   struct timeval b;
 } TraceTimer;
 
-void trace_enter   (char * func);
+extern int trace_depth_;        /*  depth of tracing  -hsbo */
+extern int trace_line_no_;      /*  set by TRACE macros  -hsbo */
+
+void trace_enter   (const char * func);
 void trace_exit    (void); 
-void trace_begin   (char * format, ...);
+void trace_begin   (const char * format, ...);
 void trace_end     (void);
-void trace_printf  (char * format, ...);
+void trace_printf  (const char * format, ...);
 
 void trace_timer_init (TraceTimer * t);
 void trace_timer_tick (TraceTimer * t, char * pre, char * post);
@@ -33,10 +44,10 @@ void print_elapsed (char *, TraceTimer *t );
 
 void 
 print_area (
-			PixelArea *pa,
-			int row,
-			int how_many_rows
-			);
+		PixelArea *pa,
+		int row,
+		int how_many_rows
+		);
 void
 pixelrow_print (
 		 PixelRow *row
