@@ -2064,7 +2064,7 @@ undo_pop_gimage_mod (GImage *gimage,
   channel_invalidate_previews (gimage->ID);
   layer_invalidate_previews (gimage->ID);
   gimage_invalidate_preview (gimage);
-  gdisplays_update_full (gimage->ID);
+  gdisplays_update_gimage (gimage->ID);
   gdisplays_update_title (gimage->ID);
 
   indexed_palette_update_image_list ();
