@@ -86,9 +86,12 @@ gimp_display_active ()
                                     &nreturn_vals,
                                     PARAM_END);
 
+  printf("%s:%d %s() %d  0x%x|%d\n",__FILE__,__LINE__,__func__, display_ID, return_vals[1].data.d_display, return_vals[1].data.d_int32);
   display_ID = -1;
-  if (return_vals[1].data.d_status == STATUS_SUCCESS)
-    display_ID = return_vals[0].data.d_display;
+  if (return_vals[0].data.d_status == STATUS_SUCCESS)
+    display_ID = return_vals[1].data.d_display;
+
+  printf("%s:%d %s() %d:%d ID:%d  0x%x|%d\n",__FILE__,__LINE__,__func__, return_vals[0].data.d_status, STATUS_SUCCESS, display_ID, return_vals[1].data.d_display, return_vals[1].data.d_int32);
 
   gimp_destroy_params (return_vals, nreturn_vals);
 
@@ -123,7 +126,8 @@ gimp_displays_flush ()
 }
 
 int
-gimp_display_get_cms_intent (gint32 display_ID)
+gimp_display_get_cms_intent (gint32 display_ID, 
+                             CMSProfileType type )
 {
   GParam *return_vals;
   int nreturn_vals;
@@ -132,6 +136,7 @@ gimp_display_get_cms_intent (gint32 display_ID)
   return_vals = gimp_run_procedure ("gimp_display_get_cms_intent",
                                     &nreturn_vals,
                                     PARAM_DISPLAY, display_ID,
+                                    PARAM_INT32, type,
                                     PARAM_END);
 
   if (return_vals[0].data.d_status == STATUS_SUCCESS)
@@ -143,7 +148,8 @@ gimp_display_get_cms_intent (gint32 display_ID)
 }
 
 void
-gimp_display_set_cms_intent (gint32 display_ID, gint32 intent)
+gimp_display_set_cms_intent (gint32 display_ID, gint32 intent,
+                             CMSProfileType type )
 {
   GParam *return_vals;
   int nreturn_vals;
@@ -152,6 +158,7 @@ gimp_display_set_cms_intent (gint32 display_ID, gint32 intent)
                                     &nreturn_vals,
                                     PARAM_DISPLAY, display_ID,
                                     PARAM_INT32, intent,
+                                    PARAM_INT32, type,
                                     PARAM_END);
 
   gimp_destroy_params (return_vals, nreturn_vals);
@@ -195,7 +202,8 @@ gimp_display_set_cms_flags (gint32 display_ID, gint32 flags)
 }
 
 int
-gimp_display_is_colormanaged (gint32 display_ID)
+gimp_display_is_colormanaged (gint32 display_ID, 
+                              CMSProfileType type )
 {
   GParam *return_vals;
   int nreturn_vals;
@@ -204,6 +212,7 @@ gimp_display_is_colormanaged (gint32 display_ID)
   return_vals = gimp_run_procedure ("gimp_display_is_colormanaged",
                                     &nreturn_vals,
                                     PARAM_DISPLAY, display_ID,
+                                    PARAM_INT32, type,
                                     PARAM_END);
 
   if (return_vals[0].data.d_status == STATUS_SUCCESS)
@@ -215,7 +224,8 @@ gimp_display_is_colormanaged (gint32 display_ID)
 }
 
 void
-gimp_display_set_colormanaged (gint32 display_ID, gint32 colormanaged)
+gimp_display_set_colormanaged (gint32 display_ID, gint32 colormanaged, 
+                               CMSProfileType type )
 {
   GParam *return_vals;
   int nreturn_vals;
@@ -224,6 +234,7 @@ gimp_display_set_colormanaged (gint32 display_ID, gint32 colormanaged)
                                     &nreturn_vals,
                                     PARAM_DISPLAY, display_ID,
                                     PARAM_INT32, colormanaged,
+                                    PARAM_INT32, type,
                                     PARAM_END);
 
   gimp_destroy_params (return_vals, nreturn_vals);
