@@ -174,6 +174,15 @@ gimp_main (int   argc,
 	gimp_quit ();
 	return 0;
     }
+  else
+  {
+    int yes = 1;
+
+    if( getenv("CP_DBG_PLUG_IN") )
+      if( strstr( argv[0], getenv("CP_DBG_PLUG_IN") ) )
+        while (yes)
+          ;
+  }
 
   g_set_message_handler ((GPrintFunc) gimp_message_func);
 
