@@ -331,15 +331,19 @@ gint32 gimp_display_active  ();
 void   gimp_display_delete (gint32 display_ID);
 void   gimp_displays_delete_image (gint32 image_ID);
 DLL_API void   gimp_displays_flush (void);
-gint32     gimp_display_get_cms_intent        (gint32   display_ID);
+gint32     gimp_display_get_cms_intent        (gint32   display_ID,
+                                               CMSProfileType type);
 void       gimp_display_set_cms_intent        (gint32   display_ID,
-                                               gint32   intent);
+                                               gint32   intent,
+                                               CMSProfileType type);
 gint32     gimp_display_get_cms_flags         (gint32   display_ID);
 void       gimp_display_set_cms_flags         (gint32   display_ID,
                                                gint32   flags);
-gint32     gimp_display_is_colormanaged       (gint32   display_ID);
+gint32     gimp_display_is_colormanaged       (gint32   display_ID,
+                                               CMSProfileType type);
 void       gimp_display_set_colormanaged      (gint32   display_ID,
-                                               gboolean True_False);
+                                               gboolean True_False,
+                                               CMSProfileType type);
 void       gimp_display_all_set_colormanaged  (gboolean True_False);
 void       gimp_display_image_set_colormanaged(gint32   display_ID,
                                                gboolean True_False);
