@@ -1,12 +1,12 @@
-// precision.h
-// Bit-stuff for wire protocol, resolves conflict between tag.h and enums.h
-// Copyright Jan 1, 2003, Robin.Rowe@MovieEditor.com
-// License MIT (http://opensource.org/licenses/mit-license.php)
+/* precision.h */
+/* Bit-stuff for wire protocol, resolves conflict between tag.h and enums.h */
+/* Copyright Jan 1, 2003, Robin.Rowe@MovieEditor.com */
+/* License MIT (http://opensource.org/licenses/mit-license.php) */
 
 #ifndef PRECISION_H
 #define PRECISION_H
 
-#include "../lib/dll_api.h"
+#include "dll_api.h"
 
 /* supported precisions */
 typedef enum
