@@ -12,8 +12,8 @@
 
   TODO (HS):
   - Check the possibility of performing "in place" or "in situ" (or
-    whatever it is called) on[in?] the entry matrix `Arg'.
-  - Make getS() safe for m < n.
+    whatever it is called) on[in?] the input matrix `Arg'.
+  - Make getS() safe for m .<. n.
   - Improve rank() for floats.
 
 */
@@ -26,8 +26,13 @@
 #include "tnt_array2d_utils.hpp"
 #include "tnt_math_utils.hpp"
 
+#include <algorithm>		// HS: like version 1.2.4
+// for min(), max() below
+#include <cmath>		// HS: like version 1.2.4
+// for abs() below
 
 using namespace TNT;
+using namespace std;
 
 namespace JAMA
 {
@@ -104,7 +109,7 @@ class SVD
     int rank ();                // HS: works satisfied only for double
 
 
-    /**
+    /** HS:
       Solve the (linear least square) problem Ax=b for given (m)-vector b.
       @return    normal solution (n)-vector x.
     */
@@ -126,7 +131,7 @@ SVD <Real>::SVD (const Array2D<Real> &Arg)
       V = Array2D<Real>(n,n);
       Array1D<Real> e(n);
       Array1D<Real> work(m);
-      Array2D<Real> A(Arg.copy());        // HS: Muss das sein?
+      Array2D<Real> A(Arg.copy());        // HS: copy() - muss das sein?
       int wantu = 1;                      /* boolean */
       int wantv = 1;                      /* boolean */
       int i=0, j=0, k=0;
@@ -435,7 +440,7 @@ SVD <Real>::SVD (const Array2D<Real> &Arg)
                double b = ((spm1 + sp)*(spm1 - sp) + epm1*epm1)/2.0;
                double c = (sp*epm1)*(sp*epm1);
                double shift = 0.0;
-               if ((b != 0.0) | (c != 0.0)) {
+               if ((b != 0.0) || (c != 0.0)) {
                   shift = sqrt(b*b + c);
                   if (b < 0.0) {
                      shift = -shift;
@@ -558,24 +563,24 @@ void SVD<Real>::getU (Array2D<Real> &A)
     @return     S
 
     HS:
-    BUG: Der interne Vektor s wird kreiert mit der Dimension min(m+1,n).
-    Falls Ausgangs-(m,n)-Matrix m+1 < n, ist s-Dim < n und es gibt eine
-    Bereichsueberschreitung bei A[i][i] = s[i], da i bis inkl. n-1 laeuft.
+    @BUG: Der interne Vektor `s' wird kreiert mit der Dimension min(m+1,n).
+     Falls Ausgangs-(m,n)-Matrix m+1 .<. n, ist dim(s) .<. n und es gibt eine
+     Bereichsueberschreitung bei A[i][i] = s[i], da i bis inkl. n-1 laeuft.
 
     Kuerzere Formulierung:
 
     A = Array2D<Real> (n,n, 0.);  // mit eventl. optimiertem Nullsetzen.
     for (int i=0; i < n; i++)
-        A[i][i] = s[i];
+       A[i][i] = s[i];
 */
 template <class Real>
 void SVD<Real>::getS (Array2D<Real> &A)
 {
     //std::cout << "getS(): (m,n)=" << m << ", " << n << "\n";
     //std::cout << s;
-    A = Array2D<Real>(n,n);             // HS: why not so:
-    for (int i = 0; i < n; i++)         // Array2D<Real>(n,n,0)?
-    {                                   // Because then the i-loop twice?
+    A = Array2D<Real>(n,n);             // HS: why not: Array2D<Real>(n,n,0)?
+    for (int i = 0; i < n; i++)         //  Because the i-loop then twice?
+    {
         for (int j = 0; j < n; j++)
             A[i][j] = 0.0;
 
@@ -594,7 +599,7 @@ int SVD<Real>::rank ()
 {
     double eps = pow(2.0,-52.0);
     double tol = max(m,n)*s[0]*eps;
-    std::cout << "SVD::rank(): eps = " << eps << "  tol = " << tol << "\n";
+    //std::cout << "SVD::rank(): eps = " << eps << "  tol = " << tol << "\n";
     int r = 0;
     for (int i=0; i < s.dim(); i++)
     {
@@ -605,7 +610,8 @@ int SVD<Real>::rank ()
 }
 
 
-/** HS-add:
+/**  
+    HS-add:
     Solve the (linear least square) problem Ax=b for a given (m)-vector b.
     @return: normal solution (n)-vector x.
 
@@ -622,8 +628,8 @@ Array1D<Real> SVD<Real>::solve (const Array1D<Real> b)
 
     int rnk = rank();
 
-    std::cout << "SVD::solve()...:  ";
-    std::cout << "A[ " << m << ", " << n << " ],  rank = " << rnk << "\n";
+    //std::cout << "SVD::solve()...:  ";
+    //std::cout << "A[ " << m << ", " << n << " ],  rank = " << rnk << "\n";
 
     // Calculate (n)-vector beta = U^T * b:
 
@@ -653,7 +659,7 @@ Array1D<Real> SVD<Real>::solve_1 (const Array1D<Real> b)
     int rnk = rank();
     int d = min(m,n) - rnk;     // defect
 
-    std::cout << "SVD::solve()...:  ";
+    std::cout << "SVD::solve_1()...:  ";
     std::cout << "A[ " << m << ", " << n << " ],  rank = " << rnk << "\n";
     if (d)
     {   std::cout << "Rank defect: " << d << "-parametric solution "
@@ -690,7 +696,7 @@ Array1D<Real> SVD<Real>::solve_2 (const Array1D<Real> b)
     int rnk = rank();
     int d = min(m,n) - rnk;     // rank defect
 
-    std::cout << "SVD::solve()...:  ";
+    std::cout << "SVD::solve_2()...:  ";
     std::cout << "A[ " << m << ", " << n << " ],  rank = " << rnk << "\n";
     if (d)
     {   std::cout << "Rank defect: " << d << "-parametric solution "
