@@ -2,7 +2,7 @@
   Meine Ergaenzung der Klasse Stopwatch aus "stopwatch.h[pp]" um die
   Funktion `result()', die stoppt und das Ergebnis ausgibt. Spart beim
   Anwender zwei Zeilen: "double zeit;" und "std::cout...".
-  In extra Datei, da hier <ostream> bzw. <cstdio> notwendig wird.
+  In Extra-Datei, da hier <ostream> bzw. <cstdio> notwendig wird.
   Vielleicht ueberfluessige Sorge, aber wer weiss.
 */
 #ifndef TNT_STOPWATCH__HPP
@@ -11,8 +11,8 @@
 #include <iostream>
 #include "tnt_stopwatch.hpp"
 
-namespace TNT
-{
+namespace TNT {
+
 
 class StopWatch : public TNT::Stopwatch {
 
@@ -26,9 +26,8 @@ class StopWatch : public TNT::Stopwatch {
     }
 };
 
-}   // namespace
-
-#endif  // TNT_STOPWATCH_HPP
 
+}  // namespace
+#endif  // TNT_STOPWATCH__HPP
 
 // END OF FILE
