@@ -52,6 +52,7 @@
 #include "lib/plugin_main.h"
 #include "lib/ui.h"
 #include "../../lib/wire/iodebug.h"
+#include <libgimp/stdplugins-intl.h>
 
 #define VERBOSE 0
 
@@ -261,6 +262,8 @@ run (char    *name,		/* I - Name of filter program. */
 
   run_mode = param[0].data.d_int32;
 
+  INIT_I18N_UI();
+
   /* what are we doing? */
 
   if (run_mode == RUN_INTERACTIVE) { interactive = 1; }
@@ -485,16 +488,16 @@ load_image(char *filename, LogImageByteConversionParameters *conversion,
   logImage = logImageOpen(filename, use_cineon);
 
   if (logImage == NULL) {
-    g_print("can't open image file\n");
+    g_print("can't open image file: %s\n", filename);
     gimp_quit();
   }
 
   logImageSetByteConversion(logImage, conversion);
 
   if (strrchr(filename, '/') != NULL) {
-    sprintf(progress, "Loading %s:", strrchr(filename, '/') + 1);
+    sprintf(progress, "%s %s:", _("Loading"), strrchr(filename, '/') + 1);
   } else {
-    sprintf(progress, "Loading %s:", filename);
+    sprintf(progress, "%s %s:", _("Loading"), filename);
   }
 
   gimp_progress_init(progress);
@@ -555,7 +558,7 @@ load_image(char *filename, LogImageByteConversionParameters *conversion,
   * Create the "background" layer to hold the image...
   */
 
-  layer = gimp_layer_new(image, "Background", width, height,
+  layer = gimp_layer_new(image, _("Background"), width, height,
                          layer_type, 100, NORMAL_MODE);
   gimp_image_add_layer(image, layer, 0);
 
@@ -614,7 +617,7 @@ load_image(char *filename, LogImageByteConversionParameters *conversion,
   logImageClose(logImage);
 
   if (lastLineRead != (height - 1)) {
-    g_print("Bad image file, last line read was %d\n", lastLineRead);
+    g_print(")Bad image file, last line read was %d\n", lastLineRead);
   }
 
   g_free(pixels[0]);
@@ -700,9 +703,9 @@ save_image(char* filename, gint32 image_ID, gint32 drawable_ID,
   logImageSetByteConversion(logImage, conversion);
 
   if (strrchr(filename, '/') != NULL)
-    progress = g_strdup_printf("Saving %s:", strrchr(filename, '/') + 1);
+    progress = g_strdup_printf("%s %s:", _("Saving"), strrchr(filename, '/') + 1);
   else
-    progress = g_strdup_printf("Saving %s:", filename);
+    progress = g_strdup_printf("%s %s:", _("Saving"), filename);
   gimp_progress_init(progress);
   g_free(progress);
 
@@ -867,7 +870,7 @@ conversion_dialog(LogImageByteConversionParameters *conversion) {
   gtk_button_box_set_spacing(GTK_BUTTON_BOX (button_box), 4);
   gtk_box_pack_end(GTK_BOX (GTK_DIALOG (gui.dialog)->action_area), button_box, FALSE, FALSE, 0);
  
-  button = gtk_button_new_with_label ("OK");
+  button = gtk_button_new_with_label (_("OK"));
   GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
   gtk_signal_connect(GTK_OBJECT (button), "clicked",
 		      (GtkSignalFunc) conversion_ok_callback,
@@ -875,14 +878,14 @@ conversion_dialog(LogImageByteConversionParameters *conversion) {
   gtk_box_pack_start(GTK_BOX (button_box), button, FALSE, FALSE, 0);
   gtk_widget_grab_default(button);
 
-  button = gtk_button_new_with_label ("Cancel");
+  button = gtk_button_new_with_label (_("Cancel"));
   GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
   gtk_signal_connect_object(GTK_OBJECT (button), "clicked",
 			     (GtkSignalFunc) gtk_widget_destroy,
 			     GTK_OBJECT (gui.dialog));
   gtk_box_pack_start(GTK_BOX (button_box), button, FALSE, FALSE, 0);
 
-  frame = gtk_frame_new("Conversion");
+  frame = gtk_frame_new(_("Conversion"));
   gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_ETCHED_IN);
   gtk_container_set_border_width(GTK_CONTAINER(frame), 10);
   gtk_box_pack_start(GTK_BOX (GTK_DIALOG(gui.dialog)->vbox), frame, TRUE, TRUE, 0);
@@ -899,7 +902,7 @@ conversion_dialog(LogImageByteConversionParameters *conversion) {
   gui.white_adj =
     gtk_adjustment_new(conversion->whitePoint, 0.0, 1023.0, 1.0, 1.0, 0.0);
 
-  label = gtk_label_new("Gamma");
+  label = gtk_label_new(_("Gamma"));
   gtk_table_attach(GTK_TABLE(table), label, 0, 1, row, row+1, flags, flags, 3, 2);
   spin = gtk_spin_button_new(GTK_ADJUSTMENT(gui.gamma_adj), 0.0, 3);
   /* get a good size for the spinners */
@@ -912,13 +915,13 @@ conversion_dialog(LogImageByteConversionParameters *conversion) {
   gtk_table_attach(GTK_TABLE(table), scale, 2, 5, row, row+1, flags, flags, 3, 2);
   ++row;
 
-  message = gtk_label_new("Hi there");
+  message = gtk_label_new(_("Hi there"));
   setMessage(GTK_ADJUSTMENT(gui.gamma_adj), message);
   gtk_table_attach(GTK_TABLE(table), message, 0, 5, row, row+1, flags, flags, 3, 2);
   gtk_signal_connect(gui.gamma_adj, "value_changed", GTK_SIGNAL_FUNC(setMessage), message);
   ++row;
 
-  label = gtk_label_new("Black");
+  label = gtk_label_new(_("Black"));
   gtk_table_attach(GTK_TABLE(table), label, 0, 1, row, row+1, flags, flags, 3, 2);
   spin = gtk_spin_button_new(GTK_ADJUSTMENT(gui.black_adj), 0.0, 0);
   gtk_widget_set_usize(spin, spinWidth, 0);
@@ -929,7 +932,7 @@ conversion_dialog(LogImageByteConversionParameters *conversion) {
   gtk_table_attach(GTK_TABLE(table), scale, 2, 5, row, row+1, flags, flags, 3, 2);
   ++row;
 
-  label = gtk_label_new("White");
+  label = gtk_label_new(_("White"));
   gtk_table_attach(GTK_TABLE(table), label, 0, 1, row, row+1, flags, flags, 3, 2);
   spin = gtk_spin_button_new(GTK_ADJUSTMENT(gui.white_adj), 0.0, 0);
   gtk_widget_set_usize(spin, spinWidth, 0);
@@ -943,7 +946,7 @@ conversion_dialog(LogImageByteConversionParameters *conversion) {
   box = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
   /*  box = gtk_hbox_new(FALSE, 0); */
   gtk_table_attach(GTK_TABLE(table), box, 0, 5, row, row+1, flags, flags, 3, 2);
-  button = gtk_button_new_with_label("  Reset  ");
+  button = gtk_button_new_with_label(_("  Reset  "));
   gtk_signal_connect(GTK_OBJECT(button), "clicked",
     GTK_SIGNAL_FUNC(resetConversion), (gpointer)&gui);
   /*  gtk_box_pack_end(GTK_BOX(box), button, FALSE, FALSE, 0); */
