@@ -35,6 +35,7 @@
 #include "gtk/gtk.h"
 #include "lib/plugin_main.h"
 #include "lib/ui.h"
+#include <libgimp/stdplugins-intl.h>
 #include "fromrad.h"
 //#include "app/image_render.h"
 
@@ -180,6 +181,8 @@ run (char    *name,
 
   run_mode = param[0].data.d_int32;
 
+  INIT_I18N_UI();
+
   *nreturn_vals = 1;
   *return_vals = values;
   values[0].type = PARAM_STATUS;
@@ -297,7 +300,7 @@ gint32 load_image(gchar * filename)
 
     /* create new layer - local variable */
     layer_id =
-		gimp_layer_new(data->image_id, "Background",
+		gimp_layer_new(data->image_id, _("Background"),
 		      xsize, ysize, ltype,
 		      100, NORMAL_MODE);
     gimp_image_add_layer(data->image_id, layer_id, 0);
@@ -313,7 +316,7 @@ gint32 load_image(gchar * filename)
  
     /* load image */
   
-    gimp_progress_init (g_strconcat("Loading ",filename,NULL));
+    gimp_progress_init (g_strconcat(_("Loading "),filename,NULL));
 
     tile_height = gimp_tile_height(); 
 
@@ -420,6 +423,9 @@ save_image (char   *filename,
   int begin,end,num;
   int tile_height;
 
+  /* allocate the raw_gimp_data structure */
+  data = (raw_gimp_data *)g_malloc0(sizeof(raw_gimp_data));
+
   gint bpp = 16;
  
   guchar *pixel = NULL;
@@ -430,11 +436,29 @@ save_image (char   *filename,
   height = drawable->height;
   bpp = drawable->bpp;
   
+  switch (drawable_type) {
+    case FLOAT_RGBA_IMAGE:
+    case FLOAT_RGB_IMAGE: break;
+	  
+    case GRAY_IMAGE:
+    case GRAYA_IMAGE:
+    case U16_GRAY_IMAGE:
+    case U16_GRAYA_IMAGE:
+    case FLOAT16_GRAY_IMAGE:
+    case FLOAT16_GRAYA_IMAGE:
+    case FLOAT_GRAY_IMAGE:
+    case FLOAT_GRAYA_IMAGE:
+    default:
+         g_message (_("HDR supports only 32-bit IEEE Float RGB image type."));
+         return FALSE;
+         break;
+    }
+
   gimp_pixel_rgn_init (&data->region, drawable, 0, 0, width, height, FALSE, FALSE);
 
   name = malloc (strlen (filename) + 11);
 
-  sprintf (name, "Saving %s:", filename);
+  sprintf (name, "%s %s:",_("Saving"), filename);
   gimp_progress_init (name);
   free (name);
 
@@ -512,6 +536,7 @@ save_image (char   *filename,
         fclose(alphafile);
 
     g_free (pixel);
+    g_free (data);
 
     gimp_drawable_detach (drawable);
 
