@@ -44,9 +44,9 @@
 #define PLUG_IN_DESCRIPTION   "Loads an assigned ICC profil from image to ICC Examin."
 #define PLUG_IN_DESCRIPTION2  "Loads an assigned ICC proof profil from image to ICC Examin."
 #define PLUG_IN_DESCRIPTION3  "Shows some colours of the image in a ICC Examin including profile gamut"
-#define PLUG_IN_VERSION       "0.3.8-2 - 13 October 2005"
+#define PLUG_IN_VERSION       "0.3.9 - 10 Februar 2006"
 #define PLUG_IN_AUTHOR        "Kai-Uwe Behrmann <ku.b@gmx.de>"
-#define PLUG_IN_COPYRIGHT     "2004/2005 Kai-Uwe Behrmann"
+#define PLUG_IN_COPYRIGHT     "2004-2006 Kai-Uwe Behrmann"
 
 /***   includes   ***/
 
@@ -63,16 +63,17 @@ using namespace std;
 
 
 extern "C" {
+#include "lib/version.h"
 #include "lib/plugin_main.h"
-#include "lib/wire/libtile.h"
-#include "plugin_pdb.h"
+//#include "lib/wire/libtile.h"
+//#include "plugin_pdb.h"
+#include "libgimp/stdplugins-intl.h"
 #include <lcms.h>
 #include <icc34.h>
 }
 
 
 /*** local macros ***/
-//#define DEBUG
 #ifdef DEBUG
 #define DBG_ cout << __FILE__<<":"<<__LINE__ <<" "<< __func__ << "() " ;
 #define DBG  {DBG_ cout << endl;}
@@ -139,6 +140,7 @@ typedef int ChanModE;
 
 /** alle Layer relevanten Informationen */
 struct Channel {
+  gint32        display_ID;      //!< die Ansicht
   gint32        ID;              //!< drawable_ID
   GimpDrawable *drawable;
   GDrawableType/*GimpDrawableType*/ drawable_type;
@@ -156,6 +158,7 @@ struct Channel {
   icUInt32Number intent;         //!< CinePaint &Uuml;bertragungsart
   ChanModE      status;          //!< Aufgaben f&uuml;r sp&auml;ter
   Channel() {
+    display_ID = 0;
     ID = 0;
     drawable = 0;
     drawable_type = RGB_IMAGE;
@@ -353,7 +356,7 @@ query ()
   n_return_vals_ = sizeof (return_vals) / sizeof (return_vals[0]);
 
   #ifndef WIN32
-  dependency_error = system("which iccexamin");
+  dependency_error = system("export PATH=$PATH:/opt/local/bin; which iccexamin");
   #endif
 
   if(!dependency_error)
@@ -406,6 +409,10 @@ query ()
                             n_args_, n_return_vals_,
                             args, return_vals);
   }
+  _("Image Profile");
+  _("Proof Profile");
+  _("Watch Colours");
+  _("Watch Colours2");
 }
 
 /** @brief plug-in Start
@@ -423,7 +430,7 @@ run (char    *name,
      int     *nreturn_vals,
      GParam **return_vals)
 {
-  GParam values[n_return_vals_];
+  GParam values[12];
   gint32 image_ID;
   GRunModeType run_mode;
   GStatusType status = GIMP_PDB_SUCCESS;
@@ -566,8 +573,9 @@ doExamin (gint32 image_ID, CMSProfileType typ)
     else
       profil_temp_name << "/tmp/icc_examin_temp_" << dateiname << "_" << typ << ".icc";
     schreibeDatei(mem_profile, size, profil_temp_name.str());
-    std::string tn = "iccexamin ";
+    std::string tn = "export PATH=$PATH:/opt/local/bin; iccexamin '";
     tn += profil_temp_name.str();
+    tn += "'";
     system (tn.c_str());
     remove( profil_temp_name.str().c_str() );
   } else
@@ -781,7 +789,11 @@ vergleicheFarben(void* zeiger)
   static std::vector<double> vorherige_farben;
 
   DBG_S( "zeiger " << (int*)zeiger )
-  #define WARN_S(text) { cout << text << " "; DBG }
+# ifdef DEBUG
+# define WARN_S(text) { cout << text << " "; DBG }
+# else
+# define WARN_S(text)
+# endif
 
   if(!layer) {
     farbe_pruefen_laeuft = false;
@@ -833,8 +845,8 @@ vergleicheFarben(void* zeiger)
     for( int x = 0; x < x_num; ++x )
       for( int y = 0; y < y_num; ++y )
       {
-        x_punkt = x_start + x*x_diff;
-        y_punkt = y_start + y*y_diff;
+        x_punkt = (int)(x_start + x*x_diff);
+        y_punkt = (int)(y_start + y*y_diff);
 
         holeFarbPunkt(layer, x_punkt, y_punkt,
                       buf, n, colour_x);
@@ -1012,8 +1024,9 @@ waechter (void* zeiger)
     tn += b;  // die Farben
     tn += " ";
     tn += a;  // das Bildprofil
-    tn += " ";
+    tn += " '";
     tn += p;  // das Proofprofil
+    tn += "'";
 
     DBG_S( tn )
 
@@ -1055,15 +1068,15 @@ pthreatFehler (int fehler)
 {
   if( fehler == EAGAIN)
   {
-    WARN_S( _("Waechter Thread nicht gestartet Fehler: ")  << fehler );
+    WARN_S( "observer thread not started Error: "  << fehler );
   } else
   if( fehler == 64/*PTHREAD_THREADS_MAX -- linux*/ )
   {
-    WARN_S( _("zu viele Waechter Threads Fehler: ") << fehler );
+    WARN_S( "too many observer threads Error: " << fehler );
   } else
   if( fehler != 0 )
   {
-    WARN_S( _("unbekannter Fehler beim Start eines Waechter Threads Fehler: ") << fehler );
+    WARN_S( "unknown error at start of observer thread: " << fehler );
   }
 }
 
@@ -1117,13 +1130,13 @@ schreibeDatei(const void *data, gint groesse, std::string name)
     {
       f.write ( (char*)data, groesse );
 #     ifdef DEBUG
-      g_print (_("Profile %s written."), name.c_str());
+      g_print ("Profile %s written.", name.c_str());
 #     endif
     }
     f.close();
     DBG_S("Profil geschrieben")
   } else
-    g_print (_("Profile %s not written."), name.c_str());
+    g_print ("Profile %s not written.", name.c_str());
 }
 
 /** @brief Ebenenlayout -> lcms Farblayout
@@ -1207,13 +1220,14 @@ bearbeiteEingebetteteProfile( channel *layer )
     return 1;
   }
 
-  layer->intent = gimp_display_get_cms_intent (image_ID);
+  layer->intent = gimp_display_get_cms_intent (image_ID, ICC_IMAGE_PROFILE);
   DBG_S( layer->intent <<" "<< intent_alt )
 
   char* profil_name = gimp_image_get_icc_profile_description(image_ID,
                                                              ICC_IMAGE_PROFILE);
-  char* pprofil_name = (char*) calloc (1,1);
-  if(gimp_image_has_icc_profile(image_ID, ICC_PROOF_PROFILE))
+  char* pprofil_name = (char*) calloc (sizeof(char*),1);
+  //if( gimp_image_has_icc_profile( image_ID, ICC_PROOF_PROFILE ) &&
+  //    gimp_display_is_colormanaged( layer->display_ID, ICC_PROOF_PROFILE ) )
   {
     pprofil_name = gimp_image_get_icc_profile_description(image_ID, 
                                                           ICC_PROOF_PROFILE);
@@ -1222,15 +1236,17 @@ bearbeiteEingebetteteProfile( channel *layer )
   static std::string old_profil_name;
   static std::string old_pprofil_name;
 
+# ifdef DEBUG
   if(profil_name)
     ;//DBG_S( image_ID <<": "<< profil_name <<" "<< old_profil_name )
   if(pprofil_name)
-    ;//DBG_S( image_ID <<": "<< pprofil_name <<" "<< old_pprofil_name )
+    cout << image_ID <<": "<< pprofil_name <<" "<< old_pprofil_name << endl;
+# endif
 
   // Test auf Veraenderung des Profiles
-  if( strcmp(old_profil_name.c_str(), profil_name) == 0 &&
+  if( strcmp(old_profil_name.c_str(), profil_name) == 0/* &&
       (pprofil_name ?
-       (strcmp(old_pprofil_name.c_str(), pprofil_name) == 0) : old_pprofil_name.size()) )
+       (strcmp(old_pprofil_name.c_str(), pprofil_name) == 0) : old_pprofil_name.size()) */)
   { //DBG
     if(profil_name) old_profil_name = profil_name; else old_profil_name = "";
     if(pprofil_name) old_pprofil_name = pprofil_name; else old_pprofil_name ="";
@@ -1269,20 +1285,34 @@ bearbeiteEingebetteteProfile( channel *layer )
   }
 
   // Speichern des eingebetteten Proofprofiles
+  WARN_S( "proof Profil\n" )
+
+  int        new_proofing = 
+                 gimp_display_get_cms_flags (image_ID) & cmsFLAGS_SOFTPROOFING;
+  static int old_proofing = 0;
+
   if( (pprofil_name ?
-       (strcmp(old_pprofil_name.c_str(), pprofil_name) != 0) : 0) )
+       (strcmp(old_pprofil_name.c_str(), pprofil_name) != 0 ||
+        old_proofing != new_proofing ) : 0) )
   {
     gint psize=0;
-    if ( gimp_image_has_icc_profile (image_ID, ICC_PROOF_PROFILE) )
+    if ( gimp_image_has_icc_profile (image_ID, ICC_PROOF_PROFILE) &&
+         gimp_display_get_cms_flags (image_ID) & cmsFLAGS_SOFTPROOFING)
     {
       proof_profile = gimp_image_get_icc_profile_by_mem ( image_ID, &psize,
                                                           ICC_PROOF_PROFILE);
       schreibeDatei( proof_profile, psize, p );
     } else {
+      WARN_S( "schreibe 1 byte\n" )
       schreibeDatei( "", 1, p );
     }
     layer->status |= PROFIL_NEU(1);
-  }
+  } else
+# ifdef DEBUG
+    cout << "" << endl
+# endif
+    ;
+  old_proofing = new_proofing;
 
   //DBG_S( old_pprofil_name.size() <<" status:"<< layer->status )
   if(profil_name) old_profil_name = profil_name; else old_profil_name = "";
@@ -1328,6 +1358,7 @@ doWatch (gint32 image_ID_)
 
   layer = (channel*) new channel [1];
   nlayers = 1;
+  layer->display_ID = gimp_display_active();
 
   DBG_S( "layer: " << (int*)layer ) 
 
@@ -1439,12 +1470,11 @@ schreibeProfil (icUInt32Number intent)
 int
 holeLayerInfo    (channel & layer)
 {
-  gint   nlayers_,
-         var, var1, var2, var3, var4;
+  gint   var, var1, var2, var3, var4;
   GDrawableType/*GimpDrawableType*/ drawable_type;
 
   gint32 drawable_ID = gimp_image_get_active_layer (image_ID);
-  if(!drawable_ID)
+  if(drawable_ID < 0)
     g_message(_("No active drawable found."));
 
   // Durchlauf
@@ -1463,8 +1493,8 @@ holeLayerInfo    (channel & layer)
         layer.drawable_type = drawable_type;
       }
       // Dimension
-      if(layer.width != layer.drawable->width ||
-         layer.height != layer.drawable->height) {
+      if(layer.width != (int)layer.drawable->width ||
+         layer.height != (int)layer.drawable->height) {
         layer.status |= GEOMETRY_NEU(1);
         layer.width  = layer.drawable->width;
         layer.height = layer.drawable->height;
@@ -1556,6 +1586,7 @@ setzeRaster( channel *layer )
   cout <<"start: "<< x_start <<","<< y_start << " "; DBG
   cout <<"num:   "<< x_num <<","<< y_num << " "; DBG
   #endif
+  return 0;
 }
 
 /** @brief reserviere Farbspeicher
