@@ -69,6 +69,7 @@
 #include "lib/plugin_main.h"
 #include <string.h>
 #include <assert.h>
+#include <libgimp/stdplugins-intl.h>
 
 /* #define IFF_DEBUG */
 
@@ -212,6 +213,8 @@ static void run ( char *name, int nparams, GParam *param, int *nRetVal,
 	values[0].type = PARAM_STATUS;
 	values[0].data.d_status =STATUS_CALLING_ERROR;
 
+        INIT_I18N_UI();
+
 	if (strcmp (name, "file_maya_iff_load") == 0) {
 		/* Perform the image load */
 		image_ID = load_image (param[1].data.d_string);
@@ -950,11 +953,11 @@ static gint32 load_image (char *filename)
 	/* Set up progress display */
 	progMessage = g_malloc(strlen (filename) + 12);
 	if (!progMessage) gimp_quit ();
-	sprintf (progMessage, "Loading %s:", filename);
+	sprintf (progMessage, "%s %s:",_("Loading"), filename);
 	gimp_progress_init (progMessage);
 	g_free (progMessage);
 
-	IFF_DEBUG_PRINT("Opening file: %s\n",filename);
+	IFF_DEBUG_PRINT("Loading file: %s\n", filename);
 
 	/* Open the file */
 	file = fopen( filename, "rb" );
@@ -1047,7 +1050,7 @@ static gint32 load_image (char *filename)
     } 
      
     if ( flags & ZBUFFER_FLAG ) {
-	    z_layer_ID = gimp_layer_new ( image_ID, "Z-Buffer",
+	    z_layer_ID = gimp_layer_new ( image_ID, _("Z-Buffer"),
 	    							  width,
 	    							  height,
 	    							  RGBA_IMAGE, 100, NORMAL_MODE );
@@ -1330,7 +1333,7 @@ static gint save_image( char *filename,  gint32 image_ID, gint32 drawable_ID )
 	{
 		case GRAY_IMAGE:
 		case GRAYA_IMAGE:
-            g_print("Greyscale images are not supported\n");
+            g_print(_("Greyscale images are not supported\n"));
 		    return (FALSE);
 		case RGB_IMAGE:
 			depth = 3;
@@ -1354,7 +1357,7 @@ static gint save_image( char *filename,  gint32 image_ID, gint32 drawable_ID )
 	/* Set up progress display */
 	progMessage = g_malloc(strlen (filename) + 12);
 	if (!progMessage) gimp_quit ();
-	sprintf (progMessage, "Saving %s:", filename);
+	sprintf (progMessage, "%s %s:", _("Saving"), filename);
 	gimp_progress_init (progMessage);
 	g_free (progMessage);
 
