@@ -31,6 +31,7 @@
 #include <jpeglib.h>
 #include "gtk/gtk.h"
 #include "lib/plugin_main.h"
+#include "libgimp/stdplugins-intl.h"
 
 #include <stdio.h>
 #include "lcms.h"
@@ -168,6 +169,8 @@ run (char    *name,
   GStatusType status = STATUS_SUCCESS;
   gint32 image_ID;
 
+  INIT_I18N_UI();
+
   run_mode = param[0].data.d_int32;
 
   *nreturn_vals = 1;
@@ -299,7 +302,7 @@ load_image (char *filename)
     }
 
   name = malloc (strlen (filename) + 12);
-  sprintf (name, "Loading %s:", filename);
+  sprintf (name, "%s %s:", _("Loading"), filename);
   gimp_progress_init (name);
   free (name);
 
@@ -378,7 +381,7 @@ load_image (char *filename)
   image_ID = gimp_image_new (cinfo.output_width, cinfo.output_height, image_type);
   gimp_image_set_filename (image_ID, filename);
 
-  layer_ID = gimp_layer_new (image_ID, "Background",
+  layer_ID = gimp_layer_new (image_ID, _("Background"),
 			     cinfo.output_width,
 			     cinfo.output_height,
 			     layer_type, 100, NORMAL_MODE);
@@ -493,7 +496,7 @@ save_image (char   *filename,
 
   name = malloc (strlen (filename) + 11);
 
-  sprintf (name, "Saving %s:", filename);
+  sprintf (name, "%s %s:",_("Saving"), filename);
   gimp_progress_init (name);
   free (name);
 
@@ -699,14 +702,14 @@ save_dialog ()
   gtk_rc_parse (gimp_gtkrc ());
 
   dlg = gtk_dialog_new ();
-  gtk_window_set_title (GTK_WINDOW (dlg), "Save as Jpeg");
+  gtk_window_set_title (GTK_WINDOW (dlg), _("Save as Jpeg"));
   gtk_window_position (GTK_WINDOW (dlg), GTK_WIN_POS_MOUSE);
   gtk_signal_connect (GTK_OBJECT (dlg), "destroy",
 		      (GtkSignalFunc) save_close_callback,
 		      NULL);
 
   /*  Action area  */
-  button = gtk_button_new_with_label ("OK");
+  button = gtk_button_new_with_label (_("OK"));
   GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
                       (GtkSignalFunc) save_ok_callback,
@@ -715,7 +718,7 @@ save_dialog ()
   gtk_widget_grab_default (button);
   gtk_widget_show (button);
 
-  button = gtk_button_new_with_label ("Cancel");
+  button = gtk_button_new_with_label (_("Cancel"));
   GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
   gtk_signal_connect_object (GTK_OBJECT (button), "clicked",
 			     (GtkSignalFunc) gtk_widget_destroy,
@@ -724,7 +727,7 @@ save_dialog ()
   gtk_widget_show (button);
 
   /*  parameter settings  */
-  frame = gtk_frame_new ("Parameter Settings");
+  frame = gtk_frame_new (_("Parameter Settings"));
   gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
   gtk_container_border_width (GTK_CONTAINER (frame), 10);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), frame, TRUE, TRUE, 0);
@@ -732,7 +735,7 @@ save_dialog ()
   gtk_container_border_width (GTK_CONTAINER (table), 10);
   gtk_container_add (GTK_CONTAINER (frame), table);
 
-  label = gtk_label_new ("Quality");
+  label = gtk_label_new (_("Quality"));
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1, GTK_FILL | GTK_EXPAND, GTK_FILL, 5, 0);
   scale_data = gtk_adjustment_new (jsvals.quality, 0.0, 1.0, 0.01, 0.01, 0.0);
@@ -748,7 +751,7 @@ save_dialog ()
   gtk_widget_show (label);
   gtk_widget_show (scale);
 
-  label = gtk_label_new ("Smoothing");
+  label = gtk_label_new (_("Smoothing"));
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2, GTK_FILL | GTK_EXPAND, GTK_FILL, 5, 0);
   scale_data = gtk_adjustment_new (jsvals.smoothing, 0.0, 1.0, 0.01, 0.01, 0.0);
@@ -764,7 +767,7 @@ save_dialog ()
   gtk_widget_show (label);
   gtk_widget_show (scale);
 
-  toggle = gtk_check_button_new_with_label("Optimize");
+  toggle = gtk_check_button_new_with_label(_("Optimize"));
   gtk_table_attach(GTK_TABLE(table), toggle, 0, 2, 2, 3, GTK_FILL, 0, 0, 0);
   gtk_signal_connect(GTK_OBJECT(toggle), "toggled",
                      (GtkSignalFunc)save_optimize_update, NULL);
