@@ -1,5 +1,5 @@
 /*
- * "$Id: png.c,v 1.6 2005/06/15 20:36:19 beku Exp $"
+ * "$Id: png.c,v 1.8 2006/10/11 08:05:45 beku Exp $"
  *
  *   Portable Network Graphics (PNG) plug-in for The GIMP -- an image
  *   manipulation program
@@ -56,6 +56,7 @@
 #include "../../lib/wire/iodebug.h"
 #include "../../lib/dialog.h"
 #include "../../lib/widgets.h"
+#include "libgimp/stdplugins-intl.h"
 
 #include <png.h>		/* PNG library definitions */
 
@@ -231,6 +232,8 @@ run (gchar   *name,
   gint32        orig_image_ID;
   //GimpExportReturnType export = GIMP_EXPORT_CANCEL; //FIXME XXX
 
+  INIT_I18N_UI();
+
   *nreturn_vals = 1;
   *return_vals  = values;
   values[0].type          = PARAM_STATUS;
@@ -427,9 +430,9 @@ load_image (gchar *filename)	/* I - File to load */
   png_init_io(pp, fp);
 
   if (strrchr(filename, '/') != NULL)
-    progress = g_strdup_printf ("Loading %s:", strrchr(filename, '/') + 1);
+    progress = g_strdup_printf ("%s %s:", _("Loading"),  strrchr(filename, '/') + 1);
   else
-    progress = g_strdup_printf ("Loading %s:", filename);
+    progress = g_strdup_printf ("%s %s:", _("Loading"), filename);
 
   gimp_progress_init(progress);
   g_free (progress);
@@ -592,7 +595,7 @@ load_image (gchar *filename)	/* I - File to load */
   * Create the "background" layer to hold the image...
   */
 
-  layer = gimp_layer_new(image, "Background", info->width, info->height,
+  layer = gimp_layer_new(image, _("Background"), info->width, info->height,
                          layer_type, 100, NORMAL_MODE);
   gimp_image_add_layer(image, layer, 0);
 
@@ -840,9 +843,9 @@ save_image (gchar  *filename,	        /* I - File to save to */
   png_init_io(pp, fp);
 
   if (strrchr(filename, '/') != NULL)
-    progress = g_strdup_printf ("Saving %s:", strrchr(filename, '/') + 1);
+    progress = g_strdup_printf ("%s %s:", _("Saving"), strrchr(filename, '/') + 1);
   else
-    progress = g_strdup_printf ("Saving %s:", filename);
+    progress = g_strdup_printf ("%s %s:", _("Saving"), filename);
 
   gimp_progress_init(progress);
   g_free (progress);
@@ -1508,14 +1511,14 @@ save_dialog (void)
   GtkWidget *scale;
   GtkObject *scale_data;
 
-  dlg = gimp_dialog_new ("Save as PNG", "png",
+  dlg = gimp_dialog_new (_("Save as PNG"), "png",
 			 gimp_standard_help_func, "filters/png.html",
 			 GTK_WIN_POS_MOUSE,
 			 FALSE, TRUE, FALSE,
 
-			 "OK", save_ok_callback,
+			 _("OK"), save_ok_callback,
 			 NULL, NULL, NULL, TRUE, FALSE,
-			 "Cancel", gtk_widget_destroy,
+			 _("Cancel"), gtk_widget_destroy,
 			 NULL, 1, NULL, FALSE, TRUE,
 
 			 NULL);
@@ -1524,7 +1527,7 @@ save_dialog (void)
 		      GTK_SIGNAL_FUNC (gtk_main_quit),
 		      NULL);
 
-  frame = gtk_frame_new ("Parameter Settings");
+  frame = gtk_frame_new (_("Parameter Settings"));
   gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
   gtk_container_set_border_width (GTK_CONTAINER (frame), 6);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), frame, TRUE, TRUE, 0);
@@ -1537,7 +1540,7 @@ save_dialog (void)
   gtk_container_add (GTK_CONTAINER (frame), table);
   gtk_widget_show (table);
 
-  toggle = gtk_check_button_new_with_label ("Interlacing (Adam7)");
+  toggle = gtk_check_button_new_with_label (_("Interlacing (Adam7)"));
   gtk_table_attach (GTK_TABLE (table), toggle, 0, 2, 0, 1,
 		    GTK_FILL, 0, 0, 0);
   gtk_signal_connect (GTK_OBJECT (toggle), "toggled",
@@ -1546,7 +1549,7 @@ save_dialog (void)
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toggle), pngvals.interlaced);
   gtk_widget_show (toggle);
 
-  toggle = gtk_check_button_new_with_label ("Save background color");
+  toggle = gtk_check_button_new_with_label (_("Save background color"));
   gtk_table_attach (GTK_TABLE (table), toggle, 0, 2, 1, 2,
 		    GTK_FILL, 0, 0, 0);
   gtk_signal_connect (GTK_OBJECT (toggle), "toggled",
@@ -1555,7 +1558,7 @@ save_dialog (void)
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toggle), pngvals.bkgd);
   gtk_widget_show (toggle);
 
-  toggle = gtk_check_button_new_with_label ("Save gamma");
+  toggle = gtk_check_button_new_with_label (_("Save gamma"));
   gtk_table_attach (GTK_TABLE (table), toggle, 0, 2, 2, 3,
 		    GTK_FILL, 0, 0, 0);
   gtk_signal_connect (GTK_OBJECT (toggle), "toggled",
@@ -1564,7 +1567,7 @@ save_dialog (void)
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toggle), pngvals.gama);
   gtk_widget_show (toggle);
 
-  toggle = gtk_check_button_new_with_label ("Save layer offset");
+  toggle = gtk_check_button_new_with_label (_("Save layer offset"));
   gtk_table_attach (GTK_TABLE (table), toggle, 0, 2, 3, 4,
 		    GTK_FILL, 0, 0, 0);
   gtk_signal_connect (GTK_OBJECT (toggle), "toggled",
@@ -1573,7 +1576,7 @@ save_dialog (void)
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toggle), pngvals.offs);
   gtk_widget_show (toggle);
 
-  toggle = gtk_check_button_new_with_label ("Save resolution");
+  toggle = gtk_check_button_new_with_label (_("Save resolution"));
   gtk_table_attach (GTK_TABLE (table), toggle, 0, 2, 4, 5,
 		    GTK_FILL, 0, 0, 0);
   gtk_signal_connect (GTK_OBJECT (toggle), "toggled",
@@ -1582,7 +1585,7 @@ save_dialog (void)
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toggle), pngvals.phys);
   gtk_widget_show (toggle);
 
-  toggle = gtk_check_button_new_with_label ("Save creation time");
+  toggle = gtk_check_button_new_with_label (_("Save creation time"));
   gtk_table_attach (GTK_TABLE (table), toggle, 0, 2, 5, 6,
 		    GTK_FILL, 0, 0, 0);
   gtk_signal_connect (GTK_OBJECT (toggle), "toggled",
@@ -1599,7 +1602,7 @@ save_dialog (void)
   gtk_scale_set_digits (GTK_SCALE (scale), 0);
   gtk_range_set_update_policy (GTK_RANGE (scale), GTK_UPDATE_DELAYED);
   gimp_table_attach_aligned (GTK_TABLE (table), 0, 6,
-			     "Compression Level:", 1.0, 1.0,
+			     _("Compression Level:"), 1.0, 1.0,
 			     scale, 1, FALSE);
   gtk_signal_connect (GTK_OBJECT (scale_data), "value_changed",
 		      GTK_SIGNAL_FUNC (gimp_int_adjustment_update),
