@@ -16,6 +16,11 @@
    trade secrets or any patents by this file or any part thereof.  In no
    event will the author be liable for any lost revenue or profits or
    other special, indirect and consequential damages.
+
+   * initial version - ku.b 06.11.2005 : v0.1 
+   * bug fix - ku.b 08.11.2005
+   * add saving - ku.b 30.3.2006 : v0.2 
+
 */
 
 
@@ -66,7 +71,7 @@
 /***   versioning   ***/
 
 static char plug_in_version_[64];
-static char Version_[] = "v0.1";
+static char Version_[] = "v0.2";
 
 
 /***   include files   ***/
@@ -136,7 +141,6 @@ static void
 query (void)
 {
   char *date=NULL;
-  char formats[] = "RGB*, GRAY*, INDEXED*, U16_RGB*, U16_GRAY*, FLOAT16_GRAY*, FLOAT_RGB*, FLOAT_GRAY*";
   
   static GimpParamDef load_args[] =
   {
@@ -175,8 +179,7 @@ query (void)
                           nload_args, nload_return_vals,
                           load_args, load_return_vals);
   gimp_register_load_handler ("file_pnm_load", "pgm,pnm,ppm,pfm", "");
-# if 0
-  sprintf (date,"%s\n2005", version()); 
+
   gimp_install_procedure ("file_pnm_save",
                           "saves files in the pnm file format",
                           "This plug-in saves PNM files.",
@@ -184,13 +187,27 @@ query (void)
                           "2005 Kai-Uwe Behrmann",
                           date,
                           "<Save>/PNM",
-                          formats,
+                          "RGB*, GRAY*, U16_RGB*, U16_GRAY*",
                           GIMP_PLUGIN,
                           nsave_args, 0,
                           save_args, NULL);
 
-  gimp_register_save_handler ("file_pnm_save", "pgm,pnm,ppm,pfm", "");
-# endif
+  gimp_register_save_handler ("file_pnm_save", "pgm,pnm,ppm", "");
+
+  gimp_install_procedure ("file_pfm_save",
+                          "saves files in the pfm file format",
+                          "This plug-in saves PFM files.",
+                          "Kai-Uwe Behrmann",
+                          "2005 Kai-Uwe Behrmann",
+                          date,
+                          "<Save>/PFM",
+                          "FLOAT_RGB*, FLOAT_GRAY*",
+                          GIMP_PLUGIN,
+                          nsave_args, 0,
+                          save_args, NULL);
+
+  gimp_register_save_handler ("file_pfm_save", "pfm", "");
+
   m_free (date)
 }
 
@@ -247,7 +264,7 @@ run                      (gchar     *name,
 	default:
 	  break;
 	}
-#if 0
+
       *nreturn_vals = 1;
       if (save_image (param[3].data.d_string, param[1].data.d_int32,
                       param[2].data.d_int32) == 1)
@@ -256,7 +273,7 @@ run                      (gchar     *name,
 	}
       else
 	values[0].data.d_status = GIMP_PDB_EXECUTION_ERROR;
-#endif
+
 
     }
 }
@@ -345,7 +362,8 @@ load_image ( gchar *filename)
   if(data[fpos] == 'P')
   {
     if(isdigit(data[++fpos])) {
-      char tmp[2] = {data[fpos], 0};
+      char tmp[2] = {0, 0};
+      tmp[0] = data[fpos];
       type = atoi(tmp);
     } else
     if (!isspace(data[fpos]))
@@ -549,8 +567,8 @@ load_image ( gchar *filename)
                   *d_8 = 0;
     unsigned char *src;
 
-    guint16 *d_16, *s_16;
-    gfloat  *d_f,  *s_f;
+    guint16 *d_16;
+    gfloat  *d_f;
     GimpPixelRgn pixel_rgn;
 
     int byte_swap = 0;
@@ -669,4 +687,251 @@ load_image ( gchar *filename)
 }
 
 
+static gint
+save_image                  (   gchar           *filename,
+                                gint32           image_ID,
+                                gint32           drawable_ID)
+{
+  guint    width, height;	/* view sizes */
+  gint32 *layers;
+  gint nlayers;
+  FILE *fp=NULL;
+
+# ifdef DEBUG
+  printf("%s:%d %s() image_ID: %d\n",__FILE__,__LINE__,__func__, image_ID);
+# endif
+  layers = gimp_image_get_layers (image_ID, &nlayers);
+
+  if ( nlayers == -1 ) {
+    g_message("no image data to save");
+    gimp_quit ();
+  }
+
+  {
+    int byte_swap = 0;
+    int drawable_type;
+    int byteps = 1;        /* byte per sample */
+    int bps = 8;
+    int spp;
+    int alpha;
+    size_t size;
+
+             char *colourspacename = 0;
+    unsigned char *src = NULL;
+
+    GimpPixelRgn pixel_rgn;
+    GDrawable *drawable;
+
+    drawable      = gimp_drawable_get (drawable_ID);
+    drawable_type = gimp_drawable_type (drawable_ID);
+
+    width         = drawable->width;
+    height        = drawable->height;
+
+    switch (drawable_type)
+        {
+        case RGB_IMAGE:
+          spp = 3;
+          bps = 8;
+          alpha = 0;
+          break;
+        case GRAY_IMAGE:
+          spp = 1;
+          bps = 8;
+          alpha = 0;
+          break;
+        case RGBA_IMAGE:
+          spp = 4;
+          bps = 8;
+          alpha = 1;
+          break;
+        case GRAYA_IMAGE:
+          spp = 2;
+          bps = 8;
+          alpha = 1;
+          break;
+        case U16_RGB_IMAGE:
+          spp = 3;
+          bps = 16;
+          alpha = 0;
+          break;
+        case U16_GRAY_IMAGE:
+          spp = 1;
+          bps = 16;
+          alpha = 0;
+          break;
+        case U16_RGBA_IMAGE:
+          spp = 4;
+          bps = 16;
+          alpha = 1;
+          break;
+        case U16_GRAYA_IMAGE:
+          spp = 2;
+          bps = 16;
+          alpha = 1;
+          break;
+        case FLOAT_RGB_IMAGE:
+          spp = 3;
+          bps = 32;
+          alpha = 0;
+          break;
+       case FLOAT_GRAY_IMAGE:
+          spp = 1;
+          bps = 32;
+          alpha = 0;
+          break;
+        case FLOAT_RGBA_IMAGE:
+          spp = 4;
+          bps = 32;
+          alpha = 1;
+          break;
+        case FLOAT_GRAYA_IMAGE:
+          spp = 2;
+          bps = 32;
+          alpha = 1;
+          break;
+        default:
+          g_print ("Can't save this image type\n");
+          m_free (drawable)
+          return 0;
+      }
+
+    byteps = bps/8;
+#if G_BYTE_ORDER == G_LITTLE_ENDIAN
+    if( (byteps == 2) ||
+        (byteps == 4)  ) {
+      byte_swap = 1;
+    }
+#endif
+
+
+    if (alpha)
+    {
+      g_message (_("Alpha is not supported\n"));
+      m_free (drawable)
+      return 0;
+    }
+
+    if (gimp_image_has_icc_profile(image_ID, ICC_IMAGE_PROFILE))
+    {
+      if (strcmp (gimp_image_get_icc_profile_color_space_name(image_ID, ICC_IMAGE_PROFILE) , "Rgb")
+        != 0)
+      {
+          g_message (_("This Colourspace is not supported\n"));
+          m_free (drawable)
+          return 0;
+      }
+      colourspacename = gimp_image_get_icc_profile_description( image_ID, ICC_IMAGE_PROFILE );
+    }
+
+    size = width * height * spp * byteps;
+    m_new ( src, char, size, return FALSE )
+
+    gimp_pixel_rgn_init (&pixel_rgn, drawable,0,0, width, height, TRUE,FALSE);
+    gimp_pixel_rgn_get_rect (&pixel_rgn, src, 0,0, width, height);
+
+    if ((fp=fopen(filename, "wb")) != NULL &&
+        src && size)
+    {
+      size_t pt = 0;
+      char text[84];
+      int  len = 0;
+      int  i = 0;
+
+      fputc( 'P', fp );
+        if(byteps == 1 ||
+           byteps == 2)
+        {
+          if(spp == 1)
+            fputc( '5', fp );
+          else
+            fputc( '6', fp );
+        } else
+        if (byteps == 4)
+        {
+          if(spp == 1)
+            fputc( 'f', fp ); // PFM gray
+          else
+            fputc( 'F', fp ); // PFM rgb
+        }
+
+      fputc( '\n', fp );
+
+      {
+        time_t	cutime;         /* Time since epoch */
+        struct tm	*gmt;
+        gchar time_str[24];
+
+        cutime = time(NULL); /* time right NOW */
+        gmt = gmtime(&cutime);
+        strftime(time_str, 24, "%Y/%m/%d %H:%M:%S", gmt);
+        snprintf( text, 84, "# CREATOR: %s : %s\n",
+                  version(), time_str );
+      }
+      len = strlen( text );
+      do { fputc ( text[pt++] , fp);
+      } while (--len); pt = 0;
+
+      snprintf( text, 84, "# COLORSPACE: %s\n", colourspacename ?
+                colourspacename : "--" );
+      len = strlen( text );
+      do { fputc ( text[pt++] , fp);
+      } while (--len); pt = 0;
+
+      snprintf( text, 84, "%d %d\n", width, height );
+      len = strlen( text );
+      do { fputc ( text[pt++] , fp);
+      } while (--len); pt = 0;
+
+      if(byteps == 1)
+        snprintf( text, 84, "256\n" );
+      else
+      if(byteps == 2)
+        snprintf( text, 84, "65535\n" );
+      else
+      if (byteps == 4)
+      {
+        if(G_BYTE_ORDER == G_LITTLE_ENDIAN)
+          snprintf( text, 84, "-1.0\n" );
+        else
+          snprintf( text, 84, "1.0\n" );
+      }
+      else
+        g_message ("Error: byteps: %d", byteps);
+      len = strlen( text );
+      do { fputc ( text[pt++] , fp);
+      } while (--len); pt = 0;
+
+#     ifdef DEBUG
+      printf("%s:%d %s() size: %d\n",__FILE__,__LINE__,__func__, (int)size);
+#     endif
+      do {
+        if(byte_swap && (byteps == 2))
+        { if(size%2)
+            fputc ( src[pt++ - 1] , fp);
+          else
+            fputc ( src[pt++ + 1] , fp);
+        } else
+          fputc ( src[pt++] , fp);
+        ++i;
+      } while (--size); pt = 0;
+
+#     ifdef DEBUG
+      printf("%s:%d %s() size: %d\n",__FILE__,__LINE__,__func__, i);
+#     endif
+
+    }
+
+
+    if (fp)
+    {
+      fflush( fp );
+      fclose (fp);
+    }
+
+    gimp_drawable_detach (drawable);
+    m_free (src)
+  }
+  return 0;
+}
 
