@@ -1,5 +1,5 @@
 /*
- * "$Id: print-image-gimp.c,v 1.2 2005/11/05 06:51:43 beku Exp $"
+ * "$Id: print-image-gimp.c,v 1.6 2006/04/15 08:00:49 beku Exp $"
  *
  *   Print plug-in for the GIMP.
  *
@@ -30,8 +30,10 @@
 
 #include "print_gimp.h"
 
-#include "print.h"
 #include "print-intl.h"
+
+
+#include "print.h"
 #include "xmalloc.h"
 
 #ifdef DEBUG
@@ -100,6 +102,8 @@ typedef struct
   guint16 *tmp;
   gint last_printed_percent;
   gint initialized;
+  gint is_cmyk;
+  gint _8to16_b; /* shall the image be converted from 8 -> 16-bit ? */
 } Gimp_Image_t;
 
 static const char *Image_get_appname(stp_image_t *image);
@@ -178,6 +182,7 @@ Image_GimpDrawable_new  ( GimpDrawable *drawable,
                       drawable->width, drawable->height, FALSE, FALSE);
   im->image_ID = image_ID;
   im->base_type = gimp_image_base_type(drawable->id);
+  im->is_cmyk = 0;
   im->initialized = 0;
   theImage.im.rep = im;
   theImage.im.reset(&(theImage.im));
@@ -205,27 +210,50 @@ Image_GimpDrawable_new  ( GimpDrawable *drawable,
 
   im->real_bpp = gimp_drawable_bpp (drawable->id);
 
+  {
+    char* colourspace = "";
+    if( gimp_image_has_icc_profile (image_ID, ICC_IMAGE_PROFILE))
+      colourspace = gimp_image_get_icc_profile_color_space_name ( image_ID,
+                                                         ICC_IMAGE_PROFILE);
+    if((strlen(colourspace) && strcmp ("Cmyk",colourspace) == 0)) {
+      im->is_cmyk = 1;
+      printf("%s:%d is a Cmyk image\n",__FILE__,__LINE__);
+    } else
+      printf("is not a Cmyk image\n");
+  }
+
   // any conversion must be done before
   switch (gimp_drawable_type (drawable->id))
     {
     case RGB_IMAGE:
+      im->samples = 3;
       break;
-      im->samples = 3;
     case RGBA_IMAGE:
-      compute_alpha_table(im);
-      im->real_bpp = 3;
-      im->samples = 3;
+      {
+        im->real_bpp = 3;
+        im->samples = 3;
+        if( im->is_cmyk )
+        {
+          im->real_bpp = 8;
+          im->samples = 4;
+        } else
+          compute_alpha_table(im);
+      }
       break;
     case GRAY_IMAGE:
+      im->real_bpp = 1;
+      im->samples = 1;
       break;
     case GRAYA_IMAGE:
       compute_alpha_table(im);
       im->real_bpp = 1;
+      im->samples = 2;
       break;
     case INDEXED_IMAGE:
     case INDEXEDA_IMAGE:
       im->cmap = gimp_image_get_cmap(image_ID, &(im->ncolors));
       im->real_bpp = 3;
+      im->samples = im->real_bpp/2;
       break;
     case U16_RGB_IMAGE:
     case U16_RGBA_IMAGE:
@@ -249,7 +277,7 @@ Image_GimpDrawable_new  ( GimpDrawable *drawable,
       break;
   }
 
-  g_print ("%s:%d %s() image_ID %d im->base_type %d\n  im->real_bpp %d im->alpha_table %d\n",__FILE__,__LINE__,__func__,image_ID, im->base_type, im->real_bpp, (int)im->alpha_table);
+  g_print ("%s:%d %s() image_ID %d im->base_type %d\n  im->real_bpp %d|%d im->alpha_table %d\n",__FILE__,__LINE__,__func__,image_ID, im->base_type, im->real_bpp, im->samples, (int)im->alpha_table);
 
   return &theImage;
 }
@@ -382,6 +410,7 @@ Image_get_row             ( stp_image_t       *image,
   if (!im->initialized)
     {
       gimp_progress_init(_("Printing..."));
+      im->_8to16_b = 0;
 
 #if 0
       switch (im->base_type)
@@ -406,15 +435,21 @@ Image_get_row             ( stp_image_t       *image,
           break;
         case GIMP_GRAY:
           if (im->drawable->bpp == 2)
-    	im->tmp = xmalloc(im->drawable->bpp * im->w);
+            im->tmp = xmalloc(im->drawable->bpp * im->w);
           break;
         case GIMP_RGB:
-          if (im->drawable->bpp == 4)
-    	im->tmp = xmalloc(im->drawable->bpp * im->w);
+          if (im->drawable->bpp == 4) {
+            if(im->is_cmyk) {
+              im->tmp = xmalloc(im->drawable->bpp * 2 * im->w);
+              im->_8to16_b = 1;
+            } else {
+              im->tmp = xmalloc(im->drawable->bpp * im->w);
+            }
+          }
           break;
         case U16_GRAY:
           if (im->drawable->bpp == 4)
-    	im->tmp = xmalloc(im->drawable->bpp * im->w);
+            im->tmp = xmalloc(im->drawable->bpp * im->w);
           break;
         case U16_RGB:
           if (im->drawable->bpp == 8)
@@ -449,6 +484,17 @@ Image_get_row             ( stp_image_t       *image,
     gimp_pixel_rgn_get_row(&(im->rgn), (guchar*) inter,
                            im->ox, im->oy + row * im->increment, im->w);
 
+  if(im->_8to16_b)
+  {
+    int i = 0,
+        samples = im->w * im->samples;
+    guchar *tmp = (guchar*) inter;
+
+    for(i = samples-1; i >= 0; --i)
+    {
+      inter[i] = (guint16)tmp[i]*257;
+    }
+  }
   //g_print ("%s:%d %s() im->base_type %d\nim->real_bpp %d im->alpha_table %d im->cmap %d im->mirror %d im->tmp %d im->columns %d drawable->id %d\n",__FILE__,__LINE__,__func__, im->base_type, im->real_bpp, (int)im->alpha_table, (int)im->cmap, im->mirror, (int)im->tmp, im->columns, im->drawable->id);
 
   if (im->cmap)
@@ -494,24 +540,42 @@ Image_get_row             ( stp_image_t       *image,
 
 	}
     }
+
   if (im->mirror)
     {
       /* Flip row -- probably inefficiently */
       int f; 
       int l;
       int samples = im->samples;
+      static int mirror=1;
       for (f = 0, l = im->w - 1; f < l; f++, l--)
-	{
-	  int c;
-	  guint16 tmp16;
-	  for (c = 0; c < samples; c++)
-	    {
-	      tmp16 = dest[f*samples + c];
-	      dest[f*samples + c] = dest[l*samples + c];
-	      dest[l*samples + c] = tmp16;
-	    }
-	}
+      {
+        int c;
+        if((im->real_bpp >= 4 && im->samples <= 2) ||
+           (im->real_bpp > 4 && im->samples > 2 ))
+        {
+          if(mirror){printf("16bit spiegeln\n");mirror=0;};
+          guint16 tmp16;
+          for (c = 0; c < samples; c++)
+	      {
+	        tmp16 = dest[f*samples + c];
+	        dest[f*samples + c] = dest[l*samples + c];
+	        dest[l*samples + c] = tmp16;
+          }
+        } else {
+          guint8 tmp8;
+          guint8 *dest8 = (guint8*)dest;
+          if(mirror){printf("8bit spiegeln %d %d\n", im->real_bpp, im->samples);mirror=0;};
+          for (c = 0; c < samples; c++)
+	      {
+	        tmp8 = dest8[f*samples + c];
+	        dest8[f*samples + c] = dest8[l*samples + c];
+	        dest8[l*samples + c] = tmp8;
+          }
+        }
+      }
     }
+
   last_printed_percent = row * 100 / im->h;
   if (last_printed_percent > im->last_printed_percent)
     {
@@ -569,6 +633,8 @@ Image_get_appname(stp_image_t *image)
   return pluginname;
 }
 
+
 /*
- * End of "$Id: print-image-gimp.c,v 1.2 2005/11/05 06:51:43 beku Exp $".
+ * End of "$Id: print-image-gimp.c,v 1.6 2006/04/15 08:00:49 beku Exp $".
  */
+
