@@ -46,7 +46,7 @@
 #include "print.h"
 
 #ifndef DEBUG
-// #define DEBUG
+ #define DEBUG
 #endif
 
 #ifdef DEBUG
@@ -127,11 +127,15 @@ LcmsVals vals =
   "",                  // image_filename [MAX_PATH]
   "CMYK.tif",          // tiff_file[MAX_PATH], tiff filename
   INTENT_PERCEPTUAL,   // intent,              rendering intent
+  INTENT_PERCEPTUAL,   // disp_intent,         displays rendering intent
   0x00,                // matrix,              conversion matrix
   0x00,                // precalc,             precalculation
-  0x00,                // bpc,                 black point compensation
+  0x00,                // flags,               flags
+  0x00,                // disp_flags,          flags of the active display
+  0x00,                // preserveblack,       preserve black for cmyk -> cmyk
   0,                   // bit per pixel
   "",                  // color type
+  -1,                  // display_ID
   -1,                  // o_image_ID,          original image
   -1,                  // e_image_ID,          exported image
   -1,                  // s_image_ID,          separated image
@@ -254,7 +258,7 @@ openInputProfile (void)
 {
   cmsHPROFILE hIn;
 
-  printf ("%s:%d %s()\n",__FILE__,__LINE__,__func__);
+  DBG
   {
     if ((strcmp (vals.i_profile,"") == 0)
      || (strcmp (vals.i_profile,"sRGB.icc") == 0)) {
@@ -384,8 +388,6 @@ convert_image ( void )
           alpha,
           nr_of_profiles = 2;
 
-  printf ("%s:%d %s()\n",__FILE__,__LINE__,__func__);
-
     cmsHPROFILE   hIn=NULL, hOut=NULL, hLinear=NULL,
                   multi[3], merge=NULL;
     cmsHTRANSFORM xform, linear_form=NULL;
@@ -400,6 +402,7 @@ convert_image ( void )
             precision = gimp_drawable_precision (vals.e_drawable_ID);
     FILE   *fp;
 
+  DBG
   cmyk_image_ID = vals.s_image_ID;
   cmyk_drawable_ID = vals.s_drawable_ID;
 
@@ -476,6 +479,9 @@ convert_image ( void )
     // post linearisation
     hIn = getLinearisationProfile (); 
     //hOut = cmsCreateLabProfile(cmsD50_xyY());
+#   ifdef DEBUG
+    DBG printf("linear.use_lin %d\n",linear.use_lin);
+#   endif
 
     xform = cmsCreateTransform     (hIn, wInput,
                                     NULL, wOutput,
@@ -507,7 +513,7 @@ convert_image ( void )
       } else {
         fp = fopen ( vals.o_profile, "r");
         if ( fp == NULL ) {
-          g_message ("Profile %s can not be found or is not readable.",
+          g_message (_("Profile %s can not be found or is not readable."),
                       vals.o_profile);
           return GIMP_PDB_CALLING_ERROR;
         } else {
@@ -515,9 +521,10 @@ convert_image ( void )
           hOut  = cmsOpenProfileFromFile(vals.o_profile, "r");
         }
       }
+      if( proof_profile_name ) free( proof_profile_name );
     }
     if ( hOut == NULL )
-      g_message ("Profile %s is incorrect.", vals.o_profile); 
+      g_message (_("Profile %s is incorrect."), vals.o_profile); 
 
     multi[0] = hIn;
     multi[1] = hOut;
@@ -526,7 +533,9 @@ convert_image ( void )
       char *text;
 
       text = getProfileInfo (multi[1]);
+#     ifdef DEBUG
       g_print ("%s:%d %s() \n%s\n",__FILE__,__LINE__,__func__, text);
+#     endif
       free (text);
     }
 
@@ -582,14 +591,14 @@ convert_image ( void )
     // TODO merge the linearisation profile in the printer profile
     //#define MERGE_GAMMALUT
     #ifdef MERGE_GAMMALUT
-    #ifndef cmsFLAGS_PRESERVEBLACK
-    #define cmsFLAGS_PRESERVEBLACK            0x8000
-    #endif
+#   ifdef DEBUG
+    DBG printf("MERGE_GAMMALUT\n");
+#   endif
     xform = cmsCreateMultiprofileTransform (multi, nr_of_profiles,
                                             wInput, wOutput,
                                             vals.intent, 
                                             vals.matrix|vals.precalc|vals.bpc|
-                                            cmsFLAGS_PRESERVEBLACK);
+                                            vals.preserveblack);
     if (0) { //TODO Knopf zum verschmelzen
       cmsHPROFILE merge;
 
@@ -603,7 +612,11 @@ convert_image ( void )
     xform = cmsCreateTransform     (hIn, wInput,
                                     hOut, wOutput,
                                     vals.intent, 
-                                    vals.matrix|vals.precalc|vals.bpc);
+                                    vals.matrix|vals.precalc|
+                                    vals.flags&cmsFLAGS_BLACKPOINTCOMPENSATION|
+                                    vals.preserveblack);
+      DBG_S( ("matrix %d precalc %d bpc %d",
+           vals.matrix,vals.precalc,vals.flags&cmsFLAGS_BLACKPOINTCOMPENSATION))
 
     if (strlen (vals.l_profile) > 0) {
       linear_form = cmsCreateTransform   (hLinear,
@@ -617,18 +630,12 @@ convert_image ( void )
                                           BYTES_SH(2) | 
                                           EXTRA_SH(0),
                                           INTENT_ABSOLUTE_COLORIMETRIC,
-                                          0);
+                                          cmsFLAGS_PRESERVEBLACK);
+      DBG_S( ("vals.l_profile %s",vals.l_profile) )
     }
     #endif
   }
 
-  g_print ("flags %d\n",vals.intent);
-  g_print ("flags %d\n",vals.matrix);
-  g_print ("flags %d\n",vals.precalc);
-  g_print ("flags %d\n",vals.bpc);
-  g_print ("flags %d\n",vals.matrix|vals.precalc|vals.bpc);
-
-
   if (w > 100000)     // huge image support - for lcms
     tile_height = gimp_tile_width()/8;
   else
@@ -642,7 +649,7 @@ convert_image ( void )
   BufferOut = malloc( tile_height * w *  4 * 2 );
 
 
-  gimp_progress_init ("separating ...");
+  gimp_progress_init (_("separating ..."));
 
   // prepare for access
   gimp_pixel_rgn_init (&src_rgn, drawable, 0, 0,
@@ -732,6 +739,7 @@ create_separated_image      (   void )
   int   w = gimp_drawable_width  (vals.s_drawable_ID),
         h = gimp_drawable_height (vals.s_drawable_ID);
   gint32 CMYK_display;
+  char* proof_profile_name = NULL;
 
   vals.s_image_ID = gimp_image_new  ( w, h, U16_RGB);
 
@@ -744,10 +752,10 @@ create_separated_image      (   void )
   gimp_image_add_layer (vals.s_image_ID, vals.s_drawable_ID, 1);
 
 
-  printf ("%s:%d %s()\n",__FILE__,__LINE__,__func__);
+  DBG
   convert_image ( );
 
-  char* proof_profile_name = get_proof_name();
+  proof_profile_name = get_proof_name();
 
   if (proof_profile_name && (strcmp(vals.o_profile, proof_profile_name)) == 0)
   {
@@ -760,10 +768,26 @@ create_separated_image      (   void )
   } else
     gimp_image_set_icc_profile_by_name (vals.s_image_ID, &vals.o_profile[0],
                                         ICC_IMAGE_PROFILE);
-  if (vals.show_image) { // show the print preview
+  if( proof_profile_name ) free( proof_profile_name );
+
+  // show the print preview
+  if (vals.show_image)
+  {
+    int proof_intent = INTENT_RELATIVE_COLORIMETRIC;
+    int is_proofed = gimp_display_is_colormanaged( vals.display_ID,
+                                                   ICC_PROOF_PROFILE );
+
+    if( is_proofed )
+      proof_intent = gimp_display_get_cms_intent( vals.display_ID,
+                                                   ICC_PROOF_PROFILE );
+
+    DBG_S( ("ID:%d/%d proof_intent:%d",vals.display_ID, is_proofed, proof_intent) )
+
     CMYK_display = gimp_display_new (vals.s_image_ID);
-    gimp_display_set_cms_intent (CMYK_display, INTENT_RELATIVE_COLORIMETRIC);
-    gimp_display_set_colormanaged (CMYK_display, TRUE);
+    gimp_display_set_cms_intent( CMYK_display,
+                                 proof_intent, ICC_IMAGE_PROFILE );
+    gimp_display_set_cms_flags (CMYK_display, 0);
+    gimp_display_set_colormanaged (CMYK_display, TRUE, ICC_IMAGE_PROFILE );
   }
 
   return GIMP_PDB_SUCCESS;
@@ -814,12 +838,14 @@ p_pdb_procedure_available (char *proc_name)
      return (l_nparams);
   }
 
-  printf("Warning: Procedure %s not found.\n", proc_name);
+# ifdef DEBUG
+  DBG printf("Warning: Procedure %s not found.\n", proc_name);
+#endif
   return -1;
 }	/* end p_pdb_procedure_available */
 
 
-gint32  
+gint32
 p_gimp_save_tiff (gint32 image_ID,
 		  gint32 drawable_ID,
                   gint   colour_space,
@@ -857,7 +883,9 @@ p_gimp_save_tiff (gint32 image_ID,
          gimp_destroy_params (return_vals, nreturn_vals);
          return 0;
       }
-      printf("Error: PDB call of %s failed status:%d\n", l_procname, (int)return_vals[0].data.d_status);
+#     ifdef DEBUG
+      DBG printf("Error: PDB call of %s failed status:%d\n", l_procname, (int)return_vals[0].data.d_status);
+#     endif
    }
 
    return(-1);
@@ -939,20 +967,13 @@ get_print_profile()
 char*
 get_proof_name()
 {
-  static char description[MAX_PATH];
-  description[0] = '0';
+  char* text = NULL;
 
   if( gimp_image_has_icc_profile (vals.o_image_ID, ICC_PROOF_PROFILE) )
-  {
-    char* text = gimp_image_get_icc_profile_description( vals.o_image_ID,
+    text = gimp_image_get_icc_profile_description( vals.o_image_ID,
                                                              ICC_PROOF_PROFILE);
-    if(text)
-    {
-      sprintf( description, text );
-      free( text );
-    }
-  }
-  return description;
+
+  return text;
 }
 
 int
@@ -1078,7 +1099,7 @@ test_print_settings                     (void)
     case FLOAT16_RGBA_IMAGE:
     case FLOAT_RGB_IMAGE:
     case FLOAT_RGBA_IMAGE:
-      g_message("drawable type %d is not supported for direct printing.", drawable_type);
+      g_message(_("drawable type %d is not supported for direct printing."), drawable_type);
       return FALSE;
       break;
     case GRAY_IMAGE:
