@@ -25,7 +25,7 @@
  *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-char version_[128] = "ICC print plug-in v0.4.1-alpha";
+char version_[128] = "ICC print plug-in v0.4.2-alpha";
 
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
@@ -42,6 +42,7 @@ char version_[128] = "ICC print plug-in v0.4.1-alpha";
 #include <lcms.h>
 #include "print_gimp.h"
 
+#include "print.h"
 #include "print-lcms-funcs.h"
 #include "print-lcms-options.h"
 #include "print-lcms-options-callbacks.h"
@@ -170,6 +171,7 @@ GtkWidget *fileselection1;
   GtkWidget *no_prec_radiobutton;
   GtkWidget *precalc_hseparator;
   GtkWidget *bpc_checkbutton;
+  GtkWidget *preserveblack_checkbutton;
   GtkWidget *print_opts_label;
   GtkWidget *lin_opts_vbox;
   GtkWidget *use_linearisation_checkbutton;
@@ -285,11 +287,17 @@ create_lcms_options_window (void)
   gint   use_midres_prec = (vals.precalc == 0x00);
   gint   use_lowres_prec = (vals.precalc == cmsFLAGS_LOWRESPRECALC);
   gint   use_no_prec = (vals.precalc == cmsFLAGS_NOTPRECALC);
-  gint   use_bpc = (vals.bpc == cmsFLAGS_BLACKPOINTCOMPENSATION);
+  gint   use_bpc = (vals.flags & cmsFLAGS_BLACKPOINTCOMPENSATION);
+  gint   use_preserveblack = (vals.preserveblack == cmsFLAGS_PRESERVEBLACK);
+  gchar     **argv;
+  gint      argc;
 
-  tooltips = gtk_tooltips_new ();
+  argc = 1;
+  argv = g_new (gchar *, 1);
+  argv[0] = g_strdup ("print");
 
-  accel_group = gtk_accel_group_new ();
+  gtk_init (&argc, &argv);
+  gtk_rc_parse (gimp_gtkrc ());
 
   lcms_options = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_object_set_data (GTK_OBJECT (lcms_options), "lcms_options", lcms_options);
@@ -299,6 +307,10 @@ create_lcms_options_window (void)
   gtk_window_set_position (GTK_WINDOW (lcms_options), GTK_WIN_POS_MOUSE);
   gtk_window_set_policy (GTK_WINDOW (lcms_options), FALSE, FALSE, TRUE);
 
+  tooltips = gtk_tooltips_new ();
+
+  accel_group = gtk_accel_group_new ();
+
   lcms_vbox = gtk_vbox_new (FALSE, 0);
   gtk_widget_ref (lcms_vbox);
   gtk_object_set_data_full (GTK_OBJECT (lcms_options), "lcms_vbox", lcms_vbox,
@@ -391,7 +403,7 @@ create_lcms_options_window (void)
   gtk_widget_show (profile_label_vbox);
   gtk_box_pack_start (GTK_BOX (profiles_hbox), profile_label_vbox, TRUE, TRUE, 0);
 
-  wksp_profile_label = gtk_label_new (_("Work Space Profile"));
+  wksp_profile_label = gtk_label_new (_("Editing Space Profile"));
   gtk_widget_ref (wksp_profile_label);
   gtk_object_set_data_full (GTK_OBJECT (lcms_options), "wksp_profile_label", wksp_profile_label,
                             (GtkDestroyNotify) gtk_widget_unref);
@@ -682,6 +694,15 @@ create_lcms_options_window (void)
   gtk_box_pack_start (GTK_BOX (options_vbox), bpc_checkbutton, FALSE, FALSE, 0);
   gtk_tooltips_set_tip (tooltips, bpc_checkbutton, _("BPC does scale full image across gray axis in order to accommodate the darkest tone origin media can render to darkest tone destination media can render."), NULL);
 
+  preserveblack_checkbutton = gtk_check_button_new_with_label (_("Preserve Black"));
+  gtk_widget_ref (preserveblack_checkbutton);
+  gtk_object_set_data_full (GTK_OBJECT (lcms_options), "preserveblack_checkbutton", preserveblack_checkbutton,
+                            (GtkDestroyNotify) gtk_widget_unref);
+  if(LCMS_VERSION >= 115)
+    gtk_widget_show (preserveblack_checkbutton);
+  gtk_box_pack_start (GTK_BOX (options_vbox), preserveblack_checkbutton, FALSE, FALSE, 0);
+  gtk_tooltips_set_tip (tooltips, preserveblack_checkbutton, _("Preserve Black channel of a Cmyk image to maintain K information. Useful only for Cmyk->Cmyk conversion."), NULL);
+
   print_opts_label = gtk_label_new (_("Print Options"));
   gtk_widget_ref (print_opts_label);
   gtk_object_set_data_full (GTK_OBJECT (lcms_options), "print_opts_label", print_opts_label,
@@ -1003,6 +1024,9 @@ create_lcms_options_window (void)
   gtk_signal_connect (GTK_OBJECT (bpc_checkbutton), "clicked",
                       GTK_SIGNAL_FUNC (on_bpc_checkbutton_clicked),
                       &use_bpc);
+  gtk_signal_connect (GTK_OBJECT (preserveblack_checkbutton), "clicked",
+                      GTK_SIGNAL_FUNC (on_preserveblack_checkbutton_clicked),
+                      &use_preserveblack);
   gtk_signal_connect (GTK_OBJECT (use_linearisation_checkbutton), "clicked",
                       GTK_SIGNAL_FUNC (on_use_linearisation_checkbutton_clicked),
                       NULL);
@@ -1019,8 +1043,15 @@ create_lcms_options_window (void)
 
 void init_lcms_options (void)
 {
-  if ( (strcmp(vals.o_profile, "")) == 0)
-    sprintf (vals.o_profile, get_proof_name());
+  char* ptr = get_proof_name();
+
+  if(ptr == NULL)
+  {
+    sprintf(vals.o_profile,"");
+  }
+  else
+    if ( (strcmp(vals.o_profile, "")) == 0)
+      snprintf (vals.o_profile, MAX_PATH, ptr);
 
 #ifndef USE_ALL_OPTIONS
   gtk_widget_hide (matrix_vbox);
@@ -1089,8 +1120,10 @@ void init_lcms_options (void)
     set_toogle_active (cmsFLAGS_NOTPRECALC,     no_prec_radiobutton)
   }
 
-  if (vals.bpc == cmsFLAGS_BLACKPOINTCOMPENSATION)
+  if (vals.flags |= cmsFLAGS_BLACKPOINTCOMPENSATION)
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bpc_checkbutton), TRUE);
+  if (vals.preserveblack == cmsFLAGS_PRESERVEBLACK)
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (preserveblack_checkbutton), TRUE);
 
   if (gimp_image_has_icc_profile (vals.o_image_ID, ICC_IMAGE_PROFILE)) {
     char *color_name =
@@ -1182,7 +1215,8 @@ set_profile_selection (gpointer user_data, char *profile)
   gtk_file_selection_hide_fileop_buttons (GTK_FILE_SELECTION (fileselection1));
 
 
-  if ((strcmp (profile,"")) == 0)
+  if ((strcmp (profile,"")) == 0 ||
+      (strcmp (profile,"s")) == 0)
     sprintf (profile, "/usr/share/color/icc/");
 
   if ((strcmp (profile,"h")) == 0 ||
@@ -1483,9 +1517,21 @@ on_bpc_checkbutton_clicked             (GtkButton       *button,
                                         gpointer         user_data)
 {
   if (GTK_TOGGLE_BUTTON (button)->active)
-    vals.bpc = cmsFLAGS_BLACKPOINTCOMPENSATION;
+    vals.flags |= cmsFLAGS_BLACKPOINTCOMPENSATION;
   else
-    vals.bpc = 0x00;
+    vals.flags &= ~cmsFLAGS_BLACKPOINTCOMPENSATION;
+  DBG_S(("flags (+-bpc):%d",vals.flags))
+}
+
+
+void
+on_preserveblack_checkbutton_clicked   (GtkButton       *button,
+                                        gpointer         user_data)
+{
+  if (GTK_TOGGLE_BUTTON (button)->active)
+    vals.preserveblack = cmsFLAGS_PRESERVEBLACK;
+  else
+    vals.preserveblack = 0x00;
 }
 
 // file dialog
