@@ -1,5 +1,5 @@
 /*
- * "$Id: print.c,v 1.7 2005/11/05 06:51:43 beku Exp $"
+ * "$Id: print.c,v 1.15 2006/10/11 08:08:21 beku Exp $"
  *
  *   Print plug-in for the GIMP.
  *
@@ -37,8 +37,6 @@
 
 #include "print_gimp.h"
 
-#include "lcms.h"
-
 #include <sys/types.h>
 #include <signal.h>
 #include <ctype.h>
@@ -50,17 +48,13 @@
 
 #include "print-intl.h"
 
+
+#include "lcms.h"
 #include "print.h"
+
 #include "print-lcms-funcs.h"
 #include "print-lcms-options.h"
 
-#undef DDBUG
-#ifdef DEBUG
- #define DBG printf("%s:%d %s()\n",__FILE__,__LINE__,__func__);
-#else
- #define DBG 
-#endif
-
 /*
  * Local functions...
  */
@@ -144,7 +138,7 @@ query (void)
   static const gchar *blurb = "This plug-in prints images from cinepaint.";
   static const gchar *help  = "Prints images to PostScript, PCL, or ESC/P2 printers.";
   static const gchar *auth  = "Michael Sweet <mike@easysw.com> and Robert Krawitz <rlk@alum.mit.edu>";
-  static const gchar *copy  = "Copyright 1997-2000 by Michael Sweet and Robert Krawitz, 2003-2004 Kai-Uwe Behrmann";
+  static const gchar *copy  = "Copyright 1997-2000 by Michael Sweet and Robert Krawitz, 2003-2006 Kai-Uwe Behrmann";
   static const gchar *types = "RGB*,U16_RGB*,FLOAT_RGB*";
 
   sprintf (&version_[strlen(version_)] , " (gutenprint %d.%d.%d)",STP_MAJOR_VERSION,
@@ -163,6 +157,7 @@ query (void)
 			  GIMP_PLUGIN,
 			  nargs, 0,
 			  args, NULL);
+  _("Print...");
 }
 
 static guchar *gimp_thumbnail_data = NULL;
@@ -170,12 +165,15 @@ static guchar *gimp_thumbnail_data = NULL;
 static guchar *
 stpui_get_thumbnail_data_function(void *image_ID, gint *width, gint *height,
 				  gint *bpp, gint page)
-{
+{ guchar *temp = 0;
+  int i = 0, x, y;
+
   if (gimp_thumbnail_data)
     free(gimp_thumbnail_data);
-  gimp_thumbnail_data = 0;
-           //gimp_image_get_thumbnail_data((gint) image_ID, width, height, bpp);
-  //printf ("bpp %d in %s:%d %s()\n", *bpp, __FILE__,__LINE__,__func__);
+  gimp_thumbnail_data = 
+           gimp_image_get_thumbnail_data((intptr_t)image_ID, width,height, bpp);
+
+  DBG_S( ("bpp %d %dx%d", *bpp, *width, *height) )
   return gimp_thumbnail_data;
 }
 
@@ -185,7 +183,6 @@ stpui_get_thumbnail_data_function(void *image_ID, gint *width, gint *height,
 
 volatile int SDEBUG = 1;
 
-
 static void
 run (char   *name,		/* I - Name of print program. */
      int    nparams,		/* I - Number of parameters passed in */
@@ -202,6 +199,9 @@ run (char   *name,		/* I - Name of print program. */
   stpui_image_t *image;
   gint32 base_type;
 
+  INIT_I18N_UI();
+  gimp_ui_init("print", TRUE);
+
 #ifdef LCMS_VERSION
   // Error handling
   cmsSetErrorHandler ((cmsErrorHandlerFunction) lcms_error);
@@ -284,6 +284,19 @@ run (char   *name,		/* I - Name of print program. */
 
   //g_print ("%s:%d %s() imag/drawable_ID:%d/%d type:%d\n",__FILE__,__LINE__,__func__,vals.s_image_ID,vals.s_drawable_ID, drawable_type);
 
+  if (gimp_image_has_icc_profile (vals.o_image_ID, ICC_IMAGE_PROFILE))
+  {
+    char *csp = gimp_image_get_icc_profile_color_space_name (vals.o_image_ID,
+                                                             ICC_IMAGE_PROFILE);
+    vals.display_ID = gimp_display_active();
+    vals.intent = vals.disp_intent =
+                                gimp_display_get_cms_intent( vals.display_ID,
+                                                             ICC_IMAGE_PROFILE);
+    vals.flags = vals.disp_flags = gimp_display_get_cms_flags( vals.display_ID);
+
+    DBG_S( ("%d: intent: %d flags: %d", vals.display_ID, vals.intent,
+            vals.flags) )
+  }
 
   if (!name) {
     char n = (char) "print";
@@ -301,6 +314,10 @@ run (char   *name,		/* I - Name of print program. */
       break;
     }
 
+  if (getenv("STP_DEBUG_STARTUP"))
+    while (SDEBUG)
+      ;
+
   // do_lcms_dialog
   if ( !do_lcms_dialog() ) {
     values[0].data.d_status = GIMP_PDB_CALLING_ERROR;
@@ -312,6 +329,8 @@ run (char   *name,		/* I - Name of print program. */
     return;
   }
 
+
+
   // gimp_export_image ?
   switch (run_mode)
     {
@@ -330,14 +349,15 @@ run (char   *name,		/* I - Name of print program. */
          || linear.use_lin) {
           alpha_capable = GIMP_EXPORT_CAN_HANDLE_ALPHA;
         }
-        if (gimp_image_has_icc_profile (vals.o_image_ID, ICC_IMAGE_PROFILE)) {
-          char *csp;
-          csp = gimp_image_get_icc_profile_color_space_name  (vals.o_image_ID,
+        if (gimp_image_has_icc_profile (vals.o_image_ID, ICC_IMAGE_PROFILE))
+        {
+          char *csp = gimp_image_get_icc_profile_color_space_name  (
+                                                             vals.o_image_ID,
                                                              ICC_IMAGE_PROFILE);
           if (strstr( csp, "Cmyk" ) != 0) {
             vals.color_space = PT_CMYK;
             alpha_capable = GIMP_EXPORT_CAN_HANDLE_ALPHA;
-            printf ("%s:%d %s() is CMYK\n",__FILE__,__LINE__,__func__);
+            DBG_S (("is CMYK\n"));
           }
         }
         //g_print ("alpha_capable: %d\n",alpha_capable);
@@ -404,115 +424,6 @@ run (char   *name,		/* I - Name of print program. */
       free (profile);
   } else {
 
-    // initialise libgimpprint
-
-    if (getenv("STP_DEBUG_STARTUP"))
-      while (SDEBUG)
-        ;
-
-    stp_init();
-
-  #ifdef INIT_I18N_UI
-    INIT_I18N_UI();
-    printf("%s:%d locale: %s\n", __FILE__,__LINE__, gtk_set_locale ());
-    #define SetCodesetForLocale( lang, codeset_ ) \
-    { \
-      char loc[24]; \
-      strncpy( loc, gtk_set_locale (), 24 ); \
-      char *pos = strstr( loc, lang ), *ptr; \
-      if(strchr(loc,'.')) \
-      { \
-        ptr = strchr(loc,'.'); \
-      } else { \
-        ptr = loc + strlen(loc); \
-        *ptr = '.'; \
-      } \
-      if(pos == loc) \
-      { \
-        if(5+strlen("ISO-8859-xx") <= 24) \
-          strncpy( ptr+1, codeset_, 24 ); \
-        stp_set_output_codeset( codeset_ ); \
-        /*bind_textdomain_codeset( "gutenprint", codeset_ );*/ \
-        setenv("LANG", loc, 1); \
-        printf("%s:%d locale: %s %s %s\n", __FILE__,__LINE__, gtk_set_locale (),PACKAGE, loc); \
-      } \
-    }
-
-      // add more LINGUAS here
-      // borrowed from http://czyborra.com/charsets/iso8859.html
-    SetCodesetForLocale( "af", "ISO-8859-1" ) // Afrikaans
-    SetCodesetForLocale( "ca", "ISO-8859-1" ) // Catalan
-    SetCodesetForLocale( "da", "ISO-8859-1" ) // Danish
-    SetCodesetForLocale( "de", "ISO-8859-1" ) // German
-    SetCodesetForLocale( "en", "ISO-8859-1" ) // English
-    SetCodesetForLocale( "es", "ISO-8859-1" ) // Spanish
-    SetCodesetForLocale( "eu", "ISO-8859-1" ) // Basque
-    SetCodesetForLocale( "fi", "ISO-8859-1" ) // Finnish
-    SetCodesetForLocale( "fo", "ISO-8859-1" ) // Faroese
-    SetCodesetForLocale( "fr", "ISO-8859-1" ) // French
-    SetCodesetForLocale( "ga", "ISO-8859-1" ) // Irish
-    SetCodesetForLocale( "gd", "ISO-8859-1" ) // Scottish
-    SetCodesetForLocale( "is", "ISO-8859-1" ) // Icelandic
-    SetCodesetForLocale( "it", "ISO-8859-1" ) // Italian
-    SetCodesetForLocale( "nl", "ISO-8859-1" ) // Dutch
-    SetCodesetForLocale( "no", "ISO-8859-1" ) // Norwegian
-    SetCodesetForLocale( "pt", "ISO-8859-1" ) // Portuguese
-    SetCodesetForLocale( "rm", "ISO-8859-1" ) // Rhaeto-Romanic
-    SetCodesetForLocale( "sq", "ISO-8859-1" ) // Albanian
-    SetCodesetForLocale( "sv", "ISO-8859-1" ) // Swedish
-    SetCodesetForLocale( "sw", "ISO-8859-1" ) // Swahili
-
-    SetCodesetForLocale( "cs", "ISO-8859-2" ) // Czech
-    SetCodesetForLocale( "hr", "ISO-8859-2" ) // Croatian
-    SetCodesetForLocale( "hu", "ISO-8859-2" ) // Hungarian
-    SetCodesetForLocale( "pl", "ISO-8859-2" ) // Polish
-    SetCodesetForLocale( "ro", "ISO-8859-2" ) // Romanian
-    SetCodesetForLocale( "sk", "ISO-8859-2" ) // Slovak
-    SetCodesetForLocale( "sl", "ISO-8859-2" ) // Slovenian
-
-    SetCodesetForLocale( "eo", "ISO-8859-3" ) // Esperanto
-    SetCodesetForLocale( "mt", "ISO-8859-3" ) // Maltese
-
-    SetCodesetForLocale( "et", "ISO-8859-4" ) // Estonian
-    SetCodesetForLocale( "lv", "ISO-8859-4" ) // Latvian
-    SetCodesetForLocale( "lt", "ISO-8859-4" ) // Lithuanian
-    SetCodesetForLocale( "kl", "ISO-8859-4" ) // Greenlandic
-
-    SetCodesetForLocale( "be", "ISO-8859-5" ) // Byelorussian
-    SetCodesetForLocale( "bg", "ISO-8859-5" ) // Bulgarian
-    SetCodesetForLocale( "mk", "ISO-8859-5" ) // Macedonian
-    SetCodesetForLocale( "ru", "ISO-8859-5" ) // Russian
-    SetCodesetForLocale( "sr", "ISO-8859-5" ) // Serbian
-    SetCodesetForLocale( "uk", "ISO-8859-5" ) // Ukrainian
-
-    SetCodesetForLocale( "ar", "ISO-8859-6" ) // Arabic
-    SetCodesetForLocale( "fa", "ISO-8859-6" ) // Persian
-    SetCodesetForLocale( "ur", "ISO-8859-6" ) // Pakistani Urdu
-
-    SetCodesetForLocale( "el", "ISO-8859-7" ) // Greek
-
-    SetCodesetForLocale( "iw", "ISO-8859-8" ) // Hebrew
-    SetCodesetForLocale( "ji", "ISO-8859-8" ) // Yiddish
-
-    SetCodesetForLocale( "tr", "ISO-8859-9" ) // Turkish
-
-    SetCodesetForLocale( "th", "ISO-8859-11" ) // Thai
-
-    SetCodesetForLocale( "ja", "SJIS" ) // Japan ; eucJP, ujis, EUC, PCK, jis7, SJIS
-  #else
-    /*
-     * With GCC and glib 1.2, there will be a warning here about braces in
-     * expressions.  Getting rid of it causes more problems than it solves.
-     * In particular, turning on -ansi on the command line causes a number of
-     * other useful things, such as strcasecmp, popen, and snprintf to go away
-     */
-    INIT_LOCALE (PACKAGE);
-  #endif
-
-    stpui_printer_initialize(&gimp_vars);
-
-    stpui_set_image_filename(vals.image_filename);
-
     if (values[0].data.d_status == GIMP_PDB_SUCCESS) {
       drawable = gimp_drawable_get ( vals.s_drawable_ID );
     } else {
@@ -544,17 +455,15 @@ run (char   *name,		/* I - Name of print program. */
       }
 
     if (vals.color_space == PT_CMYK) {
-      if (drawable->bpp > 4 ) {
+      //if (drawable->bpp > 4 ) {
         sprintf (vals.color_type , "CMYK");
-      }
+      //}
     }
 
     if (  vals.color_space == PT_CMYK
        && drawable->bpp < 8 ) {
       g_message ("Your CMYK image has not 16-bit per channel as is needed by gutenprint at the moment.\nHint: You can switch manually to \"16-bit Unsigned Integer\" in the \"Image\" menu of CinePaint."
                   );
-      //g_print ("%s:%d %s() drawable %d  Give an error message.\n",
-        //       __FILE__,__LINE__,__func__,vals.s_drawable_ID);
       values[0].data.d_status = GIMP_PDB_CALLING_ERROR;
       goto cleanup;
     }
@@ -569,12 +478,22 @@ run (char   *name,		/* I - Name of print program. */
     }
      
 
+    // initialise libgimpprint
+
+    stp_init();
+
+    stpui_printer_initialize(&gimp_vars);
+
+    stpui_set_image_filename(vals.image_filename);
+
     stpui_set_image_dimensions(drawable->width, drawable->height);
-    //g_print ("%s:%d %s() %d: %dx%d mit %dbyte\n",__FILE__,__LINE__,__func__, drawable->id, drawable->width, drawable->height, drawable->bpp);
     //gimp_image_get_resolution (vals.s_image_ID, &xres, &yres);
     xres = 180.0; yres = 180.0;
     stpui_set_image_resolution(xres, yres);
 
+    DBG_S( ("%d: %dx%d mit %dbyte\n",drawable->id,
+             drawable->width, drawable->height, drawable->bpp) )
+
     drawable_type = gimp_drawable_type(vals.s_drawable_ID);
     switch (drawable_type)
       {
@@ -605,19 +524,22 @@ run (char   *name,		/* I - Name of print program. */
         vals.bitpersample = 32;
         break;
       }
-    stpui_set_image_channel_depth (vals.bitpersample);
+    if(vals.bitpersample == 8 &&
+       vals.color_space == PT_CMYK)
+      stpui_set_image_channel_depth (16);
+    else
+      stpui_set_image_channel_depth (vals.bitpersample);
 
     stpui_set_image_type (vals.color_type);
-    stp_set_float_parameter(gimp_vars.v, "AppGamma", gimp_gamma());
 
-    //g_print ("%d-bit %s type\n",vals.bitpersample,vals.color_type);
+    DBG_S( ("%d-bit %s type\n",vals.bitpersample,vals.color_type) )
 
     image = Image_GimpDrawable_new(drawable, (int)vals.s_image_ID);
+    stp_set_float_parameter(gimp_vars.v, "AppGamma", gimp_gamma());
   
     if (!image)
       values[0].data.d_status = GIMP_PDB_CALLING_ERROR;
 
-    //g_print ("%s:%d %s() %d|%d,%d=%d\n",__FILE__,__LINE__,__func__,(int)drawable,vals.s_image_ID,vals.s_drawable_ID, drawable->id);
 
     switch (drawable_type)
       {
@@ -647,18 +569,14 @@ run (char   *name,		/* I - Name of print program. */
         break;
       }
 
-    if (stp_verify(gimp_vars.v))
-      g_message ("error");
+    /*if (stp_verify(gimp_vars.v))
+      g_message ("error");*/
 
     switch (run_mode)
       {
       case GIMP_RUN_INTERACTIVE:
 
-        //g_print ("%s:%d %s() o_image_Id %d|%d\n",__FILE__,__LINE__,__func__,
-          //        vals.o_image_ID,vals.o_drawable_ID);
-
-      // --- do_print_dialog ---
-        //g_print ("%s:%d %s() %s\n",__FILE__,__LINE__,__func__,stp_get_string_parameter (gimp_vars.v, (char*)"calibrated_warning_label"));
+        // --- do_print_dialog ---
         if (!do_print_dialog (name, vals.s_image_ID))
   	goto cleanup;
 
@@ -833,7 +751,8 @@ do_print_dialog (gchar *proc_name, gint32 image_ID)
   if (! getenv("STP_PRINT_MESSAGES_TO_STDERR"))
     stpui_set_errfunc(gimp_errfunc);
   stpui_set_thumbnail_func(stpui_get_thumbnail_data_function);
-  stpui_set_thumbnail_data((void *) vals.e_image_ID);
+  stpui_set_thumbnail_data((void *) vals.s_image_ID);
+  //textdomain("gutenprint");
   return stpui_do_print_dialog();
 }
 
@@ -843,6 +762,7 @@ do_lcms_dialog (void)
 {
   GtkWidget *lcms_options;
 
+  //textdomain("cinepaint-std-plugins");
   lcms_options = create_lcms_options_window ();
   init_lcms_options ();
 
@@ -855,3 +775,4 @@ do_lcms_dialog (void)
 }
 
 
+
