@@ -3,8 +3,8 @@
    by Dave Coffin at cybercom dot net, user dcoffin
    http://www.cybercom.net/~dcoffin/
 
-   $Revision: 1.5 $
-   $Date: 2005/11/05 12:28:58 $
+   $Revision: 1.9 $
+   $Date: 2006/10/31 08:04:19 $
 
    This code is licensed under the same terms as The GIMP.
    To simplify maintenance, it calls my command-line "dcraw"
@@ -32,12 +32,12 @@
 #else
 #include <lib/plugin_main.h>
 #include <lib/ui.h>
-#include <lib/intl.h>
+#include <libgimp/stdplugins-intl.h>
 #include <lib/dialog.h>
 #include <lib/widgets.h>
 #endif
 
-#define PLUG_IN_VERSION  "1.1.5-cp-0.1 - 19 April 2004 (cp 10.Mai 2004)"
+#define PLUG_IN_VERSION  "1.1.5-cp-0.2 - 19 April 2004 (cp 27. October 2006)"
 
 static void query(void);
 static void run(gchar *name,
@@ -64,7 +64,7 @@ static struct {
   gchar  i_profile[1024];         /* input profile */
   gchar  o_profile[1024];         /* output profile */
 } cfg = {
-  { FALSE, FALSE, FALSE, FALSE, FALSE, TRUE, FALSE },
+  { FALSE, FALSE, FALSE, FALSE, FALSE, TRUE, TRUE },
   { 2.2, 1.0, 1.0, 1.0 },
   16
 };
@@ -107,6 +107,19 @@ static void query (void)
     "bay,bmq,cr2,crw,cs1,dc2,dcr,dng,fff,jpg,k25,kdc,mos,mrw,nef,orf,pef,raf,raw,rdc,srf,sti,tif,tiff,x3f", "");
 }
 
+char*
+getTempFileName( const char* fname, const char* extension)
+{
+    char *tmpname = malloc(strlen(fname)+12);
+    char *ptr = strrchr( fname, '/');
+    sprintf(tmpname,"/tmp/%s", ptr ? ptr : fname);
+    ptr = strchr( tmpname, '.' );
+    if(ptr)
+      ptr[1] = 0;
+    sprintf( &tmpname[strlen(tmpname)], extension );
+    return tmpname;
+}
+
 static void run (gchar *name,
 		gint nparams,
 		GimpParam *param,
@@ -120,6 +133,8 @@ static void run (gchar *name,
   gchar *command, *fname;
   int stat;
 
+  INIT_I18N_UI();
+
   *nreturn_vals = 1;
   *return_vals = values;
 
@@ -158,8 +173,28 @@ static void run (gchar *name,
 
   status = GIMP_PDB_EXECUTION_ERROR;
   image_id = load_image (param[1].data.d_string);
-  if (image_id == -1) goto done;
 
+  if(cfg.check_val[6] || 1)
+  {
+    char *command = malloc(2048);
+
+    printf("%s %s\n", param[1].data.d_string, param[2].data.d_string);
+    param[1].data.d_string = getTempFileName( param[2].data.d_string, "tiff" );
+    printf("%s %s\n", param[1].data.d_string, param[2].data.d_string);
+    *return_vals = gimp_run_procedure2
+	("file_tiff_load", nreturn_vals, nparams, param);
+
+    sprintf(command, "rm -v %s", param[1].data.d_string);
+    fputs (command, stderr);
+    system( command );
+    if(command) free(command);
+
+    *nreturn_vals = 2;
+    gimp_set_data ("plug_in_rawphoto", &cfg, sizeof cfg);
+    return;
+  } 
+
+  if (image_id == -1) goto done;
   *nreturn_vals = 2;
   values[1].type = GIMP_PDB_IMAGE;
   values[1].data.d_image = image_id;
@@ -183,26 +218,40 @@ static gint32 load_image (gchar *filename)
   GimpPixelRgn	pixel_region;
   guchar	*pixel;
   char		*command, nl;
-  guchar        t;
   guint16       *val;
+#if G_BYTE_ORDER == G_LITTLE_ENDIAN
+  guchar        t;
+#endif
 
   /*setlocale (LC_NUMERIC, "C");*/
-  command = g_malloc (strlen(filename)+100);
+  command = g_malloc (strlen(filename)+200);
   if (!command) return -1;
   /* gamma now is handled internally - Kai-Uwe */
   sprintf (command,
-	"dcraw -4 -v -c%s%s%s%s%s%s%s "/*-g %0.2f*/ "-b %0.2f -r %0.2f -l %0.2f '%s'\n",
-	cfg.check_val[0] ? " -q 0 -n":"",
+	"dcraw -4 -v -s -c%s%s%s%s%s%s%s "/*-g %0.2f -b %0.2f -r %0.2f -l %0.2f*/" '%s'\n",
+	cfg.check_val[0] ? " -q 0":"",
 	cfg.check_val[1] ? " -h":"",
 	cfg.check_val[2] ? " -f":"",
 	cfg.check_val[3] ? " -d":"",
 	cfg.check_val[4] ? " -a":"",
 	cfg.check_val[5] ? " -w":"",
-	cfg.check_val[6] ? "":" -m",
-	/*cfg.spin_val[0],*/ cfg.spin_val[1], cfg.spin_val[2], cfg.spin_val[3],
+	cfg.check_val[6] ? " -o 3 -T":" -o 0 -T",
+	/*cfg.spin_val[0], cfg.spin_val[1], cfg.spin_val[2], cfg.spin_val[3],*/
 	filename );
-  fputs (command, stderr);
+
+  if(cfg.check_val[6] || 1)
+  {
+    char *ptr = getTempFileName( strrchr(filename,'/')+1, "tiff" );
+
+    sprintf( &command[strlen(command)-1], " > %s", ptr );
+    fputs (command, stderr);
+    system( command );
+
+    if(ptr) free(ptr);
+    return -1;
+  }
   
+  fputs (command, stderr);
   pfp = popen (command, "r");
   g_free (command);
   if (!pfp) {
@@ -228,7 +277,7 @@ static gint32 load_image (gchar *filename)
   gimp_image_set_filename (image, filename);
 
   /* Create the "background" layer to hold the image... */
-  layer = gimp_layer_new (image, "Background", width, height,
+  layer = gimp_layer_new (image, _("Background"), width, height,
 			  bpp_ppm == 3 ? RGB_IMAGE : U16_RGB_IMAGE,
 			  100, GIMP_NORMAL_MODE);
   gimp_image_add_layer (image, layer, 0);
@@ -300,12 +349,20 @@ gint load_dialog (gchar * name)
   GtkObject *adj;
   GtkWidget *widget;
   int i;
-  static const char *label[11] =
-  { _("Quick interpolation"), _("Half-size interpolation"),
-    _("Four color interpolation"), _("Grayscale document"),
-    _("Automatic white balance"), _("Camera white balance"),
-    _("Convert to sRGB"),
-    _("Gamma"), _("Brightness"), _("Red Multiplier"), _("Blue Multiplier") };
+  static const char *label[11];
+  
+  label[0] = _("Quick interpolation");
+  label[1] = _("Half-size interpolation");
+  label[2] = _("Four color interpolation");
+  label[3] = _("Grayscale document");
+  label[4] = _("Automatic white balance");
+  label[5] = _("Camera white balance");
+  label[6] = _("Convert to WideRGB");
+  label[7] = _("Gamma");
+  label[8] = _("Brightness");
+  label[9] = _("Red Multiplier");
+  label[10] = _("Blue Multiplier");
+
 
   if (!strcasecmp (name + strlen(name) - 4, ".dng"))
     cfg.used_bits = 16;
@@ -330,7 +387,7 @@ gint load_dialog (gchar * name)
 
   for (i=0; i < NCHECK; i++) {
     widget = gtk_check_button_new_with_label
-	(_(label[i]));
+	(label[i]);
     gtk_toggle_button_set_active
 	(GTK_TOGGLE_BUTTON (widget), cfg.check_val[i]);
     gtk_table_attach
