@@ -45,6 +45,9 @@
 #include "lib/dialog.h"
 #include "lib/widgets.h"
 
+#include "libgimp/gimp.h"
+#include "libgimp/stdplugins-intl.h"
+
 /* Defines */
 #define PLUG_IN_NAME        "extension_screenshot"
 
@@ -138,6 +141,7 @@ query (void)
 			  GIMP_EXTENSION,		
 			  nargs, nreturn_vals,
 			  args, return_vals);
+  _("Screen Shot...");
 }
 
 static void 
