@@ -214,7 +214,7 @@ save_ok_callback (GtkWidget *widget,
 		      (GtkSignalFunc) close_callback, \
 		      NULL); \
   \
-  button = gtk_button_new_with_label ("OK"); \
+  button = gtk_button_new_with_label (_("OK")); \
   GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT); \
   gtk_signal_connect (GTK_OBJECT (button), "clicked", \
                       (GtkSignalFunc) ok_callback, \
@@ -223,7 +223,7 @@ save_ok_callback (GtkWidget *widget,
   gtk_widget_grab_default (button); \
   gtk_widget_show (button); \
   \
-  button = gtk_button_new_with_label ("Cancel"); \
+  button = gtk_button_new_with_label (_("Cancel")); \
   GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT); \
   gtk_signal_connect_object (GTK_OBJECT (button), "clicked", \
 			     (GtkSignalFunc) /*gtk_widget_destroy*/cancel_callback, \
@@ -307,7 +307,7 @@ save_dialog                  (  ImageInfo       *info)
 
 
   /*  attach profile  */
-  LIST_FRAME ("ICC Profile data")
+  LIST_FRAME (_("ICC Profile data"))
   group = NULL;
 
   LIST_TOOGLE ( _("embedd ICC Profile"), use_icc_profile )
@@ -319,7 +319,7 @@ save_dialog                  (  ImageInfo       *info)
     gtk_widget_set_sensitive (frame, FALSE); 
 
   /*  compression  */
-  LIST_FRAME ("Compression")
+  LIST_FRAME (_("Compression"))
   group = NULL;
 
   LIST_TOOGLE (_("None"), use_none)
@@ -366,7 +366,7 @@ save_dialog                  (  ImageInfo       *info)
   gtk_widget_show (frame);
 
   /*  fillorder  */
-  LIST_FRAME ("Fill Order")
+  LIST_FRAME (_("Fill Order"))
   group = NULL;
 
   LIST_TOOGLE ( _("LSB to MSB"), use_lsb2msb )
@@ -376,7 +376,7 @@ save_dialog                  (  ImageInfo       *info)
   gtk_widget_show (frame);
 
   /*  premultiply  */
-  LIST_FRAME ("Transparency Computation")
+  LIST_FRAME (_("Transparency Computation"))
   group = NULL;
 
   sprintf (text,_("Premultiply Colour (associate)"));
@@ -520,7 +520,7 @@ text_entry_callback   ( GtkWidget *widget,
   if (len > 0) {
     if (len > 240)
     {
-      g_message ("TIFF save: Your string is too long.\n");
+      g_message (_("Your string is too long.\n"));
       return;
     } else {
       sprintf ( string_ptr, text);
