@@ -138,7 +138,7 @@ getProfileInfo                   ( cmsHPROFILE  hProfile)
   cmsCIEXYZ WhitePt;
   size_t    first = FALSE,
             min_len = 24,
-            len, i;
+            len = 0, i;
 
   profile_info = calloc( sizeof(char), 2048 );
   text = malloc(128);
@@ -334,8 +334,10 @@ get_ifd_info                (   TIFF           *tif,
         ci->alpha = 1;
         ci->assoc = 1;
         ci->extra--;
+#       ifdef DEBUG
         g_print ("alpha is premutliplied %s:%d\n",
                   __FILE__, __LINE__);
+#       endif
     } else if (ci->extra > 0
          && (ci->extra_types[0] == EXTRASAMPLE_UNASSALPHA
           || ci->extra_types[0] == EXTRASAMPLE_UNSPECIFIED)) {
@@ -536,11 +538,12 @@ get_ifd_info                (   TIFF           *tif,
         case PHOTOMETRIC_ICCLAB:
         case PHOTOMETRIC_ITULAB:
         case PHOTOMETRIC_SEPARATED:
+#         ifdef DEBUG
           if (ci->photomet == PHOTOMETRIC_SEPARATED)
             g_print("separated datas; bps|spp = %d|%d, sampleformat = %d\n", ci->bps, ci->spp, ci->sampleformat);
           else
             g_print("coloured datas; bps|spp = %d|%d, sampleformat = %d\n", ci->bps, ci->spp, ci->sampleformat);
-
+#         endif
           ci->grayscale = 0;
           if (ci->bps <= 8) {
             /*g_print("uint datas\n"); */
@@ -738,7 +741,9 @@ get_ifd_info                (   TIFF           *tif,
         hIn = cmsOpenProfileFromMem (ci->icc_profile, ci->profile_size);
         if (hIn) {
           ci->icc_profile_info = getProfileInfo (hIn);
+          #ifdef DEBUG
           g_print ("%s\n",ci->icc_profile_info);
+          #endif
           cmsCloseProfile (hIn);
           #ifdef DEBUG_
           saveProfileToFile ("/tmp/cinepaint_tiff_load.icc", ci->icc_profile,
