@@ -1,4 +1,4 @@
-/* $Id: unsharp.c,v 1.6 2005/10/31 16:43:03 beku Exp $
+/* $Id: unsharp.c,v 1.7 2006/10/04 18:33:31 beku Exp $
  *
  * unsharp.c 0.10 -- This is a plug-in for the GIMP 1.0
  *  http://www.stdout.org/~winston/gimp/unsharp.html
@@ -193,6 +193,8 @@ query (void)
 			  PROC_PLUG_IN,
 			  nargs, 0,
 			  args, NULL);
+  _("Unsharp Mask...");
+  _("Enhance");
 }
 
 /* this is the actual function */
@@ -220,7 +222,7 @@ run (gchar   *name,
   *return_vals = values;
   *nreturn_vals = 1;
 
-  //INIT_I18N_UI(); 
+  INIT_I18N_UI(); 
 
   switch (run_mode)
     {
@@ -293,7 +295,7 @@ unsharp_mask (TileDrawable *drawable,
 
   /* Get the input */
   gimp_drawable_mask_bounds(drawable->id, &x1, &y1, &x2, &y2);
-  gimp_progress_init("Blurring...");
+  gimp_progress_init(_("Blurring..."));
 
   width = drawable->width;
   height = drawable->height;
@@ -399,7 +401,7 @@ unsharp_region (GPixelRgn srcPR,
 	gimp_progress_update((gdouble)col/(3*x) + 0.33);
     }
 
-  gimp_progress_init("Merging...");
+  gimp_progress_init(_("Merging..."));
 
   /* find integer value of threshold */
   threshold = unsharp_params.threshold;
@@ -1262,14 +1264,14 @@ unsharp_mask_dialog (void)
 
   gimp_ui_init ("unsharp", TRUE);
 
-  window = gimp_dialog_new ("Unsharp Mask", "unsharp",
+  window = gimp_dialog_new (_("Unsharp Mask"), "unsharp",
 			    gimp_standard_help_func, "filters/unsharp.html",
 			    GTK_WIN_POS_MOUSE,
 			    FALSE, TRUE, FALSE,
 
-			    "OK", unsharp_ok_callback,
+			    _("OK"), unsharp_ok_callback,
 			    NULL, NULL, NULL, TRUE, FALSE,
-			    "Cancel", gtk_widget_destroy,
+			    _("Cancel"), gtk_widget_destroy,
 			    NULL, 1, NULL, FALSE, TRUE,
 
 			    NULL);
@@ -1278,7 +1280,7 @@ unsharp_mask_dialog (void)
 		      GTK_SIGNAL_FUNC (gtk_main_quit),
 		      NULL);
 
-  frame = gtk_frame_new ("Parameter Settings");
+  frame = gtk_frame_new (_("Parameter Settings"));
   gtk_container_set_border_width (GTK_CONTAINER (frame), 6);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (window)->vbox), frame,
 		      FALSE, FALSE, 0);
@@ -1292,7 +1294,7 @@ unsharp_mask_dialog (void)
   gtk_widget_show (table);
 
   adj = gimp_scale_entry_new (GTK_TABLE (table), 0, 0,
-			      "Radius:", SCALE_WIDTH, 0,
+			      _("Radius:"), SCALE_WIDTH, 0,
 			      unsharp_params.radius, 1.0, 150.0, 0.1, 1.0, 1,
 			      TRUE, 0, 0,
 			      NULL, NULL);
@@ -1301,7 +1303,7 @@ unsharp_mask_dialog (void)
 		      &unsharp_params.radius);
 
   adj = gimp_scale_entry_new (GTK_TABLE (table), 0, 1,
-			      "Amount:", SCALE_WIDTH, 0,
+			      _("Amount:"), SCALE_WIDTH, 0,
 			      unsharp_params.amount, 0.0, 5.0, 0.01, 0.1, 2,
 			      TRUE, 0, 0,
 			      NULL, NULL);
@@ -1310,7 +1312,7 @@ unsharp_mask_dialog (void)
 		      &unsharp_params.amount);
 
   adj = gimp_scale_entry_new (GTK_TABLE (table), 0, 2,
-			      "Threshold:", SCALE_WIDTH, 0,
+			      _("Threshold:"), SCALE_WIDTH, 0,
 			      unsharp_params.threshold, 0.0, 255.0, 1.0, 10.0, 0,
 			      TRUE, 0, 0,
 			      NULL, NULL);
